@@ -599,15 +599,9 @@ class IptablesFirewallDriver(firewall.FirewallDriver):
                                 rule, port, direction))
         return port_rules
 
-    def _get_any_remote_group_id_in_rule(self, rule):
-        remote_group_id = rule.get('remote_group_id')
-        if not remote_group_id:
-            remote_group_id = rule.get('remote_address_group_id')
-        return remote_group_id
-
     def _expand_sg_rule_with_remote_ips(self, rule, port, direction):
         """Expand a remote group rule to rule per remote group IP."""
-        remote_group_id = self._get_any_remote_group_id_in_rule(rule)
+        remote_group_id = rule.get('remote_group_id')
         if remote_group_id:
             ethertype = rule['ethertype']
             port_ips = port.get('fixed_ips', [])
@@ -629,7 +623,7 @@ class IptablesFirewallDriver(firewall.FirewallDriver):
         for sg_id in sg_ids:
             for rule in self.sg_rules.get(sg_id, []):
                 if not direction or rule['direction'] == direction:
-                    remote_sg_id = self._get_any_remote_group_id_in_rule(rule)
+                    remote_sg_id = rule.get('remote_group_id')
                     ether_type = rule.get('ethertype')
                     if remote_sg_id and ether_type:
                         remote_sg_ids[ether_type].add(remote_sg_id)
@@ -709,7 +703,7 @@ class IptablesFirewallDriver(firewall.FirewallDriver):
         return args
 
     def _convert_sg_rule_to_iptables_args(self, sg_rule):
-        remote_gid = self._get_any_remote_group_id_in_rule(sg_rule)
+        remote_gid = sg_rule.get('remote_group_id')
         if self.enable_ipset and remote_gid:
             return self._generate_ipset_rule_args(sg_rule, remote_gid)
         else:
@@ -737,7 +731,7 @@ class IptablesFirewallDriver(firewall.FirewallDriver):
 
     def _drop_invalid_packets(self, iptables_rules):
         # Always drop invalid packets
-        iptables_rules += [comment_rule('-m state --state ' 'INVALID -j DROP',
+        iptables_rules += [comment_rule('-m state --state INVALID -j DROP',
                                         comment=ic.INVALID_DROP)]
         return iptables_rules
 
@@ -775,14 +769,6 @@ class IptablesFirewallDriver(firewall.FirewallDriver):
         if not self._iptables_protocol_name_map:
             tmp_map = constants.IPTABLES_PROTOCOL_NAME_MAP.copy()
             tmp_map.update(self._local_protocol_name_map())
-            # iptables-save uses different strings for 'ipip' (protocol 4)
-            # depending on the distro, which corresponds to the entry for
-            # '4' in /etc/protocols. For example:
-            # - 'ipencap' in Ubuntu
-            # - 'ipv4' in CentOS/Fedora
-            # For this reason, we need to map the string for 'ipip' to the
-            # system-dependent string for '4', see bug #2054324.
-            tmp_map[constants.PROTO_NAME_IPIP] = tmp_map['4']
             self._iptables_protocol_name_map = tmp_map
         return self._iptables_protocol_name_map
 
@@ -937,14 +923,14 @@ class IptablesFirewallDriver(firewall.FirewallDriver):
                 del self.sg_members[sg_id]
 
     def _find_deleted_sg_rules(self, sg_id):
-        del_rules = list()
+        del_rules = []
         for pre_rule in self.pre_sg_rules.get(sg_id, []):
             if pre_rule not in self.sg_rules.get(sg_id, []):
                 del_rules.append(pre_rule)
         return del_rules
 
     def _find_devices_on_security_group(self, sg_id):
-        device_list = list()
+        device_list = []
         for device in self.filtered_ports.values():
             if sg_id in device.get('security_groups', []):
                 device_list.append(device)
