@@ -117,13 +117,8 @@ class KeepalivedVipAddress(object):
         result = '%s dev %s' % (self.ip_address, self.interface_name)
         if self.scope:
             result += ' scope %s' % self.scope
-        if cfg.CONF.keepalived_use_no_track and not self.track:
-            if _is_keepalived_use_no_track_supported():
-                result += ' no_track'
-            else:
-                LOG.warning("keepalived_use_no_track cfg option is True but "
-                            "keepalived on host seems to not support this "
-                            "option")
+        if not self.track and _is_keepalived_use_no_track_supported():
+            result += ' no_track'
         return result
 
 
@@ -131,11 +126,12 @@ class KeepalivedVirtualRoute(object):
     """A virtual route entry of a keepalived configuration."""
 
     def __init__(self, destination, nexthop, interface_name=None,
-                 scope=None):
+                 scope=None, track=True):
         self.destination = destination
         self.nexthop = nexthop
         self.interface_name = interface_name
         self.scope = scope
+        self.track = track
 
     def build_config(self):
         output = self.destination
@@ -145,13 +141,8 @@ class KeepalivedVirtualRoute(object):
             output += ' dev %s' % self.interface_name
         if self.scope:
             output += ' scope %s' % self.scope
-        if cfg.CONF.keepalived_use_no_track:
-            if _is_keepalived_use_no_track_supported():
-                output += ' no_track'
-            else:
-                LOG.warning("keepalived_use_no_track cfg option is True but "
-                            "keepalived on host seems to not support this "
-                            "option")
+        if not self.track and _is_keepalived_use_no_track_supported():
+            output += ' no_track'
         # NOTE(mstinsky): neutron and keepalived are adding the same routes on
         # primary routers. With this we ensure that both are adding the routes
         # with the same procotol and prevent duplicated routes which result in
@@ -233,7 +224,7 @@ class KeepalivedInstance(object):
         self.authentication = (auth_type, password)
 
     def add_vip(self, ip_cidr, interface_name, scope):
-        track = interface_name in self.track_interfaces
+        track = interface_name not in self.track_interfaces
         vip = KeepalivedVipAddress(ip_cidr, interface_name, scope, track=track)
         if vip not in self.vips:
             self.vips.append(vip)
