@@ -40,6 +40,7 @@ from neutron.agent.linux.openvswitch_firewall import constants as ovsfw_consts
 from neutron.agent.linux.openvswitch_firewall import exceptions
 from neutron.agent.linux.openvswitch_firewall import iptables
 from neutron.agent.linux.openvswitch_firewall import rules
+from neutron.common import utils as n_utils
 
 LOG = logging.getLogger(__name__)
 CONJ_ID_REGEX = re.compile(r"conj_id=(\d+),")
@@ -170,7 +171,7 @@ class OFPort(object):
         self.lla_address = str(netutils.get_ipv6_addr_by_EUI64(
             lib_const.IPv6_LLA_PREFIX, self.mac))
         self.ofport = ovs_port.ofport
-        self.sec_groups = list()
+        self.sec_groups = []
         self.fixed_ips = port_dict.get('fixed_ips', [])
         self.neutron_port_dict = port_dict.copy()
         self.allowed_pairs_v4 = self._get_allowed_pairs(port_dict, version=4)
@@ -306,7 +307,7 @@ class ConjIdMap(object):
                   for table in ovs_consts.OVS_FIREWALL_TABLES])
             conj_ids = CONJ_ID_REGEX.findall(" | ".join(flows_iter))
             try:
-                conj_id_max = max([int(conj_id) for conj_id in conj_ids])
+                conj_id_max = max(int(conj_id) for conj_id in conj_ids)
             except ValueError:
                 conj_id_max = 0
 
@@ -543,7 +544,8 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                                    applied
 
         """
-        self.permitted_ethertypes = cfg.CONF.SECURITYGROUP.permitted_ethertypes
+        self.permitted_ethertypes = n_utils.parse_permitted_ethertypes(
+            cfg.CONF.SECURITYGROUP.permitted_ethertypes)
         self.int_br = self.initialize_bridge(integration_bridge)
         self._initialize_sg()
         self._update_cookie = None
@@ -644,14 +646,6 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                     'resubmit(,%d)' % ovs_consts.BASE_EGRESS_TABLE,
         )
 
-        if cfg.CONF.AGENT.explicitly_egress_direct:
-            self._add_flow(
-                table=ovs_consts.TRANSIENT_TABLE,
-                priority=2,
-                actions='resubmit(,%d)' % (
-                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE)
-            )
-
     def _initialize_third_party_tables(self):
         self.int_br.br.add_flow(
             table=ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE,
@@ -1186,24 +1180,14 @@ class OVSFirewallDriver(firewall.FirewallDriver):
 
         # Allow custom ethertypes
         for permitted_ethertype in self.permitted_ethertypes:
-            if permitted_ethertype[:2] == '0x':
-                try:
-                    hex_ethertype = hex(int(permitted_ethertype, base=16))
-                    action = ('resubmit(,%d)' %
-                              ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE)
-                    self._add_flow(
-                        table=ovs_consts.BASE_EGRESS_TABLE,
-                        priority=95,
-                        dl_type=hex_ethertype,
-                        reg_port=port.ofport,
-                        actions=action
-                    )
-                    continue
-                except ValueError:
-                    pass
-            LOG.warning("Custom ethertype %(permitted_ethertype)s is not "
-                        "a hexadecimal number.",
-                        {'permitted_ethertype': permitted_ethertype})
+            action = ('resubmit(,%d)' %
+                      ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE)
+            self._add_flow(
+                table=ovs_consts.BASE_EGRESS_TABLE,
+                priority=95,
+                dl_type=permitted_ethertype,
+                reg_port=port.ofport,
+                actions=action)
 
         # Drop all remaining egress connections
         self._add_flow(
@@ -1261,7 +1245,6 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             return
 
         # Prevent flood for accepted egress traffic
-        # For packets from internal ports or VM ports.
         self._add_flow(
             flow_group_id=dst_port,
             table=ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE,
@@ -1270,15 +1253,6 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             reg_net=vlan_tag,
             actions='output:{:d}'.format(dst_port)
         )
-        # For packets from patch ports.
-        self._add_flow(
-            flow_group_id=dst_port,
-            table=ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE,
-            priority=12,
-            dl_dst=mac,
-            dl_vlan=vlan_tag,
-            actions='strip_vlan,output:{:d}'.format(dst_port)
-        )
 
         # The former flow may not match, that means the destination port is
         # not in this host. So, we direct the packet to mapped bridge(s).
@@ -1327,12 +1301,6 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             dl_src=mac,
             reg_net=vlan_tag)
 
-        self._delete_flows(
-            table=ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE,
-            dl_dst=mac,
-            dl_vlan=vlan_tag
-        )
-
     def _initialize_tracked_egress(self, port):
         # Drop invalid packets
         self._add_flow(
@@ -1414,22 +1382,12 @@ class OVSFirewallDriver(firewall.FirewallDriver):
 
         # Allow custom ethertypes
         for permitted_ethertype in self.permitted_ethertypes:
-            if permitted_ethertype[:2] == '0x':
-                try:
-                    hex_ethertype = hex(int(permitted_ethertype, base=16))
-                    self._add_flow(
-                        table=ovs_consts.BASE_INGRESS_TABLE,
-                        priority=100,
-                        dl_type=hex_ethertype,
-                        reg_port=port.ofport,
-                        actions='output:{:d}'.format(port.ofport)
-                    )
-                    continue
-                except ValueError:
-                    pass
-            LOG.warning('Custom ethertype %(permitted_ethertype)s is not '
-                        'a hexadecimal number.',
-                        {'permitted_ethertype': permitted_ethertype})
+            self._add_flow(
+                table=ovs_consts.BASE_INGRESS_TABLE,
+                priority=100,
+                dl_type=permitted_ethertype,
+                reg_port=port.ofport,
+                actions='output:{:d}'.format(port.ofport))
 
         self._initialize_ingress_ipv6_icmp(port)
 
