@@ -48,8 +48,7 @@ CHASSIS_METADATA_LOCK = 'chassis_metadata_lock'
 
 NS_PREFIX = 'ovnmeta-'
 MAC_PATTERN = re.compile(r'([0-9A-F]{2}[:-]){5}([0-9A-F]{2})', re.I)
-OVN_VIF_PORT_TYPES = (
-    "", ovn_const.LSP_TYPE_EXTERNAL, ovn_const.LSP_TYPE_LOCALPORT)
+OVN_VIF_PORT_TYPES = ("", "external", ovn_const.LSP_TYPE_LOCALPORT, )
 
 MetadataPortInfo = collections.namedtuple('MetadataPortInfo', ['mac',
                                                                'ip_addresses',
@@ -75,32 +74,40 @@ class ConfigException(Exception):
     """
 
 
-class PortBindingEvent(row_event.RowEvent):
-    def __init__(self, metadata_agent):
+class PortBindingChassisEvent(row_event.RowEvent):
+    def __init__(self, metadata_agent, events):
         self.agent = metadata_agent
         table = 'Port_Binding'
-        super().__init__((self.__class__.EVENT,), table, None)
+        super(PortBindingChassisEvent, self).__init__(
+            events, table, None)
         self.event_name = self.__class__.__name__
-        self._log_msg = (
-            "PortBindingEvent matched for logical port %s and network %s")
-
-    def log_row(self, row):
-        net_name = ovn_utils.get_network_name_from_datapath(
-            row.datapath)
-        LOG.info(self._log_msg, row.logical_port, net_name)
-
-    def match_fn(self, event, row, old):
-        return row.type in OVN_VIF_PORT_TYPES
 
     def run(self, event, row, old):
         # Check if the port has been bound/unbound to our chassis and update
         # the metadata namespace accordingly.
         resync = False
-
+        if row.type not in OVN_VIF_PORT_TYPES:
+            return
+        if row.type == ovn_const.LSP_TYPE_LOCALPORT:
+            new_ext_ids = row.external_ids
+            old_ext_ids = old.external_ids
+            device_id = row.external_ids.get(
+                ovn_const.OVN_DEVID_EXT_ID_KEY, "")
+            if not device_id.startswith(NS_PREFIX):
+                return
+            new_cidrs = new_ext_ids.get(ovn_const.OVN_CIDRS_EXT_ID_KEY, "")
+            old_cidrs = old_ext_ids.get(ovn_const.OVN_CIDRS_EXT_ID_KEY, "")
+            # If old_cidrs is "", it is create event,
+            # nothing needs to be done.
+            # If old_cidrs equals new_cidrs, the ip does not change.
+            if old_cidrs in ("", new_cidrs, ):
+                return
         with _SYNC_STATE_LOCK.read_lock():
-            self.log_row(row)
             try:
-                self.agent.provision_datapath(row)
+                net_name = ovn_utils.get_network_name_from_datapath(
+                    row.datapath)
+                LOG.info(self.LOG_MSG, row.logical_port, net_name)
+                self.agent.provision_datapath(row.datapath)
             except ConfigException:
                 # We're now in the reader lock mode, we need to exit the
                 # context and then use writer lock
@@ -109,94 +116,63 @@ class PortBindingEvent(row_event.RowEvent):
             self.agent.resync()
 
 
-class PortBindingCreateWithChassis(PortBindingEvent):
-    EVENT = PortBindingEvent.ROW_CREATE
+class PortBindingMetaPortUpdatedEvent(PortBindingChassisEvent):
+    LOG_MSG = "Metadata Port %s in datapath %s updated."
+
+    def __init__(self, metadata_agent):
+        events = (self.ROW_UPDATE,)
+        super(PortBindingMetaPortUpdatedEvent, self).__init__(
+            metadata_agent, events)
 
     def match_fn(self, event, row, old):
-        self._log_msg = "Port %s in datapath %s bound to our chassis on insert"
-        if not (super().match_fn(event, row, old) and row.chassis):
-            return False
-        return row.chassis[0].name == self.agent.chassis
-
-
-class PortBindingUpdatedEvent(PortBindingEvent):
-    EVENT = PortBindingEvent.ROW_UPDATE
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self._match_checks = [
-            self._is_localport_ext_ids_update,
-            self._is_new_chassis_set,
-            self._is_chassis_removed,
-        ]
-
-    def match_fn(self, event, row, old):
-        if not super().match_fn(event, row, old):
-            return False
-        # if any of the check functions is true, the event should be triggered
-        return any(check(row, old) for check in self._match_checks)
-
-    def _is_localport_ext_ids_update(self, row, old):
-        if row.type != ovn_const.LSP_TYPE_LOCALPORT:
-            return False
-
-        if not hasattr(old, 'external_ids'):
-            return False
-
-        device_id = row.external_ids.get(
-            ovn_const.OVN_DEVID_EXT_ID_KEY, "")
-        if not device_id.startswith(NS_PREFIX):
-            return False
-
-        new_cidrs = row.external_ids.get(
-            ovn_const.OVN_CIDRS_EXT_ID_KEY, "")
-        old_cidrs = old.external_ids.get(
-            ovn_const.OVN_CIDRS_EXT_ID_KEY, "")
-        # If old_cidrs is "", it is create event,
-        # nothing needs to be done.
-        # If old_cidrs equals new_cidrs, the ip does not change.
-        if old_cidrs not in ("", new_cidrs):
-            self._log_msg = (
-                "Metadata Port %s in datapath %s updated")
-            return True
+        if row.type == ovn_const.LSP_TYPE_LOCALPORT:
+            if hasattr(row, 'external_ids') and hasattr(old, 'external_ids'):
+                device_id = row.external_ids.get(
+                    ovn_const.OVN_DEVID_EXT_ID_KEY, "")
+                if device_id.startswith(NS_PREFIX):
+                    return True
         return False
 
-    def _is_new_chassis_set(self, row, old):
-        self._log_msg = "Port %s in datapath %s bound to our chassis"
+
+class PortBindingChassisCreatedEvent(PortBindingChassisEvent):
+    LOG_MSG = "Port %s in datapath %s bound to our chassis"
+
+    def __init__(self, metadata_agent):
+        events = (self.ROW_UPDATE,)
+        super(PortBindingChassisCreatedEvent, self).__init__(
+            metadata_agent, events)
+
+    def match_fn(self, event, row, old):
         try:
             return (row.chassis[0].name == self.agent.chassis and
                     not old.chassis)
         except (IndexError, AttributeError):
             return False
 
-    def _is_chassis_removed(self, row, old):
-        self._log_msg = "Port %s in datapath %s unbound from our chassis"
-        try:
-            return (old.chassis[0].name == self.agent.chassis and
-                    not row.chassis)
-        except (IndexError, AttributeError):
-            return False
 
+class PortBindingChassisDeletedEvent(PortBindingChassisEvent):
+    LOG_MSG = "Port %s in datapath %s unbound from our chassis"
 
-class PortBindingDeletedEvent(PortBindingEvent):
-    EVENT = PortBindingEvent.ROW_DELETE
+    def __init__(self, metadata_agent):
+        events = (self.ROW_UPDATE, self.ROW_DELETE)
+        super(PortBindingChassisDeletedEvent, self).__init__(
+            metadata_agent, events)
 
     def match_fn(self, event, row, old):
-        if not super().match_fn(event, row, old):
-            return False
         try:
-            if row.chassis[0].name != self.agent.chassis:
-                return False
+            if event == self.ROW_UPDATE:
+                return (old.chassis[0].name == self.agent.chassis and
+                        not row.chassis)
+            else:
+                if row.chassis[0].name == self.agent.chassis:
+                    if row.type != "external":
+                        LOG.warning(
+                            'Removing non-external type port %(port_id)s with '
+                            'type "%(type)s"',
+                            {"port_id": row.uuid, "type": row.type})
+                    return True
         except (IndexError, AttributeError):
             return False
-        if row.type != ovn_const.LSP_TYPE_EXTERNAL:
-            LOG.warning(
-                'Removing non-external type port %(port_id)s with '
-                'type "%(type)s"',
-                {"port_id": row.uuid, "type": row.type})
-        self._log_msg = (
-            "Port %s in datapath %s unbound from our chassis")
-        return True
 
 
 class ChassisCreateEventBase(row_event.RowEvent):
@@ -309,25 +285,6 @@ class MetadataAgent(object):
         LOG.debug("Loaded chassis name %s (UUID: %s) and ovn bridge %s.",
                   self.chassis, self.chassis_id, self.ovn_bridge)
 
-    def _update_chassis_config(self):
-        """Update the Chassis register information
-
-        This method should be called once the Metadata Agent has been
-        registered (method ``register_metadata_agent`` has been called) and
-        the corresponding Chasis or Chassis_Private register has been
-        created/updated. The Chassis table is used in an event when OVN does
-        not have the Chassis_Private.
-        """
-        external_ids = {ovn_const.OVN_AGENT_OVN_BRIDGE: self.ovn_bridge}
-        if self.has_chassis_private:
-            self.sb_idl.db_set(
-                'Chassis_Private', self.chassis,
-                ('external_ids', external_ids)).execute(check_error=True)
-        else:
-            self.sb_idl.db_set(
-                'Chassis', self.chassis,
-                ('external_ids', external_ids)).execute(check_error=True)
-
     @_sync_lock
     def resync(self):
         """Resync the agent.
@@ -335,7 +292,6 @@ class MetadataAgent(object):
         Reload the configuration and sync the agent again.
         """
         self._load_config()
-        self._update_chassis_config()
         self.sync()
 
     def start(self):
@@ -345,11 +301,10 @@ class MetadataAgent(object):
 
         tables = ('Encap', 'Port_Binding', 'Datapath_Binding', 'SB_Global',
                   'Chassis')
-        events = (PortBindingUpdatedEvent(self),
-                  PortBindingCreateWithChassis(self),
-                  PortBindingDeletedEvent(self),
+        events = (PortBindingChassisCreatedEvent(self),
+                  PortBindingChassisDeletedEvent(self),
                   SbGlobalUpdateEvent(self),
-                  )
+                  PortBindingMetaPortUpdatedEvent(self))
 
         # TODO(lucasagomes): Remove this in the future. Try to register
         # the Chassis_Private table, if not present, fallback to the normal
@@ -376,12 +331,10 @@ class MetadataAgent(object):
         self._proxy.run()
 
         # Do the initial sync.
-        # Provisioning handled by PortBindingCreateWithChassis
-        self.sync(provision=False)
+        self.sync()
 
         # Register the agent with its corresponding Chassis
         self.register_metadata_agent()
-        self._update_chassis_config()
 
         self._proxy.wait()
 
@@ -421,15 +374,15 @@ class MetadataAgent(object):
                         "br-int instead.")
             return 'br-int'
 
-    def get_networks_port_bindings(self):
-        """Return a set of Port_Binding objects of the VIF ports on the current
+    def get_networks_datapaths(self):
+        """Return a set of datapath objects of the VIF ports on the current
         chassis.
         """
         ports = self.sb_idl.get_ports_on_chassis(self.chassis)
-        return list(self._vif_ports(ports))
+        return set(p.datapath for p in self._vif_ports(ports))
 
     @_sync_lock
-    def sync(self, provision=True):
+    def sync(self):
         """Agent sync.
 
         This function will make sure that all networks with ports in our
@@ -441,27 +394,23 @@ class MetadataAgent(object):
         system_namespaces = tuple(
             ns.decode('utf-8') if isinstance(ns, bytes) else ns
             for ns in ip_lib.list_network_namespaces())
-        net_port_bindings = self.get_networks_port_bindings()
-        metadata_namespaces = set(
+        net_datapaths = self.get_networks_datapaths()
+        metadata_namespaces = [
             self._get_namespace_name(
                 ovn_utils.get_network_name_from_datapath(datapath))
-            for datapath in (pb.datapath for pb in net_port_bindings)
-        )
+            for datapath in net_datapaths
+        ]
         unused_namespaces = [ns for ns in system_namespaces if
                              ns.startswith(NS_PREFIX) and
                              ns not in metadata_namespaces]
         for ns in unused_namespaces:
-            try:
-                self.teardown_datapath(self._get_datapath_name(ns))
-            except Exception:
-                LOG.exception('Error unable to destroy namespace: %s', ns)
+            self.teardown_datapath(self._get_datapath_name(ns))
 
         # resync all network namespaces based on the associated datapaths,
         # even those that are already running. This is to make sure
         # everything within each namespace is up to date.
-        if provision:
-            for port_binding in net_port_bindings:
-                self.provision_datapath(port_binding)
+        for datapath in net_datapaths:
+            self.provision_datapath(datapath)
 
     @staticmethod
     def _get_veth_name(datapath):
@@ -632,7 +581,7 @@ class MetadataAgent(object):
 
         return net_name, datapath_ports_ips, metadata_port_info
 
-    def provision_datapath(self, port_binding):
+    def provision_datapath(self, datapath):
         """Provision the datapath so that it can serve metadata.
 
         This function will create the namespace and VETH pair if needed
@@ -640,13 +589,11 @@ class MetadataAgent(object):
         metadata port of the network. It will also remove existing IP from
         the namespace if they are no longer needed.
 
-        :param port_binding: Port_Binding object.
-        :return: The metadata namespace name for the Port_Binding.datapath or
-                 None if namespace was not provisioned
+        :param datapath: datapath object.
+        :return: The metadata namespace name for the datapath or None
+                 if namespace was not provisioned
         """
-        datapath = port_binding.datapath
-        mtu = int(port_binding.external_ids.get(
-            ovn_const.OVN_NETWORK_MTU_EXT_ID_KEY) or '0')
+
         provision_params = self._get_provision_params(datapath)
         if not provision_params:
             return
@@ -672,18 +619,13 @@ class MetadataAgent(object):
             ip1, ip2 = ip_lib.IPWrapper().add_veth(
                 veth_name[0], veth_name[1], namespace)
 
-        # Configure the MAC address.
-        ip2.link.set_address(metadata_port_info.mac)
-
-        # Set VETH ports MTU.
-        if mtu:
-            ip1.link.set_mtu(mtu)
-            ip2.link.set_mtu(mtu)
-
         # Make sure both ends of the VETH are up
         ip1.link.set_up()
         ip2.link.set_up()
 
+        # Configure the MAC address.
+        ip2.link.set_address(metadata_port_info.mac)
+
         cidrs_to_add, cidrs_to_delete = self._process_cidrs(
             {dev['cidr'] for dev in ip2.addr.list()},
             datapath_ports_ips,
