@@ -21,7 +21,6 @@ from oslo_log import log as logging
 import webob.dec
 import webob.exc
 
-from neutron._i18n import _LE, _LI
 from neutron.api import api_common
 from neutron.common import utils
 from neutron import wsgi
@@ -89,22 +88,27 @@ def Resource(controller, faults=None, deserializers=None, serializers=None,
             if fmt is not None and fmt not in format_types:
                 args['id'] = '.'.join([args['id'], fmt])
 
+            revision_number = api_common.check_request_for_revision_constraint(
+                request)
+            if revision_number is not None:
+                request.context.set_transaction_constraint(
+                    controller._collection, args['id'], revision_number)
+
             method = getattr(controller, action)
             result = method(request=request, **args)
         except Exception as e:
             mapped_exc = api_common.convert_exception_to_http_exc(e, faults,
                                                                   language)
             if hasattr(mapped_exc, 'code') and 400 <= mapped_exc.code < 500:
-                LOG.info(_LI('%(action)s failed (client error): %(exc)s'),
+                LOG.info('%(action)s failed (client error): %(exc)s',
                          {'action': action, 'exc': mapped_exc})
             else:
-                LOG.exception(
-                    _LE('%(action)s failed: %(details)s'),
-                    {
-                        'action': action,
-                        'details': utils.extract_exc_details(e),
-                    }
-                )
+                LOG.exception('%(action)s failed: %(details)s',
+                              {
+                                  'action': action,
+                                  'details': utils.extract_exc_details(e),
+                              }
+                              )
             raise mapped_exc
 
         status = action_status.get(action, 200)
