@@ -15,6 +15,7 @@
 from neutron_lib.api import converters
 from neutron_lib import constants
 from neutron_lib import context
+from neutron_lib.db import api as db_api
 from neutron_lib.db import model_query
 from oslo_config import cfg
 from oslo_serialization import jsonutils
@@ -32,6 +33,7 @@ from neutron.db.extra_dhcp_opt import models as extra_dhcp_opt_models
 from neutron.db.models import agent as agent_model
 from neutron.db.models import external_net
 from neutron.db.models import l3 as l3_models
+from neutron.db.models import l3ha as l3ha_models
 from neutron.db.models.plugins.ml2 import vlanallocation
 from neutron.db.models import segment
 from neutron.db import models_v2
@@ -52,10 +54,11 @@ def get_agents(agt_type):
     """
     filters = {'agent_type': [agt_type]}
     ctx = context.get_admin_context()
-    query = model_query.get_collection_query(ctx,
-                                             agent_model.Agent,
-                                             filters=filters)
-    return query.all()
+    with db_api.CONTEXT_READER.using(ctx):
+        query = model_query.get_collection_query(ctx,
+                                                 agent_model.Agent,
+                                                 filters=filters)
+        return query.all()
 
 
 def get_extra_dhcp_opts():
@@ -64,10 +67,10 @@ def get_extra_dhcp_opts():
     :return: list of ports' extra_dhcp_option names and values
     """
     ctx = context.get_admin_context()
-    query = model_query.get_collection_query(
-        ctx,
-        extra_dhcp_opt_models.ExtraDhcpOpt)
-    return query.all()
+    with db_api.CONTEXT_READER.using(ctx):
+        query = model_query.get_collection_query(
+            ctx, extra_dhcp_opt_models.ExtraDhcpOpt)
+        return query.all()
 
 
 def get_l3_agents():
@@ -80,75 +83,96 @@ def get_nic_switch_agents():
 
 def get_networks():
     ctx = context.get_admin_context()
-    query = model_query.get_collection_query(ctx,
-                                             models_v2.Network)
-    return query.all()
+    with db_api.CONTEXT_READER.using(ctx):
+        query = model_query.get_collection_query(ctx,
+                                                 models_v2.Network)
+        return query.all()
 
 
 def table_exists(table_name):
     ctx = context.get_admin_context()
-    tables = [t[0] for t in ctx.session.execute("SHOW TABLES;")]
-    return table_name in tables
+    with db_api.CONTEXT_READER.using(ctx):
+        tables = [t[0] for t in ctx.session.execute("SHOW TABLES;")]
+        return table_name in tables
 
 
 def get_ovn_db_revisions():
     ctx = context.get_admin_context()
-    return [row[0] for row in ctx.session.execute(
-        "SELECT version_num from %s;" % OVN_ALEMBIC_TABLE_NAME)]  # nosec
+    with db_api.CONTEXT_READER.using(ctx):
+        return [row[0] for row in ctx.session.execute(
+            "SELECT version_num from %s;" % OVN_ALEMBIC_TABLE_NAME)]  # nosec
 
 
 def count_vlan_allocations_invalid_segmentation_id():
     ctx = context.get_admin_context()
-    query = ctx.session.query(vlanallocation.VlanAllocation)
-    query = query.filter(or_(
-        vlanallocation.VlanAllocation.vlan_id < constants.MIN_VLAN_TAG,
-        vlanallocation.VlanAllocation.vlan_id > constants.MAX_VLAN_TAG))
-    return query.count()
+    with db_api.CONTEXT_READER.using(ctx):
+        query = ctx.session.query(vlanallocation.VlanAllocation)
+        query = query.filter(or_(
+            vlanallocation.VlanAllocation.vlan_id < constants.MIN_VLAN_TAG,
+            vlanallocation.VlanAllocation.vlan_id > constants.MAX_VLAN_TAG))
+        return query.count()
 
 
 def port_mac_addresses():
     ctx = context.get_admin_context()
-    return [port[0] for port in
-            ctx.session.query(models_v2.Port.mac_address).all()]
+    with db_api.CONTEXT_READER.using(ctx):
+        return [port[0] for port in
+                ctx.session.query(models_v2.Port.mac_address).all()]
 
 
 def get_duplicate_network_segment_count():
     ctx = context.get_admin_context()
-    query = ctx.session.query(segment.NetworkSegment.network_id)
-    # for a unique constraint it's always NULL != NULL --> we filter them out
-    query = query.filter(segment.NetworkSegment.physical_network.isnot(None))
-    query = query.group_by(
-        segment.NetworkSegment.network_id,
-        segment.NetworkSegment.network_type,
-        segment.NetworkSegment.physical_network,
-        segment.NetworkSegment.segment_index,
-    )
-    query = query.having(func.count() > 1)
-    return query.count()
+    with db_api.CONTEXT_READER.using(ctx):
+        query = ctx.session.query(segment.NetworkSegment.network_id)
+        # for a unique constraint it's always NULL != NULL --> we filter them
+        # out
+        query = query.filter(
+            segment.NetworkSegment.physical_network.isnot(None))
+        query = query.group_by(
+            segment.NetworkSegment.network_id,
+            segment.NetworkSegment.network_type,
+            segment.NetworkSegment.physical_network,
+            segment.NetworkSegment.segment_index,
+        )
+        query = query.having(func.count() > 1)
+        return query.count()
 
 
 def port_binding_profiles():
     ctx = context.get_admin_context()
-    return [port_binding.profile
-            for port_binding in port_obj.PortBinding.get_objects(ctx)]
+    with db_api.CONTEXT_READER.using(ctx):
+        return [port_binding.profile
+                for port_binding in port_obj.PortBinding.get_objects(ctx)]
 
 
 def get_external_networks_with_qos_policies():
     ctx = context.get_admin_context()
-    query = ctx.session.query(external_net.ExternalNetwork.network_id)
-    query = query.filter(external_net.ExternalNetwork.network_id ==
-                         qos_models.QosNetworkPolicyBinding.network_id)
-    return [network[0] for network in query.all()]
+    with db_api.CONTEXT_READER.using(ctx):
+        query = ctx.session.query(external_net.ExternalNetwork.network_id)
+        query = query.filter(external_net.ExternalNetwork.network_id ==
+                             qos_models.QosNetworkPolicyBinding.network_id)
+        return [network[0] for network in query.all()]
 
 
 def get_fip_per_network_without_qos_policies(network_id):
     ctx = context.get_admin_context()
-    query = ctx.session.query(l3_models.FloatingIP)
-    query = query.filter(and_(
-        ~exists().where(qos_models.QosFIPPolicyBinding.fip_id ==
-                        l3_models.FloatingIP.id),
-        l3_models.FloatingIP.floating_network_id == network_id))
-    return query.count()
+    with db_api.CONTEXT_READER.using(ctx):
+        query = ctx.session.query(l3_models.FloatingIP)
+        query = query.filter(and_(
+            ~exists().where(qos_models.QosFIPPolicyBinding.fip_id ==
+                            l3_models.FloatingIP.id),
+            l3_models.FloatingIP.floating_network_id == network_id))
+        return query.count()
+
+
+def get_duplicated_ha_networks_per_project():
+    """Return those HA network reg. that have more than 1 entry per project"""
+    ctx = context.get_admin_context()
+    with db_api.CONTEXT_READER.using(ctx):
+        query = ctx.session.query(l3ha_models.L3HARouterNetwork)
+        query = query.group_by(l3ha_models.L3HARouterNetwork.project_id)
+        query = query.having(func.count() > 1)
+        return query.all()
 
 
 class CoreChecks(base.BaseChecks):
@@ -179,6 +203,8 @@ class CoreChecks(base.BaseChecks):
              self.floatingip_inherit_qos_from_network),
             (_('Port extra DHCP options check'),
              self.extra_dhcp_options_check),
+            (_('Duplicated HA network per project check'),
+             self.extra_dhcp_options_check),
         ]
 
     @staticmethod
@@ -515,3 +541,32 @@ class CoreChecks(base.BaseChecks):
             upgradecheck.Code.SUCCESS,
             _('There are no extra_dhcp_opts with the newline character '
               'in the option name or option value.'))
+
+    @staticmethod
+    def duplicated_ha_network_per_project_check(checker):
+        """Check if there are duplicated HA networks per project
+
+        By definition there could be zero or one HA network per project. In
+        case of having more than one register associated to any existing
+        project (that should never happen), this check will fail.
+        """
+        if not cfg.CONF.database.connection:
+            return upgradecheck.Result(
+                upgradecheck.Code.WARNING,
+                _("Database connection string is not set. Check for "
+                  "extra_dhcp_opts can't be done."))
+
+        ha_networks = get_duplicated_ha_networks_per_project()
+        project_ids = {ha_network['project_id'] for ha_network in ha_networks}
+        network_ids = {ha_network['network_id'] for ha_network in ha_networks}
+        if project_ids:
+            return upgradecheck.Result(
+                upgradecheck.Code.WARNING,
+                _('The following projects have duplicated HA networks: '
+                  '%(project_ids)s. This is the list of duplicated HA '
+                  'networks: %(network_ids)s' %
+                  {'project_ids': project_ids, 'network_ids': network_ids}))
+
+        return upgradecheck.Result(
+            upgradecheck.Code.SUCCESS,
+            _('There are no duplicated HA networks in the system.'))
