@@ -32,8 +32,8 @@ OVN_ROUTER_NAME_EXT_ID_KEY = 'neutron:router_name'
 OVN_ROUTER_ID_EXT_ID_KEY = 'neutron:router_id'
 OVN_AZ_HINTS_EXT_ID_KEY = 'neutron:availability_zone_hints'
 OVN_ROUTER_IS_EXT_GW = 'neutron:is_ext_gw'
-OVN_GW_PORT_EXT_ID_KEY = 'neutron:gw_port_id'
-OVN_GW_NETWORK_EXT_ID_KEY = 'neutron:gw_network_id'
+OVN_GW_PORT_EXT_ID_KEY = 'neutron:gw_port_id'        # DEPRECATED, DON'T USE
+OVN_GW_NETWORK_EXT_ID_KEY = 'neutron:gw_network_id'  # DEPRECATED, DON'T USE
 OVN_SUBNET_EXT_ID_KEY = 'neutron:subnet_id'
 OVN_SUBNET_EXT_IDS_KEY = 'neutron:subnet_ids'
 OVN_SUBNET_POOL_EXT_ADDR_SCOPE4_KEY = 'neutron:subnet_pool_addr_scope4'
@@ -69,13 +69,6 @@ OVN_ROUTER_PORT_GW_MTU_OPTION = 'gateway_mtu'
 
 OVN_PROVNET_PORT_NAME_PREFIX = 'provnet-'
 OVN_NAME_PREFIX = 'neutron-'
-OVN_HA_CH_GROUP_EXTPORT_PREFIX = 'neutron-extport-'
-
-OVN_DATAPATH_TYPE = 'datapath-type'
-
-# TODO(froyo): Move this to neutron-lib as soon as possible, and when a new
-# release is created and pointed to in the requirements remove this code
-OVN_LB_HM_PORT_DISTRIBUTED = 'ovn-lb-hm:distributed'
 
 # Agent extension constants
 OVN_AGENT_DESC_KEY = 'neutron:description'
@@ -85,7 +78,6 @@ OVN_AGENT_METADATA_ID_KEY = 'neutron:ovn-metadata-id'
 OVN_AGENT_NEUTRON_SB_CFG_KEY = 'neutron:ovn-neutron-agent-sb-cfg'
 OVN_AGENT_NEUTRON_DESC_KEY = 'neutron:description-neutron-agent'
 OVN_AGENT_NEUTRON_ID_KEY = 'neutron:ovn-neutron-agent-id'
-OVN_AGENT_OVN_BRIDGE = 'neutron:ovn-bridge'
 OVN_CONTROLLER_AGENT = 'OVN Controller agent'
 OVN_CONTROLLER_GW_AGENT = 'OVN Controller Gateway agent'
 OVN_METADATA_AGENT = 'OVN Metadata agent'
@@ -216,10 +208,6 @@ OVN_STR_TYPE_DHCP_OPTS = [
     'wpad',
     'tftp_server']
 
-OVN_MAP_TYPE_DHCP_OPTS = [
-    'classless_static_route',
-]
-
 # Special option for disabling DHCP via extra DHCP options
 DHCP_DISABLED_OPT = 'dhcp_disabled'
 
@@ -274,8 +262,6 @@ _TYPES_PRIORITY_ORDER = (
     TYPE_SECURITY_GROUP_RULES)
 
 DB_CONSISTENCY_CHECK_INTERVAL = 300  # 5 minutes
-MAINTENANCE_TASK_RETRY_LIMIT = 100  # times
-MAINTENANCE_ONE_RUN_TASK_SPACING = 5  # seconds
 
 # The order in which the resources should be created or updated by the
 # maintenance task: Root ones first and leafs at the end.
@@ -317,12 +303,6 @@ HASH_RING_ML2_GROUP = 'mechanism_driver'
 # Maximum chassis count where a gateway port can be hosted
 MAX_GW_CHASSIS = 5
 
-# Maximum number of Chassis in a HA Chassis Group. Limiting the number
-# of members because OVN uses BFD to monitor the connectivity of each member
-# in the group. Having an unlimited number of members can potentially
-# put a lot of stress on OVN to monitor it all.
-MAX_CHASSIS_IN_HA_GROUP = 5
-
 UNKNOWN_ADDR = 'unknown'
 
 PORT_CAP_SWITCHDEV = 'switchdev'
@@ -412,6 +392,7 @@ LSP_OPTIONS_REQUESTED_CHASSIS_KEY = 'requested-chassis'
 LSP_OPTIONS_MCAST_FLOOD_REPORTS = 'mcast_flood_reports'
 LSP_OPTIONS_MCAST_FLOOD = 'mcast_flood'
 LSP_OPTIONS_QOS_MIN_RATE = 'qos_min_rate'
+LSP_OPTIONS_LOCALNET_LEARN_FDB = 'localnet_learn_fdb'
 
 LRP_OPTIONS_RESIDE_REDIR_CH = 'reside-on-redirect-chassis'
 LRP_OPTIONS_REDIRECT_TYPE = 'redirect-type'
@@ -436,7 +417,6 @@ EXTERNAL_PORT_TYPES = (portbindings.VNIC_DIRECT,
 NEUTRON_AVAILABILITY_ZONES = 'neutron-availability-zones'
 OVN_CMS_OPTIONS = 'ovn-cms-options'
 CMS_OPT_CHASSIS_AS_GW = 'enable-chassis-as-gw'
-CMS_OPT_CHASSIS_AS_EXTPORT_HOST = 'enable-chassis-as-extport-host'
 CMS_OPT_AVAILABILITY_ZONES = 'availability-zones'
 CMS_OPT_CARD_SERIAL_NUMBER = 'card-serial-number'
 
@@ -456,4 +436,5 @@ OVN_SUPPORTED_VNIC_TYPES = [portbindings.VNIC_NORMAL,
                             portbindings.VNIC_VHOST_VDPA,
                             portbindings.VNIC_REMOTE_MANAGED,
                             portbindings.VNIC_BAREMETAL,
+                            portbindings.VNIC_VIRTIO_FORWARDER,
                             ]
