@@ -35,12 +35,11 @@ from oslo_log import log
 from oslo_serialization import jsonutils
 from oslo_utils import netutils
 from oslo_utils import strutils
-from ovsdbapp.backend.ovs_idl import idlutils
+from ovsdbapp.backend.ovs_idl import rowview
 from ovsdbapp import constants as ovsdbapp_const
 import tenacity
 
 from neutron._i18n import _
-from neutron.common import _constants as n_const
 from neutron.common.ovn import constants
 from neutron.common.ovn import exceptions as ovn_exc
 from neutron.common import utils as common_utils
@@ -62,10 +61,6 @@ PortExtraDHCPValidation = collections.namedtuple(
 BPInfo = collections.namedtuple(
     'BPInfo', ['bp_param', 'vnic_type', 'capabilities'])
 
-HAChassisGroupInfo = collections.namedtuple(
-    'HAChassisGroupInfo', ['group_name', 'chassis_list', 'az_hints',
-                           'ignore_chassis'])
-
 
 class OvsdbClientCommand(object):
     _CONNECTION = 0
@@ -164,11 +159,6 @@ def ovn_provnet_port_name(network_id):
     return constants.OVN_PROVNET_PORT_NAME_PREFIX + '%s' % network_id
 
 
-def ovn_extport_chassis_group_name(port_id):
-    # The name of the HA Chassis Group entry will be neutron-extport-<UUID>
-    return constants.OVN_HA_CH_GROUP_EXTPORT_PREFIX + '%s' % port_id
-
-
 def ovn_vhu_sockpath(sock_dir, port_id):
     # Frame the socket path of a virtio socket
     return os.path.join(
@@ -250,10 +240,6 @@ def is_dhcp_option_quoted(opt_value):
     return opt_value.startswith('"') and opt_value.endswith('"')
 
 
-def is_dhcp_option_a_map(opt_value):
-    return opt_value.startswith('{') and opt_value.endswith('}')
-
-
 def get_lsp_dhcp_opts(port, ip_version):
     # Get dhcp options from Neutron port, for setting DHCP_Options row
     # in OVN.
@@ -292,9 +278,6 @@ def get_lsp_dhcp_opts(port, ip_version):
             if (opt in constants.OVN_STR_TYPE_DHCP_OPTS and
                     not is_dhcp_option_quoted(edo['opt_value'])):
                 edo['opt_value'] = '"%s"' % edo['opt_value']
-            elif (opt in constants.OVN_MAP_TYPE_DHCP_OPTS and
-                  not is_dhcp_option_a_map(edo['opt_value'])):
-                edo['opt_value'] = '{%s}' % edo['opt_value']
             lsp_dhcp_opts[opt] = edo['opt_value']
 
     return (lsp_dhcp_disabled, lsp_dhcp_opts)
@@ -318,33 +301,6 @@ def get_lsp_security_groups(port, skip_trusted_port=True):
                   ) else port.get('security_groups', [])
 
 
-def is_lsp_enabled(lsp):
-    """Return if a Logical Switch Port is enabled
-
-    This method mimics the OVN northd method ``lsp_is_enabled``
-    https://shorturl.at/rBSZ7. The "enabled" field can have three values:
-    * []: from older OVN versions, in this case the LSP is enabled by default.
-    * [True]: the LSP is enabled.
-    * [False]: the LSP is disabled.
-
-    :param lsp: ``ovs.db.Row`` with a Logical Switch Port register.
-    :return: True if the port is enabled, False if not.
-    """
-    return not lsp.enabled or lsp.enabled == [True]
-
-
-def is_lsp_up(lsp):
-    """Return if a Logical Switch Port is UP
-
-    This method mimics the OVN northd method ``lsp_is_up``
-    https://shorturl.at/aoKR6
-
-    :param lsp: ``ovs.db.Row`` with a Logical Switch Port register.
-    :return: True if the port is UP, False if not.
-    """
-    return lsp.up == [True]
-
-
 def is_snat_enabled(router):
     return router.get(l3.EXTERNAL_GW_INFO, {}).get('enable_snat', True)
 
@@ -368,7 +324,7 @@ def validate_and_get_data_from_binding_profile(port):
     if (constants.OVN_PORT_BINDING_PROFILE not in port or
             not validators.is_attr_set(
                 port[constants.OVN_PORT_BINDING_PROFILE])):
-        return BPInfo({}, None, [])
+        BPInfo({}, None, [])
     param_set = {}
     param_dict = {}
     vnic_type = port.get(portbindings.VNIC_TYPE, portbindings.VNIC_NORMAL)
@@ -647,9 +603,9 @@ def ovn_metadata_name(id_):
     return 'metadata-%s' % id_
 
 
-def is_ovn_lb_hm_port(port):
-    return (port['device_owner'] == constants.OVN_LB_HM_PORT_DISTRIBUTED and
-            port['device_id'].startswith('ovn-lb-hm'))
+def is_ovn_metadata_port(port):
+    return (port['device_owner'] == const.DEVICE_OWNER_DISTRIBUTED and
+            port['device_id'].startswith('ovnmeta'))
 
 
 def is_gateway_chassis_invalid(chassis_name, gw_chassis,
@@ -687,15 +643,6 @@ def is_gateway_chassis_invalid(chassis_name, gw_chassis,
 
 
 def is_provider_network(network):
-    """Check if given network is provider network
-    :param network: (str, dict) it can be given as network object or as string
-                    with network ID only. In the latter case, network object
-                    will be loaded from the database
-    """
-    if isinstance(network, str):
-        ctx = n_context.get_admin_context()
-        plugin = directory.get_plugin()
-        network = plugin.get_network(ctx, network)
     return network.get(provider_net.PHYSICAL_NETWORK, False)
 
 
@@ -719,43 +666,11 @@ def get_ovn_cms_options(chassis):
         constants.OVN_CMS_OPTIONS, '').split(',')]
 
 
-def get_ovn_bridge_from_chassis(chassis):
-    """Return the OVN bridge used by the local OVN controller
-
-    This information is stored in the Chassis or Chassis_Private register by
-    the OVN Metadata agent. The default value returned, if not present, is
-    "br-int".
-    NOTE: the default value is not reading the local ``OVS.integration_bridge``
-    configuration knob, that could be different.
-    """
-    return (chassis.external_ids.get(constants.OVN_AGENT_OVN_BRIDGE) or
-            n_const.DEFAULT_BR_INT)
-
-
-def get_datapath_type(hostname, sb_idl):
-    """Return the local OVS integration bridge datapath type
-
-    If the datapath type is not stored in the ``Chassis`` register or
-    the register is still not created, the default value returned is "".
-    """
-    chassis = sb_idl.db_find(
-        'Chassis', ('hostname', '=', hostname)).execute(check_error=True)
-    return (
-        chassis[0].get('other_config', {}).get(constants.OVN_DATAPATH_TYPE, '')
-        if chassis else '')
-
-
 def is_gateway_chassis(chassis):
     """Check if the given chassis is a gateway chassis"""
     return constants.CMS_OPT_CHASSIS_AS_GW in get_ovn_cms_options(chassis)
 
 
-def is_extport_host_chassis(chassis):
-    """Check if the given Chassis is marked to host external ports"""
-    return (constants.CMS_OPT_CHASSIS_AS_EXTPORT_HOST in
-            get_ovn_cms_options(chassis))
-
-
 def get_port_capabilities(port):
     """Return a list of port's capabilities"""
     return port.get(portbindings.PROFILE, {}).get(constants.PORT_CAP_PARAM, [])
@@ -809,7 +724,7 @@ def get_chassis_in_azs(chassis_list, az_list):
     return chassis
 
 
-def get_chassis_without_azs(chassis_list):
+def get_gateway_chassis_without_azs(chassis_list):
     """Return a set of Chassis that does not belong to any AZs.
 
     Filter a list of Chassis and return only the Chassis that does not
@@ -818,7 +733,7 @@ def get_chassis_without_azs(chassis_list):
     :param chassis_list: A list of Chassis objects
     :returns: A set of Chassis names
     """
-    return {ch.name for ch in chassis_list if not
+    return {ch.name for ch in chassis_list if is_gateway_chassis(ch) and not
             get_chassis_availability_zones(ch)}
 
 
@@ -947,152 +862,6 @@ def get_ovn_chassis_other_config(chassis):
         return chassis.external_ids
 
 
-def _get_info_for_ha_chassis_group(context, port_id, network_id, sb_idl):
-    """Get the common required information to create a HA Chassis Group.
-
-    :param context:    Neutron API context
-    :param port_id:    The port ID
-    :param network_id: The network ID
-    :param sb_idl:     OVN SB IDL
-    :returns:          An instance of HAChassisGroupInfo
-    """
-    ignore_chassis = set()
-    # If there are Chassis marked for hosting external ports create a HA
-    # Chassis Group per external port, otherwise do it at the network level
-    chassis_list = sb_idl.get_extport_chassis_from_cms_options()
-    if chassis_list:
-        group_name = ovn_extport_chassis_group_name(port_id)
-        # Check if the port is bound to a chassis and if so, ignore that
-        # chassis when building the HA Chassis Group to ensure the
-        # external port is bound to a different chassis than the VM
-        ignore_chassis = sb_idl.get_chassis_host_for_port(port_id)
-        LOG.debug('HA Chassis Group %s is based on external port %s '
-                  '(network %s)', group_name, port_id, network_id)
-    else:
-        chassis_list = sb_idl.get_gateway_chassis_from_cms_options(
-            name_only=False)
-        group_name = ovn_name(network_id)
-        LOG.debug('HA Chassis Group %s is based on network %s',
-                  group_name, network_id)
-
-    # Get the Availability Zones hints
-    plugin = directory.get_plugin()
-    az_hints = common_utils.get_az_hints(
-        plugin.get_network(context, network_id))
-
-    return HAChassisGroupInfo(
-        group_name=group_name, chassis_list=chassis_list, az_hints=az_hints,
-        ignore_chassis=ignore_chassis)
-
-
-def _filter_candidates_for_ha_chassis_group(hcg_info):
-    """Filter a list of chassis candidates for a given HA Chassis Group.
-
-    Filter a list of chassis candidates for a given HA Chassis Group taking
-    in consideration availability zones if present.
-
-    :param hcg_info: A instance of HAChassisGroupInfo
-    :returns: A list of chassis
-    """
-    if hcg_info.az_hints:
-        candidates = get_chassis_in_azs(hcg_info.chassis_list,
-                                        hcg_info.az_hints)
-        LOG.debug('Taking in consideration the AZs "%s" for HA '
-                  'Chassis Group %s', ','.join(hcg_info.az_hints),
-                  hcg_info.group_name)
-    else:
-        candidates = get_chassis_without_azs(hcg_info.chassis_list)
-
-    # Remove the ignored Chassis, if present
-    if hcg_info.ignore_chassis:
-        LOG.debug('Ignoring chassis %s for HA Chassis Group %s',
-                  ', '.join(hcg_info.ignore_chassis), hcg_info.group_name)
-        candidates = candidates - hcg_info.ignore_chassis
-
-    return candidates
-
-
-def sync_ha_chassis_group(context, port_id, network_id, nb_idl, sb_idl, txn):
-    """Return the UUID of the HA Chassis Group or the HA Chassis Group cmd.
-
-    Given the Neutron Network ID, this method will return (or create
-    and then return) the appropriate HA Chassis Group the external
-    port (in that network) needs to be associated with.
-
-    :param context: Neutron API context
-    :param port_id: The port ID
-    :param network_id: The network ID
-    :param nb_idl: OVN NB IDL
-    :param sb_idl: OVN SB IDL
-    :param txn: The ovsdbapp transaction object
-    :returns: The HA Chassis Group UUID or the HA Chassis Group command object
-    """
-    # If there are Chassis marked for hosting external ports create a HA
-    # Chassis Group per external port, otherwise do it at the network level
-    hcg_info = _get_info_for_ha_chassis_group(context, port_id, network_id,
-                                              sb_idl)
-    candidates = _filter_candidates_for_ha_chassis_group(hcg_info)
-
-    # Try to get the HA Chassis Group or create if it doesn't exist
-    ha_ch_grp = ha_ch_grp_cmd = None
-    try:
-        ha_ch_grp = nb_idl.ha_chassis_group_get(
-            hcg_info.group_name).execute(check_error=True)
-    except idlutils.RowNotFound:
-        ext_ids = {constants.OVN_AZ_HINTS_EXT_ID_KEY: ','.join(
-            hcg_info.az_hints)}
-        ha_ch_grp_cmd = txn.add(nb_idl.ha_chassis_group_add(
-            hcg_info.group_name, may_exist=True, external_ids=ext_ids))
-
-    max_chassis_number = constants.MAX_CHASSIS_IN_HA_GROUP
-    priority = constants.HA_CHASSIS_GROUP_HIGHEST_PRIORITY
-
-    # Check if the HA Chassis Group existed before. If so, re-calculate
-    # the canditates in case something changed and keep the highest priority
-    # chassis in the group (if it's an eligible candidate) with the highest
-    # priority to avoid external ports from moving around
-    if ha_ch_grp:
-        # Remove any chassis that no longer belongs to the AZ hints
-        # or is ignored
-        all_ch = {ch.chassis_name for ch in ha_ch_grp.ha_chassis}
-        ch_to_del = all_ch - candidates
-        for ch in ch_to_del:
-            txn.add(nb_idl.ha_chassis_group_del_chassis(
-                hcg_info.group_name, ch, if_exists=True))
-
-        # Find the highest priority chassis in the HA Chassis Group
-        high_prio_ch = max(ha_ch_grp.ha_chassis, key=lambda x: x.priority,
-                           default=None)
-        if (high_prio_ch and
-                high_prio_ch.chassis_name in candidates):
-            # If found, keep it as the highest priority chassis in the group
-            txn.add(nb_idl.ha_chassis_group_add_chassis(
-                hcg_info.group_name, high_prio_ch.chassis_name,
-                priority=priority))
-            candidates.remove(high_prio_ch.chassis_name)
-            priority -= 1
-            max_chassis_number -= 1
-            LOG.debug('Keeping chassis %s as the highest priority chassis '
-                      'for HA Chassis Group %s', high_prio_ch.chassis_name,
-                      hcg_info.group_name)
-
-    # random.sample() second parameter needs to be <= the list size,
-    # that's why we need to check for the max value here
-    max_chassis_number = min(max_chassis_number, len(candidates))
-    # Limit the number of members and randomize the order so each group,
-    # even if they belonging to the same availability zones do not
-    # necessarily end up with the same Chassis as the highest priority one.
-    for ch in random.sample(list(candidates), max_chassis_number):
-        txn.add(nb_idl.ha_chassis_group_add_chassis(
-            hcg_info.group_name, ch, priority=priority))
-        priority -= 1
-
-    LOG.info('HA Chassis Group %s synchronized', hcg_info.group_name)
-    # Return the existing register UUID or the HA chassis group creation
-    # command (see ovsdbapp ``HAChassisGroupAddChassisCommand`` class).
-    return ha_ch_grp.uuid if ha_ch_grp else ha_ch_grp_cmd
-
-
 def get_subnets_address_scopes(context, subnets, fixed_ips, ml2_plugin):
     """Returns the IPv4 and IPv6 address scopes of several subnets.
 
@@ -1135,6 +904,79 @@ def get_subnets_address_scopes(context, subnets, fixed_ips, ml2_plugin):
     return address4_scope_id, address6_scope_id
 
 
+def sync_ha_chassis_group(context, network_id, nb_idl, sb_idl, txn):
+    """Return the UUID of the HA Chassis Group or the HA Chassis Group cmd.
+
+    Given the Neutron Network ID, this method will return (or create
+    and then return) the appropriate HA Chassis Group the external
+    port (in that network) needs to be associated with.
+
+    :param context: Neutron API context.
+    :param network_id: The Neutron network ID.
+    :param nb_idl: OVN NB IDL
+    :param sb_idl: OVN SB IDL
+    :param txn: The ovsdbapp transaction object.
+    :returns: The HA Chassis Group UUID or the HA Chassis Group command object.
+    """
+    plugin = directory.get_plugin()
+    az_hints = common_utils.get_az_hints(
+        plugin.get_network(context, network_id))
+
+    ha_ch_grp_name = ovn_name(network_id)
+    ext_ids = {constants.OVN_AZ_HINTS_EXT_ID_KEY: ','.join(az_hints)}
+    hcg_cmd = txn.add(nb_idl.ha_chassis_group_add(
+        ha_ch_grp_name, may_exist=True, external_ids=ext_ids))
+
+    if isinstance(hcg_cmd.result, rowview.RowView):
+        # The HA chassis group existed before this transaction.
+        ha_ch_grp = hcg_cmd.result
+    else:
+        # The HA chassis group is being created in this transaction.
+        ha_ch_grp = None
+
+    # Get the chassis belonging to the AZ hints
+    ch_list = sb_idl.get_gateway_chassis_from_cms_options(name_only=False)
+    if not az_hints:
+        az_chassis = get_gateway_chassis_without_azs(ch_list)
+    else:
+        az_chassis = get_chassis_in_azs(ch_list, az_hints)
+
+    priority = constants.HA_CHASSIS_GROUP_HIGHEST_PRIORITY
+    if ha_ch_grp:
+        # Remove any chassis that no longer belongs to the AZ hints
+        all_ch = {ch.chassis_name for ch in ha_ch_grp.ha_chassis}
+        ch_to_del = all_ch - az_chassis
+        for ch in ch_to_del:
+            txn.add(nb_idl.ha_chassis_group_del_chassis(
+                ha_ch_grp_name, ch, if_exists=True))
+
+        # Find the highest priority chassis in the HA Chassis Group. If
+        # it exists and still belongs to the same AZ, keep it as the
+        # highest priority in the group to avoid ports already bond to it
+        # from moving to another chassis.
+        high_prio_ch = max(ha_ch_grp.ha_chassis, key=lambda x: x.priority,
+                           default=None)
+        priority = constants.HA_CHASSIS_GROUP_HIGHEST_PRIORITY
+        if high_prio_ch and high_prio_ch.chassis_name in az_chassis:
+            txn.add(nb_idl.ha_chassis_group_add_chassis(
+                ha_ch_grp_name, high_prio_ch.chassis_name,
+                priority=priority))
+            az_chassis.remove(high_prio_ch.chassis_name)
+            priority -= 1
+
+    # Randomize the order so that networks belonging to the same
+    # availability zones do not necessarily end up with the same
+    # Chassis as the highest priority one.
+    for ch in random.sample(list(az_chassis), len(az_chassis)):
+        txn.add(nb_idl.ha_chassis_group_add_chassis(
+            hcg_cmd, ch, priority=priority))
+        priority -= 1
+
+    # Return the existing register UUID or the HA chassis group creation
+    # command (see ovsdbapp ``HAChassisGroupAddChassisCommand`` class).
+    return ha_ch_grp.uuid if ha_ch_grp else hcg_cmd
+
+
 def get_port_type_virtual_and_parents(subnets, fixed_ips, network_id, port_id,
                                       nb_idl):
     """Returns if a port is type virtual and its corresponding parents.
@@ -1248,30 +1090,3 @@ def get_requested_chassis(requested_chassis):
     if isinstance(requested_chassis, str):
         return requested_chassis.split(',')
     return []
-
-
-# TODO(lucasagomes): Remove this function when the additional_chassis column
-# becomes the norm and older versions of OVN are no longer supported
-def is_additional_chassis_supported(idl):
-    return idl.is_col_present('Port_Binding', 'additional_chassis')
-
-
-def validate_port_forwarding_configuration():
-    if not ovn_conf.is_ovn_distributed_floating_ip():
-        return
-
-    pf_plugin_names = [
-        'port_forwarding',
-        'neutron.services.portforwarding.pf_plugin.PortForwardingPlugin']
-    if not any(plugin in pf_plugin_names
-               for plugin in cfg.CONF.service_plugins):
-        return
-
-    provider_network_types = ['vlan', 'flat']
-    if any(net_type in provider_network_types
-           for net_type in cfg.CONF.ml2.tenant_network_types):
-        raise ovn_exc.InvalidPortForwardingConfiguration()
-
-
-def is_nat_gateway_port_supported(idl):
-    return idl.is_col_present('NAT', 'gateway_port')
