@@ -772,7 +772,7 @@ def attach_exc_details(e, msg, args=_NO_ARGS_MARKER):
 def extract_exc_details(e):
     for attr in ('_error_context_msg', '_error_context_args'):
         if not hasattr(e, attr):
-            return u'No details.'
+            return 'No details.'
     details = e._error_context_msg
     args = e._error_context_args
     if args is _NO_ARGS_MARKER:
@@ -1068,7 +1068,7 @@ def skip_exceptions(exceptions):
                 with excutils.save_and_reraise_exception() as ctx:
                     if issubclass(type(exc), tuple(exceptions)):
                         LOG.info('Skipped exception %s when calling method %s',
-                                 ctx.value.__repr__(), function.__repr__())
+                                 repr(ctx.value), repr(function))
                         ctx.reraise = False
         return wrapper
     return decorator
@@ -1093,6 +1093,26 @@ def sign_instance_id(conf, instance_id):
     return hmac.new(secret, instance_id, hashlib.sha256).hexdigest()
 
 
+def parse_permitted_ethertypes(permitted_ethertypes):
+    ret = set()
+    for pe in permitted_ethertypes:
+        if pe[:2].lower() != '0x':
+            LOG.warning('Custom ethertype %s is not a hexadecimal number.', pe)
+            continue
+
+        try:
+            value = hex(int(pe, 16))
+            if value in ret:
+                LOG.warning('Custom ethertype %s is repeated', pe)
+            else:
+                ret.add(value)
+        except ValueError:
+            LOG.warning('Custom ethertype %s is not a hexadecimal number.', pe)
+            continue
+
+    return ret
+
+
 # TODO(slaweq): this should be moved to neutron_lib.plugins.utils module
 def is_port_bound(port, log_message=True):
     active_binding = plugin_utils.get_port_binding_by_status_and_host(
