@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron_lib.utils import host
 from oslo_config import cfg
 
 from neutron._i18n import _
@@ -22,6 +21,7 @@ USER_MODE = 'user'
 GROUP_MODE = 'group'
 ALL_MODE = 'all'
 SOCKET_MODES = (DEDUCE_MODE, USER_MODE, GROUP_MODE, ALL_MODE)
+RATE_LIMITING_GROUP = 'metadata_rate_limiting'
 
 SHARED_OPTS = [
     cfg.StrOpt('metadata_proxy_socket',
@@ -46,7 +46,6 @@ METADATA_PROXY_HANDLER_OPTS = [
                       "file for ssl")),
     cfg.HostAddressOpt('nova_metadata_host',
                        default='127.0.0.1',
-                       deprecated_name='nova_metadata_ip',
                        help=_("IP address or DNS name of Nova metadata "
                               "server.")),
     cfg.PortOpt('nova_metadata_port',
@@ -58,19 +57,19 @@ METADATA_PROXY_HANDLER_OPTS = [
                       'Instance-ID header with a shared secret to prevent '
                       'spoofing. You may select any string for a secret, '
                       'but it must match here and in the configuration used '
-                      'by the Nova Metadata Server. NOTE: Nova uses the same '
+                      'by the Nova metadata server. NOTE: Nova uses the same '
                       'config key, but in [neutron] section.'),
                secret=True),
     cfg.StrOpt('nova_metadata_protocol',
                default='http',
                choices=['http', 'https'],
-               help=_("Protocol to access nova metadata, http or https")),
+               help=_("Protocol to access Nova metadata, http or https")),
     cfg.BoolOpt('nova_metadata_insecure', default=False,
                 help=_("Allow to perform insecure SSL (https) requests to "
-                       "nova metadata")),
+                       "Nova metadata")),
     cfg.StrOpt('nova_client_cert',
                default='',
-               help=_("Client certificate for nova metadata api server.")),
+               help=_("Client certificate for Nova metadata api server.")),
     cfg.StrOpt('nova_client_priv_key',
                default='',
                help=_("Private key of client certificate."))
@@ -94,9 +93,10 @@ UNIX_DOMAIN_METADATA_PROXY_OPTS = [
                       "'all': set metadata proxy socket mode to 0o666, to use "
                       "otherwise.")),
     cfg.IntOpt('metadata_workers',
-               default=host.cpu_count() // 2,
+               sample_default='<num_of_cpus> / 2',
                help=_('Number of separate worker processes for metadata '
-                      'server (defaults to half of the number of CPUs)')),
+                      'server (defaults to 2 when used with ML2/OVN and half '
+                      'of the number of CPUs with other backend drivers)')),
     cfg.IntOpt('metadata_backlog',
                default=4096,
                help=_('Number of backlog requests to configure the '
@@ -104,5 +104,37 @@ UNIX_DOMAIN_METADATA_PROXY_OPTS = [
 ]
 
 
-def register_meta_conf_opts(opts, cfg=cfg.CONF):
-    cfg.register_opts(opts)
+METADATA_RATE_LIMITING_OPTS = [
+    cfg.BoolOpt('rate_limit_enabled',
+                default=False,
+                help=_('Enable rate limiting on the metadata API.')),
+    cfg.ListOpt('ip_versions',
+                default=['4'],
+                help=_('Comma separated list of the metadata address IP '
+                       'versions (4, 6) for which rate limiting will be '
+                       'enabled. The default is to rate limit only for the '
+                       'metadata IPv4 address. NOTE: at the moment, the open '
+                       'source version of HAProxy only allows us to rate '
+                       'limit for IPv4 or IPv6, but not both at the same '
+                       'time.')),
+    cfg.IntOpt('base_window_duration',
+               default=10,
+               help=_("Duration (seconds) of the base window on the "
+                      "metadata API.")),
+    cfg.IntOpt('base_query_rate_limit',
+               default=10,
+               help=_("Max number of queries to accept during the base "
+                      "window.")),
+    cfg.IntOpt('burst_window_duration',
+               default=10,
+               help=_("Duration (seconds) of the burst window on the "
+                      "metadata API.")),
+    cfg.IntOpt('burst_query_rate_limit',
+               default=10,
+               help=_("Max number of queries to accept during the burst "
+                      "window.")),
+]
+
+
+def register_meta_conf_opts(opts, cfg=cfg.CONF, group=None):
+    cfg.register_opts(opts, group=group)
