@@ -13,12 +13,12 @@
 #    under the License.
 
 from neutron_lib import constants as n_const
+from neutron_lib.plugins.ml2 import ovs_constants
 from oslo_config import cfg
 
 from neutron._i18n import _
 from neutron.conf.agent import common
-from neutron.plugins.ml2.drivers.openvswitch.agent.common \
-    import constants
+from neutron.conf.agent.metadata import config as meta_conf
 
 
 DEFAULT_BRIDGE_MAPPINGS = []
@@ -149,13 +149,14 @@ ovs_opts = [
                        "See also: "
                        "https://docs.openstack.org/api-ref/placement/"
                        "#update-resource-provider-inventories")),
-    cfg.StrOpt('datapath_type', default=constants.OVS_DATAPATH_SYSTEM,
-               choices=[constants.OVS_DATAPATH_SYSTEM,
-                        constants.OVS_DATAPATH_NETDEV],
+    cfg.StrOpt('datapath_type', default=ovs_constants.OVS_DATAPATH_SYSTEM,
+               choices=[ovs_constants.OVS_DATAPATH_SYSTEM,
+                        ovs_constants.OVS_DATAPATH_NETDEV],
                help=_("OVS datapath to use. 'system' is the default value and "
                       "corresponds to the kernel datapath. To enable the "
                       "userspace datapath set this value to 'netdev'.")),
-    cfg.StrOpt('vhostuser_socket_dir', default=constants.VHOST_USER_SOCKET_DIR,
+    cfg.StrOpt('vhostuser_socket_dir',
+               default=ovs_constants.VHOST_USER_SOCKET_DIR,
                help=_("OVS vhost-user socket directory.")),
     cfg.IPOpt('of_listen_address', default='127.0.0.1',
               help=_("Address to listen on for OpenFlow connections.")),
@@ -171,17 +172,26 @@ ovs_opts = [
                help=_("The inactivity_probe interval in seconds for the local "
                       "switch connection to the controller. "
                       "A value of 0 disables inactivity probes.")),
+    cfg.BoolOpt('openflow_processed_per_port',
+                default=False,
+                help=_('If enabled, all OpenFlow rules associated to a port '
+                       'are processed at once, in one single transaction. '
+                       'That avoids possible inconsistencies during OVS agent '
+                       'restart and port updates. '
+                       'If disabled, the flows will be processed in batches '
+                       'of ``_constants.AGENT_RES_PROCESSING_STEP`` number of '
+                       'OpenFlow rules.')),
 ]
 
 agent_opts = [
     cfg.BoolOpt('minimize_polling',
                 default=True,
-                help=_("Minimize polling by monitoring ovsdb for interface "
+                help=_("Minimize polling by monitoring OVSDB for interface "
                        "changes.")),
     cfg.IntOpt('ovsdb_monitor_respawn_interval',
-               default=constants.DEFAULT_OVSDBMON_RESPAWN,
+               default=ovs_constants.DEFAULT_OVSDBMON_RESPAWN,
                help=_("The number of seconds to wait before respawning the "
-                      "ovsdb monitor after losing communication with it.")),
+                      "OVSDB monitor after losing communication with it.")),
     cfg.ListOpt('tunnel_types', default=DEFAULT_TUNNEL_TYPES,
                 help=_("Network types supported by the agent "
                        "(gre, vxlan and/or geneve).")),
@@ -207,7 +217,7 @@ agent_opts = [
                        "in the agent, regardless of the setting in the config "
                        "file.")),
     cfg.BoolOpt('dont_fragment', default=True,
-                help=_("Set or un-set the don't fragment (DF) bit on "
+                help=_("Set or un-set the do not fragment (DF) bit on "
                        "outgoing IP packet carrying GRE/VXLAN tunnel.")),
     cfg.BoolOpt('enable_distributed_routing', default=False,
                 help=_("Make the l2 agent run in DVR mode.")),
@@ -236,12 +246,12 @@ dhcp_opts = [
 
 local_ip_opts = [
     cfg.BoolOpt('static_nat', default=False,
-                help=_("When set to True, the Local IP openvswitch agent "
+                help=_("When set to True, the Local IP Openvswitch agent "
                        "extension will use static NAT rules instead of using "
                        "conntrack. This allows to use feature in OVS offload "
                        "and DPDK scenarios at the cost of number and "
-                       "complexity of flows. This also allows to use feature "
-                       "together with ovs firewall.")),
+                       "complexity of flows. This also allows using this "
+                       "feature together with the OVS firewall.")),
 ]
 
 
@@ -251,6 +261,7 @@ def register_ovs_agent_opts(cfg=cfg.CONF):
     cfg.register_opts(dhcp_opts, "DHCP")
     cfg.register_opts(common.DHCP_PROTOCOL_OPTS, "DHCP")
     cfg.register_opts(local_ip_opts, "LOCAL_IP")
+    cfg.register_opts(meta_conf.METADATA_PROXY_HANDLER_OPTS, "METADATA")
 
 
 def register_ovs_opts(cfg=cfg.CONF):
