@@ -10,13 +10,14 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
+from neutron_lib import policy as neutron_policy
 from oslo_log import versionutils
 from oslo_policy import policy
 
 from neutron.conf.policies import base
 
 DEPRECATED_REASON = (
-    "The segment API now supports system scope and default roles.")
+    "The segment API now supports project scope and default roles.")
 
 COLLECTION_PATH = '/segments'
 RESOURCE_PATH = '/segments/{id}'
@@ -25,8 +26,8 @@ RESOURCE_PATH = '/segments/{id}'
 rules = [
     policy.DocumentedRuleDefault(
         name='create_segment',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description='Create a segment',
         operations=[
             {
@@ -36,14 +37,14 @@ rules = [
         ],
         deprecated_rule=policy.DeprecatedRule(
             name='create_segment',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
     policy.DocumentedRuleDefault(
         name='get_segment',
-        check_str=base.SYSTEM_READER,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description='Get a segment',
         operations=[
             {
@@ -57,14 +58,14 @@ rules = [
         ],
         deprecated_rule=policy.DeprecatedRule(
             name='get_segment',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
     policy.DocumentedRuleDefault(
         name='update_segment',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description='Update a segment',
         operations=[
             {
@@ -74,14 +75,14 @@ rules = [
         ],
         deprecated_rule=policy.DeprecatedRule(
             name='update_segment',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
     policy.DocumentedRuleDefault(
         name='delete_segment',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description='Delete a segment',
         operations=[
             {
@@ -91,7 +92,7 @@ rules = [
         ],
         deprecated_rule=policy.DeprecatedRule(
             name='delete_segment',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
