@@ -10,6 +10,7 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
+from neutron_lib import policy as neutron_policy
 from oslo_log import versionutils
 from oslo_policy import policy
 
@@ -39,15 +40,13 @@ ACTION_GET = [
 rules = [
     policy.DocumentedRuleDefault(
         name='create_subnet',
-        check_str=base.policy_or(
-            base.ADMIN_OR_PROJECT_MEMBER,
-            base.RULE_NET_OWNER),
+        check_str=base.ADMIN_OR_NET_OWNER_MEMBER,
         scope_types=['project'],
         description='Create a subnet',
         operations=ACTION_POST,
         deprecated_rule=policy.DeprecatedRule(
             name='create_subnet',
-            check_str=base.RULE_ADMIN_OR_NET_OWNER,
+            check_str=neutron_policy.RULE_ADMIN_OR_NET_OWNER,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
@@ -61,7 +60,7 @@ rules = [
         operations=ACTION_POST,
         deprecated_rule=policy.DeprecatedRule(
             name='create_subnet:segment_id',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
@@ -75,13 +74,13 @@ rules = [
         operations=ACTION_POST,
         deprecated_rule=policy.DeprecatedRule(
             name='create_subnet:service_types',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
     policy.DocumentedRuleDefault(
         name='get_subnet',
-        check_str=base.policy_or(
+        check_str=neutron_policy.policy_or(
             base.ADMIN_OR_PROJECT_READER,
             'rule:shared'),
         scope_types=['project'],
@@ -89,8 +88,8 @@ rules = [
         operations=ACTION_GET,
         deprecated_rule=policy.DeprecatedRule(
             name='get_subnet',
-            check_str=base.policy_or(
-                base.RULE_ADMIN_OR_OWNER,
+            check_str=neutron_policy.policy_or(
+                neutron_policy.RULE_ADMIN_OR_OWNER,
                 'rule:shared'),
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
@@ -103,21 +102,19 @@ rules = [
         operations=ACTION_GET,
         deprecated_rule=policy.DeprecatedRule(
             name='get_subnet:segment_id',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
     policy.DocumentedRuleDefault(
         name='update_subnet',
-        check_str=base.policy_or(
-            base.ADMIN_OR_PROJECT_MEMBER,
-            base.RULE_NET_OWNER),
+        check_str=base.ADMIN_OR_NET_OWNER_MEMBER,
         scope_types=['project'],
         description='Update a subnet',
         operations=ACTION_PUT,
         deprecated_rule=policy.DeprecatedRule(
             name='update_subnet',
-            check_str=base.RULE_ADMIN_OR_NET_OWNER,
+            check_str=neutron_policy.RULE_ADMIN_OR_NET_OWNER,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
@@ -129,7 +126,7 @@ rules = [
         operations=ACTION_PUT,
         deprecated_rule=policy.DeprecatedRule(
             name='update_subnet:segment_id',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
@@ -141,21 +138,19 @@ rules = [
         operations=ACTION_PUT,
         deprecated_rule=policy.DeprecatedRule(
             name='update_subnet:service_types',
-            check_str=base.RULE_ADMIN_ONLY,
+            check_str=neutron_policy.RULE_ADMIN_ONLY,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
     policy.DocumentedRuleDefault(
         name='delete_subnet',
-        check_str=base.policy_or(
-            base.ADMIN_OR_PROJECT_MEMBER,
-            base.RULE_NET_OWNER),
+        check_str=base.ADMIN_OR_NET_OWNER_MEMBER,
         scope_types=['project'],
         description='Delete a subnet',
         operations=ACTION_DELETE,
         deprecated_rule=policy.DeprecatedRule(
             name='delete_subnet',
-            check_str=base.RULE_ADMIN_OR_NET_OWNER,
+            check_str=neutron_policy.RULE_ADMIN_OR_NET_OWNER,
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
