@@ -51,13 +51,17 @@ from sqlalchemy import not_
 from neutron._i18n import _
 from neutron.api.rpc.agentnotifiers import l3_rpc_agent_api
 from neutron.common import _constants
+from neutron.common import experimental
 from neutron.common import ipv6_utils
 from neutron.common import utils
+from neutron.conf import experimental as c_exp
 from neutron.db import db_base_plugin_common
 from neutron.db import ipam_pluggable_backend
 from neutron.db import models_v2
 from neutron.db import rbac_db_mixin as rbac_mixin
+from neutron.db import rbac_db_models
 from neutron.db import standardattrdescription_db as stattr_db
+from neutron.exceptions import mtu as mtu_exc
 from neutron.extensions import subnetpool_prefix_ops
 from neutron import ipam
 from neutron.ipam import exceptions as ipam_exc
@@ -162,7 +166,17 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             result_filters=None)
         return super(NeutronDbPluginV2, cls).__new__(cls, *args, **kwargs)
 
+    @staticmethod
+    def _validate_ipv6_pd():
+        try:
+            if cfg.CONF.ipv6_pd_enabled:
+                experimental.validate_experimental_enabled(
+                    c_exp.EXPERIMENTAL_IPV6_PD)
+        except cfg.NoSuchOptError:
+            return
+
     def __init__(self):
+        self._validate_ipv6_pd()
         self.set_ipam_backend()
         if (cfg.CONF.notify_nova_on_port_status_changes or
                 cfg.CONF.notify_nova_on_port_data_changes):
@@ -210,7 +224,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         policy = (payload.request_body if event == events.BEFORE_CREATE
                   else payload.latest_state)
 
-        if object_type != 'network' or policy['action'] != 'access_as_shared':
+        if (object_type != 'network' or
+                policy['action'] != rbac_db_models.ACCESS_SHARED):
             # we only care about shared network policies
             return
         # The object a policy targets cannot be changed so we can look
@@ -253,7 +268,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 # any port with another RBAC entry covering it or one belonging
                 # to the same tenant as the network owner is ok
                 other_rbac_objs = network_obj.NetworkRBAC.get_objects(
-                    elevated, object_id=network_id, action='access_as_shared')
+                    elevated, object_id=network_id,
+                    action=rbac_db_models.ACCESS_SHARED)
                 allowed_tenants = [rbac['target_project'] for rbac
                                    in other_rbac_objs
                                    if rbac.target_project != tenant_id]
@@ -265,7 +281,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 # allows any ports
                 if network_obj.NetworkRBAC.get_object(
                         elevated, object_id=network_id,
-                        action='access_as_shared', target_project='*'):
+                        action=rbac_db_models.ACCESS_SHARED,
+                        target_project='*'):
                     return
                 ports = ports.filter(models_v2.Port.project_id == tenant_id)
             if ports.count():
@@ -311,14 +328,15 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
     def _validate_projects_have_access_to_network(self, network, project_ids):
         ctx_admin = ctx.get_admin_context()
         other_rbac_objs = network_obj.NetworkRBAC.get_objects(
-            ctx_admin, object_id=network.id, action='access_as_shared')
+            ctx_admin, object_id=network.id,
+            action=rbac_db_models.ACCESS_SHARED)
         allowed_projects = {rbac['target_project'] for rbac in other_rbac_objs
                             if rbac.target_project != '*'}
         allowed_projects.add(network.project_id)
         if project_ids - allowed_projects:
             raise exc.InvalidSharedSetting(network=network.name)
 
-    def _validate_ipv6_attributes(self, subnet, cur_subnet, has_cidr):
+    def _validate_ipv6_attributes(self, subnet, cur_subnet):
         if cur_subnet:
             self._validate_ipv6_update_dhcp(subnet, cur_subnet)
             return
@@ -330,7 +348,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         if ra_mode_set and address_mode_set:
             self._validate_ipv6_combination(subnet['ipv6_ra_mode'],
                                             subnet['ipv6_address_mode'])
-        if has_cidr and (address_mode_set or ra_mode_set):
+        if address_mode_set or ra_mode_set:
             self._validate_eui64_applicable(subnet)
 
     def _validate_eui64_applicable(self, subnet):
@@ -425,7 +443,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             if n['shared']:
                 np_rbac_args = {'project_id': network.project_id,
                                 'object_id': network.id,
-                                'action': 'access_as_shared',
+                                'action': rbac_db_models.ACCESS_SHARED,
                                 'target_project': '*'}
                 np_rbac_obj = network_obj.NetworkRBAC(context, **np_rbac_args)
                 np_rbac_obj.create()
@@ -443,7 +461,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             if 'shared' in n:
                 entry = None
                 for item in network.rbac_entries:
-                    if (item.action == 'access_as_shared' and
+                    if (item.action == rbac_db_models.ACCESS_SHARED and
                             item.target_project == '*'):
                         entry = item
                         break
@@ -453,7 +471,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 if update_shared and not entry:
                     np_rbac_args = {'project_id': network.project_id,
                                     'object_id': network.id,
-                                    'action': 'access_as_shared',
+                                    'action': rbac_db_models.ACCESS_SHARED,
                                     'target_project': '*'}
                     np_rbac_obj = network_obj.NetworkRBAC(context,
                                                           **np_rbac_args)
@@ -461,7 +479,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 elif not update_shared and entry:
                     network_obj.NetworkRBAC.delete_objects(
                         context, object_id=network.id,
-                        action='access_as_shared', target_project='*')
+                        action=rbac_db_models.ACCESS_SHARED,
+                        target_project='*')
 
                 # TODO(ihrachys) Below can be removed when we make sqlalchemy
                 # event listeners in neutron_lib/db/api.py to refresh expired
@@ -473,6 +492,10 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 # context.
                 getattr(network, 'rbac_entries')
 
+            # validate 'mtu' parameter
+            if 'mtu' in n:
+                self._validate_change_network_mtu(context, id, n['mtu'])
+
             # The filter call removes attributes from the body received from
             # the API that are logically tied to network resources but are
             # stored in other database tables handled by extensions
@@ -480,6 +503,28 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 ndb_utils.filter_non_model_columns(n, models_v2.Network))
         return self._make_network_dict(network, context=context)
 
+    def _validate_change_network_mtu(self, context, id, mtu):
+        # can support either ip_version
+        if mtu >= constants.IPV6_MIN_MTU:
+            return
+
+        subnets = self._get_subnets_by_network(context, id)
+        if len(subnets) == 0:
+            return
+
+        # at least one subnet present, if below IPv4 minimum we fail early
+        if mtu < _constants.IPV4_MIN_MTU:
+            raise mtu_exc.NetworkMTUSubnetConflict(
+                net_id=id, mtu=_constants.IPV4_MIN_MTU)
+
+        # We do not need to check IPv4 subnets as they will have been
+        # caught by above IPV4_MIN_MTU check
+        for subnet in subnets:
+            if (subnet.ip_version == constants.IP_VERSION_6 and
+                    mtu < constants.IPV6_MIN_MTU):
+                raise mtu_exc.NetworkMTUSubnetConflict(
+                    net_id=id, mtu=constants.IPV6_MIN_MTU)
+
     def _ensure_network_not_in_use(self, context, net_id):
         non_auto_ports = context.session.query(
             models_v2.Port.id).filter_by(network_id=net_id).filter(
@@ -595,7 +640,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                     "the ip_version '%(ip_version)s'") % data
             raise exc.InvalidInput(error_message=msg)
 
-    def _validate_subnet(self, context, s, cur_subnet=None, is_pd=False):
+    def _validate_subnet(self, context, s, cur_subnet=None):
         """Validate a subnet spec."""
 
         # This method will validate attributes which may change during
@@ -607,14 +652,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
 
         ip_ver = s['ip_version']
 
-        # We could be called without a cidr if a subnet pool is being used,
-        # so remember that since some checks below require one and should
-        # be skipped.
-        has_cidr = False
         if validators.is_attr_set(s.get('cidr')):
             self._validate_ip_version(ip_ver, s['cidr'], 'cidr')
-            net = netaddr.IPNetwork(s['cidr'])
-            has_cidr = True
 
         # TODO(watanabe.isao): After we found a way to avoid the re-sync
         # from the agent side, this restriction could be removed.
@@ -622,21 +661,15 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             dhcp_was_enabled = cur_subnet.enable_dhcp
         else:
             dhcp_was_enabled = False
-        # A subnet cidr of '::' is invalid, unless the caller has
-        # indicated they are doing Prefix Delegation,
-        # see https://bugs.launchpad.net/neutron/+bug/2028159
-        if (has_cidr and ip_ver == constants.IP_VERSION_6 and
-                net.network == netaddr.IPAddress('::') and not
-                is_pd):
-            error_message = _("IPv6 subnet '::' is not supported")
-            raise exc.InvalidInput(error_message=error_message)
-        if has_cidr and s.get('enable_dhcp') and not dhcp_was_enabled:
+        if s.get('enable_dhcp') and not dhcp_was_enabled:
+            subnet_prefixlen = netaddr.IPNetwork(s['cidr']).prefixlen
             error_message = _("Subnet has a prefix length that is "
                               "incompatible with DHCP service enabled")
-            if ((ip_ver == 4 and net.prefixlen > 30) or
-                    (ip_ver == 6 and net.prefixlen > 126)):
+            if ((ip_ver == 4 and subnet_prefixlen > 30) or
+                    (ip_ver == 6 and subnet_prefixlen > 126)):
                 raise exc.InvalidInput(error_message=error_message)
 
+            net = netaddr.IPNetwork(s['cidr'])
             if net.is_multicast():
                 error_message = _("Multicast IP subnet is not supported "
                                   "if enable_dhcp is True")
@@ -650,39 +683,31 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                                   "supported if enable_dhcp is True.")
                 raise exc.InvalidInput(error_message=error_message)
 
-        gateway_ip = s.get('gateway_ip', constants.ATTR_NOT_SPECIFIED)
-        if validators.is_attr_set(gateway_ip) or gateway_ip is None:
-            # Validate the gateway IP, if defined in the request.
-            if s['gateway_ip']:
-                self._validate_ip_version(ip_ver, gateway_ip, 'gateway_ip')
-                if has_cidr:
-                    is_gateway_not_valid = (
-                        ipam.utils.check_gateway_invalid_in_subnet(
-                            s['cidr'], gateway_ip))
-                    if is_gateway_not_valid:
-                        error_message = _("Gateway is not valid on subnet")
-                        raise exc.InvalidInput(error_message=error_message)
-
-            # Ensure the current subnet gateway IP is not assigned to any port.
-            # The subnet gateway IP cannot be modified or removed if in use
-            # (assigned to a router interface).
-            # Skip this check in case of create (s parameter won't have id).
+        if validators.is_attr_set(s.get('gateway_ip')):
+            self._validate_ip_version(ip_ver, s['gateway_ip'], 'gateway_ip')
+            is_gateway_not_valid = (
+                ipam.utils.check_gateway_invalid_in_subnet(
+                    s['cidr'], s['gateway_ip']))
+            if is_gateway_not_valid:
+                error_message = _("Gateway is not valid on subnet")
+                raise exc.InvalidInput(error_message=error_message)
+            # Ensure the gateway IP is not assigned to any port
+            # skip this check in case of create (s parameter won't have id)
             # NOTE(salv-orlando): There is slight chance of a race, when
             # a subnet-update and a router-interface-add operation are
             # executed concurrently
-            s_gateway_ip = (netaddr.IPAddress(gateway_ip) if gateway_ip else
-                            None)
+            s_gateway_ip = netaddr.IPAddress(s['gateway_ip'])
             if (cur_subnet and
                     s_gateway_ip != cur_subnet['gateway_ip'] and
                     not ipv6_utils.is_ipv6_pd_enabled(s)):
-                current_gateway_ip = str(cur_subnet['gateway_ip'])
+                gateway_ip = str(cur_subnet['gateway_ip'])
                 alloc = port_obj.IPAllocation.get_alloc_routerports(
-                    context, cur_subnet['id'], gateway_ip=current_gateway_ip,
+                    context, cur_subnet['id'], gateway_ip=gateway_ip,
                     first=True)
 
                 if alloc and alloc.port_id:
                     raise exc.GatewayIpInUse(
-                        ip_address=current_gateway_ip,
+                        ip_address=gateway_ip,
                         port_id=alloc.port_id)
 
         if validators.is_attr_set(s.get('dns_nameservers')):
@@ -718,7 +743,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                     error_message=(_("ipv6_address_mode is not valid when "
                                      "ip_version is 4")))
         if ip_ver == 6:
-            self._validate_ipv6_attributes(s, cur_subnet, has_cidr)
+            self._validate_ipv6_attributes(s, cur_subnet)
 
     def _validate_subnet_for_pd(self, subnet):
         """Validates that subnet parameters are correct for IPv6 PD"""
@@ -742,6 +767,23 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                        "Prefix Delegation.")
             raise exc.BadRequest(resource='subnets', msg=reason)
 
+    def _validate_subnet_network_mtu(self, network, subnet):
+        """Validates that network mtu is correct for subnet association"""
+        mtu = network.mtu
+        if not mtu or mtu >= constants.IPV6_MIN_MTU:
+            return
+
+        # if below IPv4 minimum we fail early
+        if mtu < _constants.IPV4_MIN_MTU:
+            raise mtu_exc.NetworkMTUSubnetConflict(net_id=network.id, mtu=mtu)
+
+        # We do not need to check IPv4 subnets as they will have been
+        # caught by above IPV4_MIN_MTU check
+        ip_version = subnet.get('ip_version')
+        if (ip_version == constants.IP_VERSION_6 and
+                mtu < constants.IPV6_MIN_MTU):
+            raise mtu_exc.NetworkMTUSubnetConflict(net_id=network.id, mtu=mtu)
+
     def _update_router_gw_ports(self, context, network, subnet):
         l3plugin = directory.get_plugin(plugin_constants.L3)
         if l3plugin:
@@ -880,34 +922,30 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             msg = _('a subnetpool must be specified in the absence of a cidr')
             raise exc.BadRequest(resource='subnets', msg=msg)
 
-        validate = True
-        is_pd = False
         if subnetpool_id:
             self.ipam.validate_pools_with_subnetpool(s)
             if subnetpool_id == constants.IPV6_PD_POOL_ID:
-                is_pd = True
                 if has_cidr:
                     # We do not currently support requesting a specific
                     # cidr with IPv6 prefix delegation. Set the subnetpool_id
                     # to None and allow the request to continue as normal.
                     subnetpool_id = None
+                    self._validate_subnet(context, s)
                 else:
                     prefix = constants.PROVISIONAL_IPV6_PD_PREFIX
                     subnet['subnet']['cidr'] = prefix
                     self._validate_subnet_for_pd(s)
-                    validate = False
         else:
             if not has_cidr:
                 msg = _('A cidr must be specified in the absence of a '
                         'subnet pool')
                 raise exc.BadRequest(resource='subnets', msg=msg)
-
-        if validate:
-            self._validate_subnet(context, s, is_pd=is_pd)
+            self._validate_subnet(context, s)
 
         with db_api.CONTEXT_WRITER.using(context):
             network = self._get_network(context,
                                         subnet['subnet']['network_id'])
+            self._validate_subnet_network_mtu(network, s)
             subnet, ipam_subnet = self.ipam.allocate_subnet(context,
                                                             network,
                                                             subnet['subnet'],
@@ -959,8 +997,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         # Fill 'network_id' field with the current value since this is expected
         # by _validate_segment() in ipam_pluggable_backend.
         s['network_id'] = subnet_obj.network_id
-        is_pd = s['subnetpool_id'] == constants.IPV6_PD_POOL_ID
-        self._validate_subnet(context, s, cur_subnet=subnet_obj, is_pd=is_pd)
+        self._validate_subnet(context, s, cur_subnet=subnet_obj)
         db_pools = [netaddr.IPRange(p.start, p.end)
                     for p in subnet_obj.allocation_pools]
 
