@@ -37,13 +37,17 @@ DIRECTION_IP_PREFIX = {'ingress': 'source_ip_prefix',
 DHCP_RULE_PORT = {4: (67, 68, const.IPv4), 6: (547, 546, const.IPv6)}
 
 
-@registry.has_registry_receivers
 class SecurityGroupServerNotifierRpcMixin(sg_db.SecurityGroupDbMixin):
     """Mixin class to add agent-based security group implementation."""
 
-    @registry.receives(resources.PORT, [events.AFTER_CREATE,
-                                        events.AFTER_UPDATE,
-                                        events.AFTER_DELETE])
+    def register_sg_notifier(self):
+        registry.subscribe(self._notify_sg_on_port_change, resources.PORT,
+                           events.AFTER_CREATE)
+        registry.subscribe(self._notify_sg_on_port_change, resources.PORT,
+                           events.AFTER_UPDATE)
+        registry.subscribe(self._notify_sg_on_port_change, resources.PORT,
+                           events.AFTER_DELETE)
+
     def _notify_sg_on_port_change(self, resource, event, trigger, payload):
         """Trigger notification to other SG members on port changes."""
 
@@ -211,10 +215,12 @@ class SecurityGroupInfoAPIMixin(object):
                     # this set will be serialized into a list by rpc code
                     remote_address_group_info[remote_ag_id][ethertype] = set()
             direction = rule_in_db['direction']
+            stateful = self._is_security_group_stateful(context,
+                                                        security_group_id)
             rule_dict = {
                 'direction': direction,
                 'ethertype': ethertype,
-            }
+                'stateful': stateful}
 
             for key in ('protocol', 'port_range_min', 'port_range_max',
                         'remote_ip_prefix', 'remote_group_id',
@@ -232,13 +238,6 @@ class SecurityGroupInfoAPIMixin(object):
             if rule_dict not in sg_info['security_groups'][security_group_id]:
                 sg_info['security_groups'][security_group_id].append(
                     rule_dict)
-
-        # Populate the security group "stateful" flag in the SGs list of rules.
-        for sg_id, stateful in self._get_sgs_stateful_flag(
-                context, sg_info['security_groups'].keys()).items():
-            for rule in sg_info['security_groups'][sg_id]:
-                rule['stateful'] = stateful
-
         # Update the security groups info if they don't have any rules
         sg_ids = self._select_sg_ids_for_ports(context, ports)
         for (sg_id, ) in sg_ids:
@@ -432,13 +431,13 @@ class SecurityGroupInfoAPIMixin(object):
         """
         raise NotImplementedError()
 
-    def _get_sgs_stateful_flag(self, context, sg_id):
-        """Return the security groups stateful flag.
+    def _is_security_group_stateful(self, context, sg_id):
+        """Return whether the security group is stateful or not.
 
-        Returns a dictionary with the SG ID as key and the stateful flag:
-        {sg_1: True, sg_2: False, ...}
+        Return True if the security group associated with the given ID
+        is stateful, else False.
         """
-        raise NotImplementedError()
+        return True
 
 
 class SecurityGroupServerRpcMixin(SecurityGroupInfoAPIMixin,
@@ -535,5 +534,5 @@ class SecurityGroupServerRpcMixin(SecurityGroupInfoAPIMixin,
         return ips_by_group
 
     @db_api.retry_if_session_inactive()
-    def _get_sgs_stateful_flag(self, context, sg_ids):
-        return sg_obj.SecurityGroup.get_sgs_stateful_flag(context, sg_ids)
+    def _is_security_group_stateful(self, context, sg_id):
+        return sg_obj.SecurityGroup.get_sg_by_id(context, sg_id).stateful
