@@ -127,7 +127,7 @@ def check_assertisinstance(logical_line, filename):
 
 @core.flake8ext
 def check_assertequal_for_httpcode(logical_line, filename):
-    """N332 - Enforce correct oredering for httpcode in assertEqual."""
+    """N332 - Enforce correct ordering for httpcode in assertEqual."""
     msg = ("N332: Use assertEqual(expected_http_code, observed_http_code) "
            "instead of assertEqual(observed_http_code, expected_http_code)")
     if 'neutron/tests/' in filename:
@@ -149,8 +149,8 @@ def check_oslo_i18n_wrapper(logical_line, filename, noqa):
 
     if (len(split_line) > 1 and split_line[0] in ('import', 'from')):
         if (split_line[1] == bad_i18n_module or
-            modulename != 'neutron' and split_line[1] in ('neutron.i18n',
-                                                          'neutron._i18n')):
+                modulename != 'neutron' and split_line[1] in
+                ('neutron.i18n', 'neutron._i18n')):
             msg = ("N340: %(found)s is found. Use %(module)s._i18n instead."
                    % {'found': split_line[1], 'module': modulename})
             yield (0, msg)
