@@ -789,6 +789,22 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         result = lrp.execute(check_error=True)
         return result[0] if result else None
 
+    def get_lrouter_gw_ports(self, lrouter_name):
+        lr = self.get_lrouter(lrouter_name)
+        gw_ports = []
+        for lrp in getattr(lr, 'ports', []):
+            lrp_ext_ids = getattr(lrp, 'external_ids', {})
+            if (ovn_const.OVN_ROUTER_NAME_EXT_ID_KEY not in lrp_ext_ids or
+                    utils.ovn_name(lrp_ext_ids[
+                        ovn_const.OVN_ROUTER_NAME_EXT_ID_KEY]) != lr.name):
+                continue
+            lrp_ha_cfg = (getattr(lrp, 'gateway_chassis', None) or
+                          getattr(lrp, 'options', {}).get(
+                              ovn_const.OVN_GATEWAY_CHASSIS_KEY))
+            if lrp_ha_cfg:
+                gw_ports.append(lrp)
+        return gw_ports
+
     def delete_lrouter_ext_gw(self, lrouter_name, if_exists=True):
         return cmd.DeleteLRouterExtGwCommand(self, lrouter_name, if_exists)
 
@@ -807,7 +823,7 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         port_groups = {}
         for row in self._tables['Port_Group'].rows.values():
             name = getattr(row, 'name')
-            if not (ovn_const.OVN_SG_EXT_ID_KEY in row.external_ids or
+            if (ovn_const.OVN_SG_EXT_ID_KEY not in row.external_ids or
                     name == ovn_const.OVN_DROP_PORT_GROUP_NAME):
                 continue
             data = {}
@@ -832,10 +848,6 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
     def update_lb_external_ids(self, lb_name, values, if_exists=True):
         return cmd.UpdateLbExternalIds(self, lb_name, values, if_exists)
 
-    def db_set(self, table, record, *col_values, if_exists=True, **columns):
-        return cmd.DbSetCommand(self, table, record, *col_values,
-                                if_exists=if_exists, **columns)
-
 
 class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
     def __init__(self, connection):
@@ -956,7 +968,3 @@ class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
         # and just start using chassis objects so db_find_rows could be used
         rows = self.db_list_rows('Port_Binding').execute(check_error=True)
         return [r for r in rows if r.chassis and r.chassis[0].name == chassis]
-
-    def db_set(self, table, record, *col_values, if_exists=True, **columns):
-        return cmd.DbSetCommand(self, table, record, *col_values,
-                                if_exists=if_exists, **columns)
