@@ -15,9 +15,7 @@
 
 import abc
 import copy
-import functools
 import inspect
-import re
 import threading
 
 from futurist import periodics
@@ -54,34 +52,6 @@ INCONSISTENCY_TYPE_CREATE_UPDATE = 'create/update'
 INCONSISTENCY_TYPE_DELETE = 'delete'
 
 
-def has_lock_periodic(*args, periodic_run_limit=0, **kwargs):
-    def wrapper(f):
-        _retries = 0
-
-        @functools.wraps(f)
-        @periodics.periodic(*args, **kwargs)
-        def decorator(self, *args, **kwargs):
-            # This periodic task is included in DBInconsistenciesPeriodics
-            # since it uses the lock to ensure only one worker is executing
-            # additonally, if periodic_run_limit parameter with value > 0 is
-            # provided and lock is not acquired for periodic_run_limit
-            # times, task will not be run anymore by this maintenance worker
-            nonlocal _retries
-            if not self.has_lock:
-                if periodic_run_limit > 0:
-                    if _retries >= periodic_run_limit:
-                        LOG.debug("Have not been able to acquire lock to run "
-                                  "task '%s' after %s tries, limit reached. "
-                                  "No more attempts will be made.",
-                                  f, _retries)
-                        raise periodics.NeverAgain()
-                    _retries += 1
-                return
-            return f(self, *args, **kwargs)
-        return decorator
-    return wrapper
-
-
 class MaintenanceThread(object):
 
     def __init__(self):
@@ -318,10 +288,15 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
     # is held by some other neutron-server instance in the cloud, we'll attempt
     # to perform the migration every 10 seconds until completed.
     # TODO(ihrachys): Remove the migration to stateful fips in Z+1.
-    @has_lock_periodic(spacing=10, run_immediately=True)
+    @periodics.periodic(spacing=10, run_immediately=True)
     @rerun_on_schema_updates
     def migrate_to_stateful_fips(self):
         """Perform the migration from stateless to stateful Floating IPs. """
+        # Only the worker holding a valid lock within OVSDB will perform the
+        # migration.
+        if not self.has_lock:
+            return
+
         admin_context = n_context.get_admin_context()
         nb_sync = ovn_db_sync.OvnNbSynchronizer(
             self._ovn_client._plugin, self._nb_idl, self._ovn_client._sb_idl,
@@ -334,7 +309,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
     # to perform the migration every 10 seconds until completed.
     # TODO(jlibosva): Remove the migration to port groups at some point. It's
     # been around since Queens release so it is good to drop this soon.
-    @has_lock_periodic(spacing=10, run_immediately=True)
+    @periodics.periodic(spacing=10, run_immediately=True)
     @rerun_on_schema_updates
     def migrate_to_port_groups(self):
         """Perform the migration from Address Sets to Port Groups. """
@@ -346,6 +321,11 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         if not self._nb_idl.get_address_sets():
             raise periodics.NeverAgain()
 
+        # Only the worker holding a valid lock within OVSDB will perform the
+        # migration.
+        if not self.has_lock:
+            return
+
         admin_context = n_context.get_admin_context()
         nb_sync = ovn_db_sync.OvnNbSynchronizer(
             self._ovn_client._plugin, self._nb_idl, self._ovn_client._sb_idl,
@@ -377,9 +357,14 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         _log(create_update_inconsistencies, INCONSISTENCY_TYPE_CREATE_UPDATE)
         _log(delete_inconsistencies, INCONSISTENCY_TYPE_DELETE)
 
-    @has_lock_periodic(spacing=ovn_const.DB_CONSISTENCY_CHECK_INTERVAL,
-                       run_immediately=True)
+    @periodics.periodic(spacing=ovn_const.DB_CONSISTENCY_CHECK_INTERVAL,
+                        run_immediately=True)
     def check_for_inconsistencies(self):
+        # Only the worker holding a valid lock within OVSDB will run
+        # this periodic
+        if not self.has_lock:
+            return
+
         admin_context = n_context.get_admin_context()
         create_update_inconsistencies = (
             revision_numbers_db.get_inconsistent_resources(admin_context))
@@ -495,11 +480,13 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600,
+                        run_immediately=True)
     def check_global_dhcp_opts(self):
+        # This periodic task is included in DBInconsistenciesPeriodics since
+        # it uses the lock to ensure only one worker is executing
+        if not self.has_lock:
+            return
         if (not ovn_conf.get_global_dhcpv4_opts() and
                 not ovn_conf.get_global_dhcpv6_opts()):
             # No need to scan the subnets if the settings are unset.
@@ -528,11 +515,11 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_for_igmp_snoop_support(self):
+        if not self.has_lock:
+            return
+
         with self._nb_idl.transaction(check_error=True) as txn:
             value = ('true' if ovn_conf.is_igmp_snooping_enabled()
                      else 'false')
@@ -551,11 +538,11 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
     # TODO(czesla): Remove this in the A+4 cycle
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_port_has_address_scope(self):
+        if not self.has_lock:
+            return
+
         ports = self._nb_idl.db_find_rows(
             "Logical_Switch_Port", ("type", "!=", ovn_const.LSP_TYPE_LOCALNET)
         ).execute(check_error=True)
@@ -597,16 +584,16 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_for_ha_chassis_group(self):
         # If external ports is not supported stop running
         # this periodic task
         if not self._ovn_client.is_external_ports_supported():
             raise periodics.NeverAgain()
 
+        if not self.has_lock:
+            return
+
         external_ports = self._nb_idl.db_find_rows(
             'Logical_Switch_Port', ('type', '=', ovn_const.LSP_TYPE_EXTERNAL)
         ).execute(check_error=True)
@@ -618,8 +605,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                     ovn_const.OVN_NETWORK_NAME_EXT_ID_KEY].replace(
                         ovn_const.OVN_NAME_PREFIX, '')
                 ha_ch_grp = utils.sync_ha_chassis_group(
-                    context, port.name, network_id, self._nb_idl,
-                    self._sb_idl, txn)
+                    context, network_id, self._nb_idl, self._sb_idl, txn)
                 txn.add(self._nb_idl.set_lswitch_port(
                     port.name, ha_chassis_group=ha_ch_grp))
 
@@ -630,17 +616,17 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
     # TODO(lucasagomes): Remove this in the B+3 cycle
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_for_mcast_flood_reports(self):
+        if not self.has_lock:
+            return
+
         cmds = []
         for port in self._nb_idl.lsp_list().execute(check_error=True):
             port_type = port.type.strip()
             options = port.options
             mcast_flood_reports_value = options.get(
-                ovn_const.LSP_OPTIONS_MCAST_FLOOD_REPORTS)
+                    ovn_const.LSP_OPTIONS_MCAST_FLOOD_REPORTS)
 
             if self._ovn_client.is_mcast_flood_broken:
                 if port_type in ("vtep", ovn_const.LSP_TYPE_LOCALPORT,
@@ -664,7 +650,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                 cmds.append(self._nb_idl.lsp_set_options(port.name, **options))
 
             elif (mcast_flood_reports_value and port_type !=
-                  ovn_const.LSP_TYPE_LOCALNET):
+                    ovn_const.LSP_TYPE_LOCALNET):
                 cmds.append(self._nb_idl.db_remove(
                     'Logical_Switch_Port', port.name, 'options',
                     ovn_const.LSP_OPTIONS_MCAST_FLOOD_REPORTS, if_exists=True))
@@ -676,11 +662,44 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         raise periodics.NeverAgain()
 
+    # A static spacing value is used here, but this method will only run
+    # once per lock due to the use of periodics.NeverAgain().
+    @periodics.periodic(spacing=600, run_immediately=True)
+    def check_localnet_port_has_learn_fdb(self):
+        if not self.has_lock:
+            return
+
+        ports = self._nb_idl.db_find_rows(
+            "Logical_Switch_Port", ("type", "=", ovn_const.LSP_TYPE_LOCALNET)
+        ).execute(check_error=True)
+
+        with self._nb_idl.transaction(check_error=True) as txn:
+            for port in ports:
+                if ovn_conf.is_learn_fdb_enabled():
+                    fdb_opt = port.options.get(
+                        ovn_const.LSP_OPTIONS_LOCALNET_LEARN_FDB)
+                    if not fdb_opt or fdb_opt == 'false':
+                        txn.add(self._nb_idl.db_set(
+                            'Logical_Switch_Port', port.name,
+                            ('options',
+                             {ovn_const.LSP_OPTIONS_LOCALNET_LEARN_FDB: 'true'}
+                             )))
+                elif port.options.get(
+                        ovn_const.LSP_OPTIONS_LOCALNET_LEARN_FDB) == 'true':
+                    txn.add(self._nb_idl.db_set(
+                        'Logical_Switch_Port', port.name,
+                        ('options',
+                         {ovn_const.LSP_OPTIONS_LOCALNET_LEARN_FDB: 'false'})))
+        raise periodics.NeverAgain()
+
     # TODO(lucasagomes): Remove this in the Z cycle
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(spacing=600, run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_router_mac_binding_options(self):
+        if not self.has_lock:
+            return
+
         cmds = []
         for router in self._nb_idl.lr_list().execute(check_error=True):
             if (router.options.get('always_learn_from_arp_request') and
@@ -698,49 +717,16 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                     txn.add(cmd)
         raise periodics.NeverAgain()
 
-    # TODO(ralonsoh): Remove this in the Z+2 cycle
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(spacing=600, run_immediately=True)
-    def update_port_qos_with_external_ids_reference(self):
-        """Update all OVN QoS registers with the port ID
-
-        This method will only update the OVN QoS registers related to port QoS,
-        not FIP QoS. FIP QoS have the corresponding "external_ids" reference.
-        """
-        regex = re.compile(
-            r'(inport|outport) == \"(?P<port_id>[a-z0-9\-]{36})\"')
-        cmds = []
-        for ls in self._nb_idl.ls_list().execute(check_error=True):
-            for qos in self._nb_idl.qos_list(ls.name).execute(
-                    check_error=True):
-                if qos.external_ids:
-                    continue
-                match = re.match(regex, qos.match)
-                if not match:
-                    continue
-                port_id = match.group('port_id')
-                external_ids = {ovn_const.OVN_PORT_EXT_ID_KEY: port_id}
-                cmds.append(self._nb_idl.db_set(
-                    'QoS', qos.uuid, ('external_ids', external_ids)))
-
-        if cmds:
-            with self._nb_idl.transaction(check_error=True) as txn:
-                for cmd in cmds:
-                    txn.add(cmd)
-        raise periodics.NeverAgain()
-
-    # A static spacing value is used here, but this method will only run
-    # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_redirect_type_router_gateway_ports(self):
         """Check OVN router gateway ports
         Check for the option "redirect-type=bridged" value for
         router gateway ports.
         """
+        if not self.has_lock:
+            return
         context = n_context.get_admin_context()
         cmds = []
         gw_ports = self._ovn_client._plugin.get_ports(
@@ -793,21 +779,23 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_vlan_distributed_ports(self):
         """Check VLAN distributed ports
         Check for the option "reside-on-redirect-chassis" value for
         distributed VLAN ports.
         """
+        if not self.has_lock:
+            return
         context = n_context.get_admin_context()
         cmds = []
         # Get router ports belonging to VLAN networks
         vlan_nets = self._ovn_client._plugin.get_networks(
             context, {pnet.NETWORK_TYPE: [n_const.TYPE_VLAN]})
-        vlan_net_ids = [vn['id'] for vn in vlan_nets]
+        # FIXME(ltomasbo): Once Bugzilla 2162756 is fixed the
+        # is_provider_network check should be removed
+        vlan_net_ids = [vn['id'] for vn in vlan_nets
+                        if not utils.is_provider_network(vn)]
         router_ports = self._ovn_client._plugin.get_ports(
             context, {'network_id': vlan_net_ids,
                       'device_owner': n_const.ROUTER_PORT_OWNERS})
@@ -829,30 +817,31 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                     txn.add(cmd)
         raise periodics.NeverAgain()
 
-    # TODO(ralonsoh): Remove this in the Z+3 cycle. This method adds the
-    # "external_ids:OVN_GW_NETWORK_EXT_ID_KEY" to each router that has
-    # a gateway (that means, that has "external_ids:OVN_GW_PORT_EXT_ID_KEY").
+    # TODO(fnordahl): Remove this in the B+3 cycle. This method removes the
+    # now redundant  "external_ids:OVN_GW_NETWORK_EXT_ID_KEY" and
+    # "external_ids:OVN_GW_PORT_EXT_ID_KEY" from to each router.
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
-    def update_logical_router_with_gateway_network_id(self):
-        """Update all OVN logical router registers with the GW network ID"""
+    @periodics.periodic(spacing=600, run_immediately=True)
+    def remove_gw_ext_ids_from_logical_router(self):
+        """Remove `gw_port_id` and `gw_network_id` external_ids from LRs"""
+        if not self.has_lock:
+            return
+
         cmds = []
-        context = n_context.get_admin_context()
         for lr in self._nb_idl.lr_list().execute(check_error=True):
-            gw_port = lr.external_ids.get(ovn_const.OVN_GW_PORT_EXT_ID_KEY)
-            gw_net = lr.external_ids.get(ovn_const.OVN_GW_NETWORK_EXT_ID_KEY)
-            if not gw_port or (gw_port and gw_net):
-                # This router does not have a gateway network assigned yet or
-                # it has a gateway port and its corresponding network.
+            if (ovn_const.OVN_GW_PORT_EXT_ID_KEY not in lr.external_ids and
+                    ovn_const.OVN_GW_NETWORK_EXT_ID_KEY not in
+                    lr.external_ids):
+                # This router have none of the deprecated external_ids.
                 continue
 
-            port = self._ovn_client._plugin.get_port(context, gw_port)
-            external_ids = {
-                ovn_const.OVN_GW_NETWORK_EXT_ID_KEY: port['network_id']}
+            external_ids = lr.external_ids.copy()
+            for k in (ovn_const.OVN_GW_PORT_EXT_ID_KEY,
+                      ovn_const.OVN_GW_NETWORK_EXT_ID_KEY):
+                if k in external_ids:
+                    del(external_ids[k])
+
             cmds.append(self._nb_idl.db_set(
                 'Logical_Router', lr.uuid, ('external_ids', external_ids)))
 
@@ -864,10 +853,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
     # A static spacing value is used here, but this method will only run
     # once per lock due to the use of periodics.NeverAgain().
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_baremetal_ports_dhcp_options(self):
         """Update baremetal ports DHCP options
 
@@ -879,6 +865,9 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         if not self._ovn_client.is_external_ports_supported():
             raise periodics.NeverAgain()
 
+        if not self.has_lock:
+            return
+
         context = n_context.get_admin_context()
         ports = ports_obj.Port.get_ports_by_vnic_type_and_host(
             context, portbindings.VNIC_BAREMETAL)
@@ -916,13 +905,16 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         raise periodics.NeverAgain()
 
     # TODO(ralonsoh): Remove this in the Z+4 cycle
-    @has_lock_periodic(spacing=600, run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def update_port_virtual_type(self):
         """Set type=virtual to those ports with parents
         Before LP#1973276, any virtual port with "device_owner" defined, lost
         its type=virtual. This task restores the type for those ports updated
         before the fix https://review.opendev.org/c/openstack/neutron/+/841711.
         """
+        if not self.has_lock:
+            return
+
         context = n_context.get_admin_context()
         cmds = []
         for lsp in self._nb_idl.lsp_list().execute(check_error=True):
@@ -950,10 +942,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         raise periodics.NeverAgain()
 
     # TODO(ralonsoh): Remove this in the Antelope+4 cycle
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def create_router_extra_attributes_registers(self):
         """Create missing ``RouterExtraAttributes`` registers.
 
@@ -963,6 +952,9 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         only execution method finds those ``Routers`` registers without the
         child one and creates one with the default values.
         """
+        if not self.has_lock:
+            return
+
         context = n_context.get_admin_context()
         for router_id in router_obj.Router.\
                 get_router_ids_without_router_std_attrs(context):
@@ -973,53 +965,13 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         raise periodics.NeverAgain()
 
-    # TODO(slaweq): Remove this in the E cycle (C+2 as it will be next SLURP)
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
-    def add_gw_port_info_to_logical_router_port(self):
-        """Add info if LRP is connecting internal subnet or ext gateway."""
-        cmds = []
-        context = n_context.get_admin_context()
-        for router in self._ovn_client._l3_plugin.get_routers(context):
-            ext_gw_net_id = (router.get('external_gateway_info') or
-                             {}).get('network_id')
-            if not ext_gw_net_id:
-                continue
-            rtr_name = 'neutron-{}'.format(router['id'])
-            ovn_lr = self._nb_idl.get_lrouter(rtr_name)
-            for lrp in ovn_lr.ports:
-                if ovn_const.OVN_ROUTER_IS_EXT_GW in lrp.external_ids:
-                    continue
-                ovn_network_name = lrp.external_ids.get(
-                    ovn_const.OVN_NETWORK_NAME_EXT_ID_KEY)
-                if not ovn_network_name:
-                    continue
-                network_id = ovn_network_name.replace('neutron-', '')
-                if not network_id:
-                    continue
-                is_ext_gw = str(network_id == ext_gw_net_id)
-                external_ids = lrp.external_ids
-                external_ids[ovn_const.OVN_ROUTER_IS_EXT_GW] = is_ext_gw
-                cmds.append(
-                    self._nb_idl.update_lrouter_port(
-                        name=lrp.name,
-                        external_ids=external_ids))
-
-        if cmds:
-            with self._nb_idl.transaction(check_error=True) as txn:
-                for cmd in cmds:
-                    txn.add(cmd)
-        raise periodics.NeverAgain()
-
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_router_default_route_empty_dst_ip(self):
         """Check routers with default route with empty dst-ip (LP: #2002993).
         """
+        if not self.has_lock:
+            return
+
         cmds = []
         for router in self._nb_idl.lr_list().execute(check_error=True):
             if not router.external_ids.get(ovn_const.OVN_REV_NUM_EXT_ID_KEY):
@@ -1027,8 +979,8 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
             for route in self._nb_idl.lr_route_list(router.uuid).execute(
                     check_error=True):
                 if (route.nexthop == '' and
-                        (route.ip_prefix == n_const.IPv4_ANY or
-                         route.ip_prefix == n_const.IPv6_ANY)):
+                        route.ip_prefix in (n_const.IPv4_ANY,
+                                            n_const.IPv6_ANY)):
                     cmds.append(
                         self._nb_idl.delete_static_route(
                             router.name, route.ip_prefix, ''))
@@ -1041,10 +993,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         raise periodics.NeverAgain()
 
     # TODO(ralonsoh): Remove this in the Antelope+4 cycle
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def add_vnic_type_and_pb_capabilities_to_lsp(self):
         """Add the port VNIC type and port binding capabilities to the LSP.
 
@@ -1055,6 +1004,9 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         been added to the LSP the VNIC type and the port binding capabilities.
         To implement LP#1998608, only direct ports are needed.
         """
+        if not self.has_lock:
+            return
+
         port_bindings = ports_obj.PortBinding.get_port_binding_by_vnic_type(
             n_context.get_admin_context(), portbindings.VNIC_DIRECT)
         with self._nb_idl.transaction(check_error=True) as txn:
@@ -1076,10 +1028,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         raise periodics.NeverAgain()
 
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
+    @periodics.periodic(spacing=600, run_immediately=True)
     def check_fair_meter_consistency(self):
         """Update the logging meter after neutron-server reload
 
@@ -1088,6 +1037,8 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         driver after the OVN NB idl is loaded
 
         """
+        if not self.has_lock:
+            return
         if log_driver.OVNDriver.network_logging_supported(self._nb_idl):
             meter_name = (
                 cfg.CONF.network_log.local_output_log_base or "acl_log_meter")
@@ -1095,7 +1046,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                                                    from_reload=True)
         raise periodics.NeverAgain()
 
-    @has_lock_periodic(spacing=300, run_immediately=True)
+    @periodics.periodic(spacing=300, run_immediately=True)
     def remove_duplicated_chassis_registers(self):
         """Remove the "Chassis" and "Chassis_Private" duplicated registers.
 
@@ -1114,6 +1065,9 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         if not self._sb_idl.is_table_present('Chassis_Private'):
             raise periodics.NeverAgain()
 
+        if not self.has_lock:
+            return
+
         # dup_chassis_port_host = {host_name: [(ch1, ch_private1),
         #                                      (ch2, ch_private2), ... ]}
         dup_chassis_port_host = {}
@@ -1149,7 +1103,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                     for table in ('Chassis_Private', 'Chassis'):
                         txn.add(self._sb_idl.db_destroy(table, ch.name))
 
-    @has_lock_periodic(spacing=86400, run_immediately=True)
+    @periodics.periodic(spacing=86400, run_immediately=True)
     def cleanup_old_hash_ring_nodes(self):
         """Daily task to cleanup old stable Hash Ring node entries.
 
@@ -1158,58 +1112,11 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         information.
 
         """
+        if not self.has_lock:
+            return
         context = n_context.get_admin_context()
         hash_ring_db.cleanup_old_nodes(context, days=5)
 
-    @has_lock_periodic(
-        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
-        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
-        run_immediately=True)
-    def update_nat_floating_ip_with_gateway_port_reference(self):
-        """Set NAT rule gateway_port column to any floating IP without
-        router gateway port uuid reference - LP#2035281.
-        """
-
-        if not utils.is_nat_gateway_port_supported(self._nb_idl):
-            raise periodics.NeverAgain()
-
-        context = n_context.get_admin_context()
-        fip_update = []
-        lrouters = self._nb_idl.get_all_logical_routers_with_rports()
-        for router in lrouters:
-            ovn_fips = router['dnat_and_snats']
-            for ovn_fip in ovn_fips:
-                # Skip FIPs that are already configured with gateway_port
-                if ovn_fip['gateway_port']:
-                    continue
-                fip_id = ovn_fip['external_ids'].get(
-                    ovn_const.OVN_FIP_EXT_ID_KEY)
-                if fip_id:
-                    fip_update.append({'uuid': ovn_fip['uuid'],
-                                       'router_id': router['name']})
-
-        # Simple caching mechanism to avoid unnecessary DB calls
-        gw_port_id_cache = {}
-        lrp_cache = {}
-        cmds = []
-        for fip in fip_update:
-            lrouter = utils.ovn_name(fip['router_id'])
-            if lrouter not in gw_port_id_cache.keys():
-                router_db = self._ovn_client._l3_plugin.get_router(
-                    context, fip['router_id'], fields=['gw_port_id'])
-                gw_port_id_cache[lrouter] = router_db.get('gw_port_id')
-                lrp_cache[lrouter] = self._nb_idl.get_lrouter_port(
-                    gw_port_id_cache[lrouter])
-            columns = {'gateway_port': lrp_cache[lrouter].uuid}
-            cmds.append(self._nb_idl.set_nat_rule_in_lrouter(
-                lrouter, fip['uuid'], **columns))
-
-        if cmds:
-            with self._nb_idl.transaction(check_error=True) as txn:
-                for cmd in cmds:
-                    txn.add(cmd)
-        raise periodics.NeverAgain()
-
 
 class HashRingHealthCheckPeriodics(object):
 
