@@ -284,7 +284,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
 
         # Remove the common ones
         for na in list(neutron_acls):
-            for ovn_a in ovn_acls:
+            for ovn_a in ovn_acls.copy():
                 if all(item in na.items() for item in ovn_a.items()):
                     neutron_acls.remove(na)
                     ovn_acls.remove(ovn_a)
@@ -299,7 +299,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                          'remove': num_acls_to_remove})
 
         if self.mode == SYNC_MODE_REPAIR:
-            pg_resync_count = 0
+            one_time_pg_resync = True
             while True:
                 try:
                     with self.ovn_api.transaction(check_error=True) as txn:
@@ -311,13 +311,13 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                                 **acla, may_exist=True))
                 except idlutils.RowNotFound as row_err:
                     if row_err.msg.startswith("Cannot find Port_Group"):
-                        if pg_resync_count < 1:
+                        if one_time_pg_resync:
                             LOG.warning('Port group row was not found during '
                                         'ACLs sync. Will attempt to sync port '
                                         'groups one more time. The caught '
                                         'exception is: %s', row_err)
                             self.sync_port_groups(ctx)
-                            pg_resync_count += 1
+                            one_time_pg_resync = False
                             continue
                         LOG.error('Port group exception during ACL sync '
                                   'even after one more port group resync. '
@@ -865,20 +865,10 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             LOG.warning('DHCP options for subnet %s is present in '
                         'Neutron but out of sync for OVN', subnet_id)
             if self.mode == SYNC_MODE_REPAIR:
-                # If neutron-server is running we could race and find a
-                # subnet without a cached network, just skip it to avoid
-                # a KeyError below.
-                network_id = utils.ovn_name(subnet['network_id'])
-                if network_id not in db_networks:
-                    LOG.warning('Network %s for subnet %s not found in OVN NB '
-                                'DB network cache, possible race condition, '
-                                'please check that neutron-server is stopped! '
-                                'Skipping subnet.', network_id, subnet_id)
-                    continue
                 try:
-                    LOG.warning('Adding/Updating DHCP options for subnet %s '
-                                'in OVN NB DB', subnet_id)
-                    network = db_networks[network_id]
+                    LOG.debug('Adding/Updating DHCP options for subnet %s in '
+                              ' OVN NB DB', subnet_id)
+                    network = db_networks[utils.ovn_name(subnet['network_id'])]
                     # _ovn_client._add_subnet_dhcp_options doesn't create
                     # a new row in DHCP_Options if the row already exists.
                     # See commands.AddDHCPOptionsCommand.
@@ -1363,8 +1353,7 @@ class OvnSbSynchronizer(OvnDbSynchronizer):
         LOG.debug('OVN-SB Sync hostname and physical networks started')
         host_phynets_map = self.ovn_api.get_chassis_hostname_and_physnets()
         current_hosts = set(host_phynets_map)
-        previous_hosts = segments_db.get_hosts_mapped_with_segments(
-            ctx, include_agent_types={ovn_const.OVN_CONTROLLER_AGENT})
+        previous_hosts = segments_db.get_hosts_mapped_with_segments(ctx)
 
         stale_hosts = previous_hosts - current_hosts
         for host in stale_hosts:
