@@ -38,9 +38,11 @@ class OVNPortForwardingHandler(object):
         return pf_const.LB_PROTOCOL_MAP[pf_obj.protocol]
 
     @staticmethod
-    def lb_name(fip_id, proto):
-        return "{}-{}-{}".format(
-            pf_const.PORT_FORWARDING_PREFIX, fip_id, proto)
+    def lb_name(fip_id, proto, external_port=''):
+        if external_port:
+            external_port = '-%s' % external_port
+        return "{}-{}-{}{}".format(
+            pf_const.PORT_FORWARDING_PREFIX, fip_id, proto, external_port)
 
     @classmethod
     def lb_names(cls, fip_id):
@@ -48,9 +50,11 @@ class OVNPortForwardingHandler(object):
                 for proto in pf_const.LB_PROTOCOL_MAP.values()]
 
     @classmethod
-    def _get_lb_attributes(cls, pf_obj):
+    def _get_lb_attributes(cls, pf_obj, is_range=False):
+        external_port = pf_obj.external_port if is_range else ''
         lb_name = cls.lb_name(pf_obj.floatingip_id,
-                              cls._get_lb_protocol(pf_obj))
+                              cls._get_lb_protocol(pf_obj),
+                              external_port)
         vip = "{}:{}".format(pf_obj.floating_ip_address, pf_obj.external_port)
         internal_ip = "{}:{}".format(pf_obj.internal_ip_address,
                                      pf_obj.internal_port)
@@ -87,10 +91,12 @@ class OVNPortForwardingHandler(object):
             if lb in ls_lbs:
                 ovn_txn.add(nb_ovn.ls_lb_del(ls_name, lb.name))
 
-    def _port_forwarding_created(self, ovn_txn, nb_ovn, pf_obj):
+    def _port_forwarding_created(self, ovn_txn, nb_ovn, pf_obj,
+                                 is_range=False):
         # Add vip to its corresponding load balancer. There can be multiple
         # vips, so load balancer may already be present.
-        lb_name, vip, internal_ips, rtr_name = self._get_lb_attributes(pf_obj)
+        lb_name, vip, internal_ips, rtr_name = self._get_lb_attributes(
+            pf_obj, is_range=is_range)
         external_ids = {
             ovn_const.OVN_DEVICE_OWNER_EXT_ID_KEY:
                 pf_const.PORT_FORWARDING_PLUGIN,
@@ -116,7 +122,7 @@ class OVNPortForwardingHandler(object):
             for ls_name in ovn_lss:
                 try:
                     ovn_txn.add(nb_ovn.ls_lb_add(ls_name, lb_name,
-                        may_exist=True))
+                                                 may_exist=True))
                 except idlutils.RowNotFound:
                     # If one or more logical_switches are deleted
                     # log warning for those and continue with the rest.
@@ -125,21 +131,34 @@ class OVNPortForwardingHandler(object):
                                 lb_name, ls_name)
 
     def port_forwarding_created(self, ovn_txn, nb_ovn, pf_obj):
-        LOG.info("CREATE for port-forwarding %s vip %s:%s to %s:%s",
-                 pf_obj.protocol,
-                 pf_obj.floating_ip_address, pf_obj.external_port,
-                 pf_obj.internal_ip_address, pf_obj.internal_port)
-        self._port_forwarding_created(ovn_txn, nb_ovn, pf_obj)
+        pf_objs = pf_obj.unroll_port_ranges()
+        is_range = len(pf_objs) > 1
+        for pf_obj in pf_objs:
+            LOG.info("CREATE for port-forwarding %s vip %s:%s to %s:%s",
+                     pf_obj.protocol,
+                     pf_obj.floating_ip_address, pf_obj.external_port,
+                     pf_obj.internal_ip_address, pf_obj.internal_port)
+            self._port_forwarding_created(ovn_txn, nb_ovn, pf_obj,
+                                          is_range=is_range)
 
     def port_forwarding_updated(self, ovn_txn, nb_ovn, pf_obj, orig_pf_obj):
-        LOG.info("UPDATE for port-forwarding %s vip %s:%s to %s:%s",
-                 pf_obj.protocol,
-                 pf_obj.floating_ip_address, pf_obj.external_port,
-                 pf_obj.internal_ip_address, pf_obj.internal_port)
-        self._port_forwarding_deleted(ovn_txn, nb_ovn, orig_pf_obj)
-        self._port_forwarding_created(ovn_txn, nb_ovn, pf_obj)
+        orig_pf_objs = orig_pf_obj.unroll_port_ranges()
+        is_range = len(orig_pf_objs) > 1
+        for orig_pf_obj in orig_pf_objs:
+            self._port_forwarding_deleted(ovn_txn, nb_ovn, orig_pf_obj,
+                                          is_range=is_range)
+        pf_objs = pf_obj.unroll_port_ranges()
+        is_range = len(pf_objs) > 1
+        for pf_obj in pf_objs:
+            LOG.info("UPDATE for port-forwarding %s vip %s:%s to %s:%s",
+                     pf_obj.protocol,
+                     pf_obj.floating_ip_address, pf_obj.external_port,
+                     pf_obj.internal_ip_address, pf_obj.internal_port)
+            self._port_forwarding_created(ovn_txn, nb_ovn, pf_obj,
+                                          is_range=is_range)
 
-    def _port_forwarding_deleted(self, ovn_txn, nb_ovn, pf_obj):
+    def _port_forwarding_deleted(self, ovn_txn, nb_ovn, pf_obj,
+                                 is_range=False):
         # NOTE: load balancer instance is expected to be removed by api once
         #       last vip is removed.
         #       Since router has weak ref to the lb, that gets taken care
@@ -150,15 +169,23 @@ class OVNPortForwardingHandler(object):
         # TODO(flaviof): see about enhancing lb_del so that removal of lb
         # can optionally take a logical router, which explicitly dissociates
         # router from removed lb.
-        lb_name, vip, _internal_ips, _rtr = self._get_lb_attributes(pf_obj)
-        ovn_txn.add(nb_ovn.lb_del(lb_name, vip, if_exists=True))
+        pf_objs = pf_obj.unroll_port_ranges()
+        is_range = is_range or len(pf_objs) > 1
+        for pf_obj in pf_objs:
+            lb_name, vip, _internal_ips, _rtr = self._get_lb_attributes(
+                pf_obj, is_range=is_range)
+            ovn_txn.add(nb_ovn.lb_del(lb_name, vip, if_exists=True))
 
     def port_forwarding_deleted(self, ovn_txn, nb_ovn, pf_obj):
-        LOG.info("DELETE for port-forwarding %s vip %s:%s to %s:%s",
-                 pf_obj.protocol,
-                 pf_obj.floating_ip_address, pf_obj.external_port,
-                 pf_obj.internal_ip_address, pf_obj.internal_port)
-        self._port_forwarding_deleted(ovn_txn, nb_ovn, pf_obj)
+        pf_objs = pf_obj.unroll_port_ranges()
+        is_range = len(pf_objs) > 1
+        for pf_obj in pf_objs:
+            LOG.info("DELETE for port-forwarding %s vip %s:%s to %s:%s",
+                     pf_obj.protocol,
+                     pf_obj.floating_ip_address, pf_obj.external_port,
+                     pf_obj.internal_ip_address, pf_obj.internal_port)
+            self._port_forwarding_deleted(ovn_txn, nb_ovn, pf_obj,
+                                          is_range=is_range)
 
 
 @registry.has_registry_receivers
@@ -206,8 +233,8 @@ class OVNPortForwarding(object):
         """
         check_rev_tuples = []
         for lb_name in self._handler.lb_names(fip_id):
-            check_rev_cmd = ovn_nb.check_revision_number(lb_name, fip_obj,
-                ovn_const.TYPE_FLOATINGIPS, if_exists=True)
+            check_rev_cmd = ovn_nb.check_revision_number(
+                lb_name, fip_obj, ovn_const.TYPE_FLOATINGIPS, if_exists=True)
             ovn_txn.add(check_rev_cmd)
             check_rev_tuples.append((check_rev_cmd, fip_obj))
         return check_rev_tuples
@@ -229,15 +256,15 @@ class OVNPortForwarding(object):
                 self._handler.port_forwarding_created(ovn_txn, ovn_nb,
                                                       payload.latest_state)
                 self._l3_plugin.update_floatingip_status(
-                        context, payload.latest_state.floatingip_id,
-                        const.FLOATINGIP_STATUS_ACTIVE)
+                    context, payload.latest_state.floatingip_id,
+                    const.FLOATINGIP_STATUS_ACTIVE)
             elif event_type == events.AFTER_UPDATE:
                 self._handler.port_forwarding_updated(
                     ovn_txn, ovn_nb,
                     payload.latest_state, payload.states[0])
             elif event_type == events.AFTER_DELETE:
                 pfs = _pf_plugin.get_floatingip_port_forwardings(
-                          context, payload.states[0].floatingip_id)
+                    context, payload.states[0].floatingip_id)
                 self._handler.port_forwarding_deleted(ovn_txn, ovn_nb,
                                                       payload.states[0])
                 if not pfs:
