@@ -46,7 +46,6 @@ from oslotest import base
 from osprofiler import profiler
 from sqlalchemy import exc as sqlalchemy_exc
 import testtools
-from testtools import content
 
 from neutron._i18n import _
 from neutron.agent.linux import external_process
@@ -68,8 +67,6 @@ ETCDIR = os.path.join(ROOTDIR, 'etc')
 
 SUDO_CMD = 'sudo -n'
 
-TESTCASE_RETRIES = 3
-
 
 def etcdir(*p):
     return os.path.join(ETCDIR, *p)
@@ -177,26 +174,10 @@ class AttributeDict(dict):
 def _catch_timeout(f):
     @functools.wraps(f)
     def func(self, *args, **kwargs):
-        for idx in range(1, TESTCASE_RETRIES + 1):
-            try:
-                return f(self, *args, **kwargs)
-            except eventlet.Timeout as e:
-                self.fail('Execution of this test timed out: %s' % e)
-            # NOTE(ralonsoh): exception catch added due to the constant
-            # occurrences of this exception during FT and UT execution.
-            # This is due to [1]. Once the sync decorators are removed or the
-            # privsep ones are decorated by those ones (swap decorator
-            # declarations) this catch can be remove.
-            # [1] https://review.opendev.org/#/c/631275/
-            except fixtures.TimeoutException:
-                if idx < TESTCASE_RETRIES:
-                    msg = ('"fixtures.TimeoutException" during test case '
-                           'execution no %s; test case re-executed' % idx)
-                    self.addDetail('DietTestCase',
-                                   content.text_content(msg))
-                    self._set_timeout()
-                else:
-                    self.fail('Execution of this test timed out')
+        try:
+            return f(self, *args, **kwargs)
+        except eventlet.Timeout as e:
+            self.fail('Execution of this test timed out: %s' % e)
     return func
 
 
@@ -285,6 +266,24 @@ class DietTestCase(base.BaseTestCase, metaclass=_CatchTimeoutMetaclass):
 
         config.register_common_config_options()
 
+        self.addCleanup(CONF.reset)
+        self.setup_config()
+
+    @staticmethod
+    def config_parse(conf=None, args=None):
+        """Create the default configurations."""
+        if args is None:
+            args = []
+        args += ['--config-file', etcdir('neutron.conf')]
+        if conf is None:
+            config.init(args=args)
+        else:
+            conf(args)
+
+    def setup_config(self, args=None):
+        """Tests that need a non-default config can override this method."""
+        self.config_parse(args=args)
+
     def addOnException(self, handler):
 
         def safe_handler(*args, **kwargs):
@@ -371,17 +370,6 @@ class ProcessMonitorFixture(fixtures.Fixture):
 
 class BaseTestCase(DietTestCase):
 
-    @staticmethod
-    def config_parse(conf=None, args=None):
-        """Create the default configurations."""
-        if args is None:
-            args = []
-        args += ['--config-file', etcdir('neutron.conf')]
-        if conf is None:
-            config.init(args=args)
-        else:
-            conf(args)
-
     def setUp(self):
         super(BaseTestCase, self).setUp()
 
@@ -390,7 +378,6 @@ class BaseTestCase(DietTestCase):
 
         cfg.CONF.set_override('state_path', self.get_default_temp_dir().path)
 
-        self.addCleanup(CONF.reset)
         self.useFixture(ProcessMonitorFixture())
 
         self.useFixture(fixtures.MonkeyPatch(
@@ -403,8 +390,6 @@ class BaseTestCase(DietTestCase):
 
         self.useFixture(fixture.RPCFixture())
 
-        self.setup_config()
-
         self._callback_manager = registry_manager.CallbacksManager()
         self.useFixture(fixture.CallbackRegistryFixture(
             callback_manager=self._callback_manager))
@@ -455,10 +440,6 @@ class BaseTestCase(DietTestCase):
         root = root or self.get_default_temp_dir()
         return root.join(filename)
 
-    def setup_config(self, args=None):
-        """Tests that need a non-default config can override this method."""
-        self.config_parse(args=args)
-
     def config(self, **kw):
         """Override some configuration values.
 
@@ -557,6 +538,7 @@ class PluginFixture(fixtures.Fixture):
         self.core_plugin = core_plugin
 
     def _setUp(self):
+        config.register_common_config_options()
         # Do not load default service plugins in the testing framework
         # as all the mocking involved can cause havoc.
         self.default_svc_plugins_p = mock.patch(
