@@ -48,6 +48,11 @@ class BaseFullStackTestCase(testlib_api.MySQLTestCaseMixin,
 
     BUILD_WITH_MIGRATIONS = True
 
+    # NOTE(slaweq): In fullstack tests there need to be new database created
+    # for every test, and one db shouldn't be really shared between tests
+    # running by the same worker
+    CLEAN_DB_AFTER_TEST = True
+
     def setUp(self, environment):
         super(BaseFullStackTestCase, self).setUp()
 
@@ -172,6 +177,8 @@ class BaseFullStackTestCase(testlib_api.MySQLTestCaseMixin,
             for host in self.environment.hosts)
 
         vms.block_until_all_boot()
+        if use_dhcp:
+            vms.block_until_all_dhcp_config_done()
         return vms
 
     def assert_namespace_exists(self, ns_name):
