@@ -20,7 +20,6 @@ from oslo_utils import uuidutils
 import testscenarios
 
 from neutron.common import utils as common_utils
-from neutron.tests import base as tests_base
 from neutron.tests.common import net_helpers
 from neutron.tests.fullstack import base
 from neutron.tests.fullstack.resources import config
@@ -37,7 +36,7 @@ LOG = logging.getLogger(__name__)
 class BaseConnectivitySameNetworkTest(base.BaseFullStackTestCase):
 
     arp_responder = False
-    use_dhcp = True
+    use_dhcp = False
 
     num_hosts = 3
 
@@ -150,39 +149,6 @@ class TestOvsConnectivitySameNetworkOnOvsBridgeControllerStop(
             signal.SIGKILL)
 
 
-class TestLinuxBridgeConnectivitySameNetwork(BaseConnectivitySameNetworkTest):
-
-    l2_agent_type = constants.AGENT_TYPE_LINUXBRIDGE
-    scenarios = [
-        ('VXLAN', {'network_type': 'vxlan',
-                   'l2_pop': False}),
-        ('VLANs', {'network_type': 'vlan',
-                   'l2_pop': False}),
-        ('VXLAN and l2pop', {'network_type': 'vxlan',
-                             'l2_pop': True})
-    ]
-
-    def test_connectivity(self):
-        self._test_connectivity()
-
-
-class TestConnectivitySameNetworkNoDhcp(BaseConnectivitySameNetworkTest):
-
-    scenarios = [
-        (constants.AGENT_TYPE_OVS,
-         {'l2_agent_type': constants.AGENT_TYPE_OVS}),
-        (constants.AGENT_TYPE_LINUXBRIDGE,
-         {'l2_agent_type': constants.AGENT_TYPE_LINUXBRIDGE})
-    ]
-
-    use_dhcp = False
-    network_type = 'vxlan'
-    l2_pop = False
-
-    def test_connectivity(self):
-        self._test_connectivity()
-
-
 class _TestUninterruptedConnectivityOnL2AgentRestart(
         BaseConnectivitySameNetworkTest):
 
@@ -227,20 +193,3 @@ class TestUninterruptedConnectivityOnL2AgentRestartOvs(
 
     def test_l2_agent_restart(self, agent_restart_timeout=20):
         self._test_l2_agent_restart(agent_restart_timeout)
-
-
-class TestUninterruptedConnectivityOnL2AgentRestartLB(
-        _TestUninterruptedConnectivityOnL2AgentRestart):
-
-    scenario = [('LB',
-                 {'l2_agent_type': constants.AGENT_TYPE_LINUXBRIDGE})]
-
-    scenarios = (
-        testscenarios.multiply_scenarios(
-            scenario,
-            _TestUninterruptedConnectivityOnL2AgentRestart.network_scenarios)
-    )
-
-    @tests_base.unstable_test("bug 1928764")
-    def test_l2_agent_restart(self, agent_restart_timeout=20):
-        self._test_l2_agent_restart(agent_restart_timeout)
