@@ -20,19 +20,12 @@ from oslo_utils import uuidutils
 
 from neutron.common import utils
 from neutron.services.trunk.drivers.openvswitch.agent import ovsdb_handler
-from neutron.services.trunk.drivers.openvswitch.agent import trunk_manager
 from neutron.services.trunk.drivers.openvswitch import utils as trunk_ovs_utils
 from neutron.tests.fullstack import base
 from neutron.tests.fullstack.resources import environment
 from neutron.tests.fullstack.resources import machine
 
 
-def trunk_bridge_does_not_exist(trunk_id):
-    """Return true if trunk bridge for given ID does not exists."""
-    bridge = trunk_manager.TrunkBridge(trunk_id)
-    return not bridge.exists()
-
-
 def make_ip_network(port, network):
     """Make an IPNetwork object from port and network.
 
@@ -91,7 +84,7 @@ class TestTrunkPlugin(base.BaseFullStackTestCase):
         host_desc = [environment.HostDescription(
             l3_agent=False,
             l2_agent_type=constants.AGENT_TYPE_OVS)]
-        env_desc = environment.EnvironmentDescription()
+        env_desc = environment.EnvironmentDescription(service_plugins='trunk')
         env = environment.Environment(env_desc, host_desc)
         super(TestTrunkPlugin, self).setUp(env)
 
@@ -207,6 +200,14 @@ class TestTrunkPlugin(base.BaseFullStackTestCase):
         vm.add_vlan_interface(
             subport['mac_address'], ip_network, subport_network.tag)
 
+    # NOTE(slaweq): As is described in bug
+    # https://bugs.launchpad.net/neutron/+bug/1687709 when more than one
+    # different ovs-agent with enabled trunk driver is running at a time it
+    # might lead to race conditions between them.
+    # Because of that ovs_agent used for fullstack tests is monkeypatched and
+    # loads trunk driver only if trunk service plugin is enabled.
+    # That makes restriction that only a single set of tests with trunk-enabled
+    # services will run at the same time.
     def test_trunk_lifecycle(self):
         """Test life-cycle of a fake VM with trunk port.
 
@@ -274,16 +275,8 @@ class TestTrunkPlugin(base.BaseFullStackTestCase):
         vlan_aware_vm.block_until_ping(trunk_network_vm.ip)
         vlan_aware_vm.block_until_ping(vlan2_network_vm.ip)
 
-        # Delete vm and check that patch ports and trunk bridge are gone
+        # Delete vm and check that patch ports are gone
         vlan_aware_vm.destroy()
-        bridge_doesnt_exist_predicate = functools.partial(
-            trunk_bridge_does_not_exist, trunk_id)
-        utils.wait_until_true(
-            bridge_doesnt_exist_predicate,
-            exception=TrunkTestException(
-                'Trunk bridge with ID %s has not been removed' %
-                trunk_id)
-        )
 
         integration_bridge = self.host.get_bridge(None)
         no_patch_ports_predicate = functools.partial(
