@@ -360,12 +360,6 @@ class TestNBDbMonitor(base.TestOVNFunctionalBase):
         # and the corresponding "virtual-parents".
         self._check_port_binding_type(vip['id'], ovn_const.LSP_TYPE_VIRTUAL)
         self._check_port_virtual_parents(vip['id'], port['id'])
-        n_utils.wait_until_true(lambda: mock_update_vip_host.called,
-                                timeout=10)
-        # The "Port_Binding" has been deleted. Then the "Port_Binding" register
-        # is created again without virtual_parents, but this event doesn't
-        # call "update_virtual_port_host".
-        mock_update_vip_host.assert_called_once_with(vip['id'], None)
 
         # 2) Unset the allowed address pairs.
         # Assign the VIP again and delete the virtual port.
@@ -406,6 +400,19 @@ class TestNBDbMonitor(base.TestOVNFunctionalBase):
         # if this behaviour is changed.
         mock_update_vip_host.assert_called_with(vip['id'], None)
 
+    @mock.patch.object(mech_driver.OVNMechanismDriver,
+                       'update_virtual_port_host')
+    def test_non_virtual_port_no_host_update(self, mock_update_vip_host):
+        # The ``PortBindingUpdateVirtualPortsEvent`` delete event should affect
+        # only to virtual ports. This check is done for virtual ports in
+        # ``test_virtual_port_host_update``.
+        port = self.create_port()
+        self._delete('ports', port['id'])
+        # We actively wait for 5 seconds for the ``Port_Binding`` event to
+        # arrive and be processed, but the port host must not be updated.
+        self.assertRaises(n_utils.WaitTimeout, n_utils.wait_until_true,
+                          lambda: mock_update_vip_host.called, timeout=5)
+
 
 class TestNBDbMonitorOverTcp(TestNBDbMonitor):
     def get_ovsdb_server_protocol(self):
@@ -666,3 +673,45 @@ class TestOvnIdlConnections(base.TestOVNFunctionalBase):
                 **kwargs)
             self.assertEqual(set(idlutils.parse_connection(conns)),
                              set(idl._session.remotes))
+
+
+class TestPortBindingChassisEvent(base.TestOVNFunctionalBase,
+                                  test_l3.L3NatTestCaseMixin):
+
+    def setUp(self, **kwargs):
+        super().setUp(**kwargs)
+        self.chassis = self.add_fake_chassis('ovs-host1')
+        self.l3_plugin = directory.get_plugin(plugin_constants.L3)
+        kwargs = {'arg_list': (external_net.EXTERNAL,),
+                  external_net.EXTERNAL: True}
+        self.net = self._make_network(
+            self.fmt, 'ext_net', True, as_admin=True, **kwargs)
+        self._make_subnet(self.fmt, self.net, '20.0.10.1', '20.0.10.0/24')
+        port_res = self._create_port(self.fmt, self.net['network']['id'])
+        self.port = self.deserialize(self.fmt, port_res)['port']
+
+        self.ext_api = test_extensions.setup_extensions_middleware(
+            test_l3.L3TestExtensionManager())
+        self.pb_event_match = mock.patch.object(
+            self.sb_api.idl._portbinding_event, 'match_fn').start()
+
+    def _check_pb_type(self, _type):
+        def check_pb_type(_type):
+            if len(self.pb_event_match.call_args_list) < 1:
+                return False
+
+            pb_row = self.pb_event_match.call_args_list[0].args[1]
+            return _type == pb_row.type
+
+        n_utils.wait_until_true(lambda: check_pb_type(_type), timeout=5)
+
+    def test_pb_type_patch(self):
+        router = self._make_router(self.fmt, self._tenant_id)
+        self._add_external_gateway_to_router(router['router']['id'],
+                                             self.net['network']['id'])
+        self._check_pb_type('patch')
+
+    def test_pb_type_empty(self):
+        self.sb_api.lsp_bind(self.port['id'], self.chassis,
+                             may_exist=True).execute(check_error=True)
+        self._check_pb_type('')
