@@ -33,18 +33,16 @@ from neutron.common.ovn import utils
 from neutron.common import utils as n_utils
 from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 from neutron.db import ovn_revision_numbers_db as db_rev
-from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import ovn_client
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import ovsdb_monitor
 from neutron.tests import base as tests_base
 from neutron.tests.functional import base
+from neutron.tests.unit.extensions import test_securitygroup as test_sg
 
 VHU_MODE = 'server'
 OVS_VIF_DETAILS = {
     portbindings.CAP_PORT_FILTER: True,
     portbindings.VIF_DETAILS_CONNECTIVITY: portbindings.CONNECTIVITY_L2,
     portbindings.VIF_DETAILS_BOUND_DRIVERS: {'0': 'ovn'},
-    portbindings.VIF_DETAILS_BRIDGE_NAME: 'br-int',
-    portbindings.OVS_DATAPATH_TYPE: 'system',
 }
 VHOSTUSER_VIF_DETAILS = {
     portbindings.CAP_PORT_FILTER: False,
@@ -52,39 +50,34 @@ VHOSTUSER_VIF_DETAILS = {
     'vhostuser_ovs_plug': True,
     portbindings.VIF_DETAILS_CONNECTIVITY: portbindings.CONNECTIVITY_L2,
     portbindings.VIF_DETAILS_BOUND_DRIVERS: {'0': 'ovn'},
-    portbindings.VIF_DETAILS_BRIDGE_NAME: 'br-int',
-    portbindings.OVS_DATAPATH_TYPE: 'netdev',
 }
 
 
 class TestPortBinding(base.TestOVNFunctionalBase):
 
-    def setUp(self, **kwargs):
-        super().setUp(**kwargs)
+    def setUp(self):
+        super(TestPortBinding, self).setUp()
         self.ovs_host = 'ovs-host'
         self.dpdk_host = 'dpdk-host'
         self.invalid_dpdk_host = 'invalid-host'
         self.insecure_host = 'insecure-host'
         self.smartnic_dpu_host = 'smartnic-dpu-host'
         self.smartnic_dpu_serial = 'fake-smartnic-dpu-serial'
-        self.add_fake_chassis(
-            self.ovs_host,
-            other_config={ovn_const.OVN_DATAPATH_TYPE: 'system'})
+        self.add_fake_chassis(self.ovs_host)
         self.add_fake_chassis(
             self.dpdk_host,
-            other_config={ovn_const.OVN_DATAPATH_TYPE: 'netdev',
+            other_config={'datapath-type': 'netdev',
                           'iface-types': 'dummy,dummy-internal,dpdkvhostuser'})
 
         self.add_fake_chassis(
             self.invalid_dpdk_host,
-            other_config={ovn_const.OVN_DATAPATH_TYPE: 'netdev',
+            other_config={'datapath-type': 'netdev',
                           'iface-types': 'dummy,dummy-internal,geneve,vxlan'})
         self.add_fake_chassis(
             self.smartnic_dpu_host,
             other_config={ovn_const.OVN_CMS_OPTIONS: '{}={}'.format(
                 ovn_const.CMS_OPT_CARD_SERIAL_NUMBER,
-                self.smartnic_dpu_serial),
-                ovn_const.OVN_DATAPATH_TYPE: 'system'})
+                self.smartnic_dpu_serial)})
         self.n1 = self._make_network(self.fmt, 'n1', True)
         res = self._create_subnet(self.fmt, self.n1['network']['id'],
                                   '10.0.0.0/24')
@@ -108,20 +101,21 @@ class TestPortBinding(base.TestOVNFunctionalBase):
                 'network_id': self.n1['network']['id'],
                 'tenant_id': self._tenant_id})
 
-            port_req = self.new_create_request('ports', port_data, self.fmt)
+            port_req = self.new_create_request('ports', port_data, self.fmt,
+                                               as_admin=True)
             port_res = port_req.get_response(self.api)
             p = self.deserialize(self.fmt, port_res)
             port_id = p['port']['id']
         else:
             port_req = self.new_update_request('ports', port_data, port_id,
-                                               self.fmt)
+                                               self.fmt, as_admin=True)
             port_res = port_req.get_response(self.api)
             self.deserialize(self.fmt, port_res)
 
         return port_id
 
     def _port_show(self, port_id):
-        port_req = self.new_show_request('ports', port_id)
+        port_req = self.new_show_request('ports', port_id, as_admin=True)
         port_res = port_req.get_response(self.api)
         return self.deserialize(self.fmt, port_res)
 
@@ -158,13 +152,9 @@ class TestPortBinding(base.TestOVNFunctionalBase):
         self._verify_vif_details(port_id, self.dpdk_host, 'vhostuser',
                                  expected_vif_details)
 
-        expected_vif_details = copy.deepcopy(VHOSTUSER_VIF_DETAILS)
-        expected_vif_details.pop('vhostuser_mode')
-        expected_vif_details.pop('vhostuser_ovs_plug')
-        expected_vif_details[portbindings.CAP_PORT_FILTER] = True
         port_id = self._create_or_update_port(hostname=self.invalid_dpdk_host)
         self._verify_vif_details(port_id, self.invalid_dpdk_host, 'ovs',
-                                 expected_vif_details)
+                                 OVS_VIF_DETAILS)
 
     def test_port_binding_create_remote_managed_port(self):
         pci_vendor_info = 'fake-pci-vendor-info'
@@ -216,12 +206,8 @@ class TestPortBinding(base.TestOVNFunctionalBase):
 
         port_id = self._create_or_update_port(port_id=port_id,
                                               hostname=self.invalid_dpdk_host)
-        expected_vif_details = copy.deepcopy(VHOSTUSER_VIF_DETAILS)
-        expected_vif_details.pop('vhostuser_mode')
-        expected_vif_details.pop('vhostuser_ovs_plug')
-        expected_vif_details[portbindings.CAP_PORT_FILTER] = True
         self._verify_vif_details(port_id, self.invalid_dpdk_host, 'ovs',
-                                 expected_vif_details)
+                                 OVS_VIF_DETAILS)
 
     def test_port_binding_update_remote_managed_port(self):
         port_id = self._create_or_update_port(
@@ -730,13 +716,13 @@ class TestExternalPorts(base.TestOVNFunctionalBase):
     def _test_external_port_create_switchdev(self, vnic_type):
         port_data = {
             'port': {'network_id': self.n1['network']['id'],
-                     'tenant_id': self._tenant_id,
                      portbindings.VNIC_TYPE: vnic_type,
                      ovn_const.OVN_PORT_BINDING_PROFILE: {
                          ovn_const.PORT_CAP_PARAM: [
                              ovn_const.PORT_CAP_SWITCHDEV]}}}
 
-        port_req = self.new_create_request('ports', port_data, self.fmt)
+        port_req = self.new_create_request('ports', port_data, self.fmt,
+                                           as_admin=True)
         port_res = port_req.get_response(self.api)
         port = self.deserialize(self.fmt, port_res)['port']
 
@@ -784,7 +770,8 @@ class TestExternalPorts(base.TestOVNFunctionalBase):
                      ovn_const.PORT_CAP_PARAM: [
                          ovn_const.PORT_CAP_SWITCHDEV]}}}
         port_req = self.new_update_request(
-            'ports', port_upt_data, port['id'], self.fmt)
+            'ports', port_upt_data, port['id'], self.fmt,
+            as_admin=True)
         port_res = port_req.get_response(self.api)
         port = self.deserialize(self.fmt, port_res)['port']
 
@@ -852,6 +839,10 @@ class TestSecurityGroup(base.TestOVNFunctionalBase):
             'tenant_id': self._tenant_id,
             'is_default': True,
         }
+        mock.patch.object(
+            self.plugin, 'get_default_security_group_rules',
+            return_value=copy.deepcopy(
+                test_sg.RULES_TEMPLATE_FOR_CUSTOM_SG)).start()
 
     def _find_acls_for_sg(self, sg_id):
         rows = self.nb_api.db_find_rows('ACL').execute(check_error=True)
@@ -963,7 +954,7 @@ class TestProvnetPorts(base.TestOVNFunctionalBase):
 
     def test_network_segments_localnet_ports(self):
         n1 = self._make_network(
-                self.fmt, 'n1', True,
+                self.fmt, 'n1', True, as_admin=True,
                 arg_list=('provider:network_type',
                           'provider:segmentation_id',
                           'provider:physical_network'),
@@ -1035,7 +1026,7 @@ class TestMetadataPorts(base.TestOVNFunctionalBase):
 
     def _check_metadata_port(self, net_id, fixed_ip, fail=True):
         for port in self._list_ports_ovn(net_id=net_id):
-            if ovn_client.OVNClient.is_metadata_port(port):
+            if utils.is_ovn_metadata_port(port):
                 self.assertEqual(net_id, port['network_id'])
                 if fixed_ip:
                     self.assertIn(fixed_ip, port['fixed_ips'])
@@ -1230,8 +1221,7 @@ class TestAgentApi(base.TestOVNFunctionalBase):
         # then Chassis_Private.chassis = []; both metadata and controller
         # agents will still be present in the agent list.
         agent_event = AgentWaitEvent(self.mech_driver, [self.chassis],
-                                     events=(event.RowEvent.ROW_UPDATE,
-                                             event.RowEvent.ROW_DELETE,))
+                                     events=(event.RowEvent.ROW_UPDATE,))
         self.sb_api.idl.notify_handler.watch_event(agent_event)
         self.sb_api.chassis_del(self.chassis).execute(check_error=True)
         self.assertTrue(agent_event.wait())
@@ -1264,103 +1254,3 @@ class TestAgentApi(base.TestOVNFunctionalBase):
         self.plugin.delete_agent(self.context, metadata_id)
         self.assertRaises(agent_exc.AgentNotFound, self.plugin.get_agent,
                           self.context, metadata_id)
-
-
-class TestNATRuleGatewayPort(base.TestOVNFunctionalBase):
-
-    def setUp(self):
-        super().setUp()
-        self._ovn_client = self.mech_driver._ovn_client
-
-    def deserialize(self, content_type, response):
-        ctype = 'application/%s' % content_type
-        data = self._deserializers[ctype].deserialize(response.body)['body']
-        return data
-
-    def _create_router(self, name, external_gateway_info=None):
-        data = {'router': {'name': name, 'tenant_id': self._tenant_id,
-                           'external_gateway_info': external_gateway_info}}
-        req = self.new_create_request('routers', data, self.fmt)
-        res = req.get_response(self.api)
-        return self.deserialize(self.fmt, res)['router']
-
-    def _process_router_interface(self, action, router_id, subnet_id):
-        req = self.new_action_request(
-            'routers', {'subnet_id': subnet_id}, router_id,
-            '%s_router_interface' % action)
-        res = req.get_response(self.api)
-        return self.deserialize(self.fmt, res)
-
-    def _add_router_interface(self, router_id, subnet_id):
-        return self._process_router_interface('add', router_id, subnet_id)
-
-    def _create_port(self, name, net_id, security_groups=None,
-                     device_owner=None):
-        data = {'port': {'name': name,
-                         'tenant_id': self._tenant_id,
-                         'network_id': net_id}}
-
-        if security_groups is not None:
-            data['port']['security_groups'] = security_groups
-
-        if device_owner is not None:
-            data['port']['device_owner'] = device_owner
-
-        req = self.new_create_request('ports', data, self.fmt)
-        res = req.get_response(self.api)
-        return self.deserialize(self.fmt, res)['port']
-
-    def test_create_floatingip(self):
-        ext_net = self._make_network(
-            self.fmt, 'ext_networktest', True,
-            arg_list=('router:external',
-                      'provider:network_type',
-                      'provider:physical_network'),
-            **{'router:external': True,
-               'provider:network_type': 'flat',
-               'provider:physical_network': 'public'})['network']
-        res = self._create_subnet(self.fmt, ext_net['id'],
-            '100.0.0.0/24', gateway_ip='100.0.0.254',
-            allocation_pools=[{'start': '100.0.0.2',
-                               'end': '100.0.0.253'}],
-            enable_dhcp=False)
-        ext_subnet = self.deserialize(self.fmt, res)['subnet']
-        net1 = self._make_network(
-            self.fmt, 'network1test', True)['network']
-        res = self._create_subnet(self.fmt, net1['id'],
-            '192.168.0.0/24', gateway_ip='192.168.0.1',
-            allocation_pools=[{'start': '192.168.0.2',
-                               'end': '192.168.0.253'}],
-            enable_dhcp=False)
-        subnet1 = self.deserialize(self.fmt, res)['subnet']
-        external_gateway_info = {
-            'enable_snat': True,
-            'network_id': ext_net['id'],
-            'external_fixed_ips': [
-                {'ip_address': '100.0.0.2', 'subnet_id': ext_subnet['id']}]}
-        router = self._create_router(
-            'routertest', external_gateway_info=external_gateway_info)
-        self._add_router_interface(router['id'], subnet1['id'])
-
-        p1 = self._create_port('testp1', net1['id'])
-        logical_ip = p1['fixed_ips'][0]['ip_address']
-        fip_info = {'floatingip': {
-            'tenant_id': self._tenant_id,
-            'description': 'test_fip',
-            'floating_network_id': ext_net['id'],
-            'port_id': p1['id'],
-            'fixed_ip_address': logical_ip}}
-
-        fip = self.l3_plugin.create_floatingip(self.context, fip_info)
-
-        self.assertEqual(router['id'], fip['router_id'])
-        self.assertEqual('testp1', fip['port_details']['name'])
-        self.assertIsNotNone(self.nb_api.get_lswitch_port(fip['port_id']))
-
-        rules = self.nb_api.get_all_logical_routers_with_rports()[0]
-        fip_rule = rules['dnat_and_snats'][0]
-
-        if utils.is_nat_gateway_port_supported(self.nb_api):
-            self.assertNotEqual([], fip_rule['gateway_port'])
-        else:
-            self.assertNotIn('gateway_port', fip_rule)
