@@ -32,14 +32,12 @@ from neutron.tests.functional.resources.ovsdb import events
 
 
 class TestRouter(base.TestOVNFunctionalBase):
-    def setUp(self, **kwargs):
-        super().setUp(**kwargs)
+    def setUp(self):
+        super(TestRouter, self).setUp()
         self.chassis1 = self.add_fake_chassis(
-            'ovs-host1', physical_nets=['physnet1', 'physnet3'],
-            enable_chassis_as_gw=True, azs=[])
+            'ovs-host1', physical_nets=['physnet1', 'physnet3'])
         self.chassis2 = self.add_fake_chassis(
-            'ovs-host2', physical_nets=['physnet2', 'physnet3'],
-            enable_chassis_as_gw=True, azs=[])
+            'ovs-host2', physical_nets=['physnet2', 'physnet3'])
         self.cr_lrp_pb_event = events.WaitForCrLrpPortBindingEvent()
         self.sb_api.idl.notify_handler.watch_event(self.cr_lrp_pb_event)
 
@@ -65,7 +63,7 @@ class TestRouter(base.TestOVNFunctionalBase):
         if physnet:
             arg_list = arg_list + (pnet.PHYSICAL_NETWORK,)
             net_arg[pnet.PHYSICAL_NETWORK] = physnet
-        network = self._make_network(self.fmt, name, True,
+        network = self._make_network(self.fmt, name, True, as_admin=True,
                                      arg_list=arg_list, **net_arg)
         if cidr:
             self._make_subnet(self.fmt, network, gateway, cidr,
@@ -89,22 +87,16 @@ class TestRouter(base.TestOVNFunctionalBase):
                     self.sb_api.tables['Chassis'].rows.values()]
         for row in self.nb_api.tables[
                 'Logical_Router_Port'].rows.values():
-            if self._l3_ha_supported():
-                chassis = [gwc.chassis_name for gwc in row.gateway_chassis]
-                self.assertCountEqual(expected, chassis)
-            else:
-                rc = row.options.get(ovn_const.OVN_GATEWAY_CHASSIS_KEY)
-                self.assertIn(rc, expected)
+            chassis = [gwc.chassis_name for gwc in row.gateway_chassis]
+            self.assertCountEqual(expected, chassis)
 
     def _check_gateway_chassis_candidates(self, candidates,
-                                          router_az_hints=None,
-                                          physnet='physnet1'):
+                                          router_az_hints=None):
         # In this test, fake_select() is called once from _create_router()
         # and later from schedule_unhosted_gateways()
         ovn_client = self.l3_plugin._ovn_client
-        net_type = 'vlan' if physnet else 'geneve'
         ext1 = self._create_ext_network(
-            'ext1', net_type, physnet, 1, "10.0.0.1", "10.0.0.0/24")
+            'ext1', 'vlan', 'physnet1', 1, "10.0.0.1", "10.0.0.0/24")
         # mock select function and check if it is called with expected
         # candidates.
 
@@ -135,11 +127,12 @@ class TestRouter(base.TestOVNFunctionalBase):
 
     def test_gateway_chassis_with_cms_and_bridge_mappings(self):
         # Both chassis1 and chassis3 are having proper bridge mappings,
-        # but only chassis1 is having enable-chassis-as-gw.
-        # Test if chassis1 is selected as candidate or not.
+        # but only chassis3 is having enable-chassis-as-gw.
+        # Test if chassis3 is selected as candidate or not.
         self.chassis3 = self.add_fake_chassis(
-            'ovs-host3', physical_nets=['physnet1'], azs=[])
-        self._check_gateway_chassis_candidates([self.chassis1])
+            'ovs-host3', physical_nets=['physnet1'],
+            other_config={'ovn-cms-options': 'enable-chassis-as-gw'})
+        self._check_gateway_chassis_candidates([self.chassis3])
 
     def test_gateway_chassis_with_cms_and_no_bridge_mappings(self):
         # chassis1 is having proper bridge mappings.
@@ -173,10 +166,12 @@ class TestRouter(base.TestOVNFunctionalBase):
         # Test if chassis3 is selected as candidate or not.
         self.chassis3 = self.add_fake_chassis(
             'ovs-host3', physical_nets=['physnet1'],
-            azs=['ovn'], enable_chassis_as_gw=True)
+            other_config={'ovn-cms-options': 'enable-chassis-as-gw'},
+            azs=['ovn'])
         self.chassis4 = self.add_fake_chassis(
             'ovs-host4', physical_nets=['physnet1'],
-            azs=['ovn2'], enable_chassis_as_gw=True)
+            other_config={'ovn-cms-options': 'enable-chassis-as-gw'},
+            azs=['ovn2'])
         self._check_gateway_chassis_candidates([self.chassis3],
                                                router_az_hints=['ovn'])
 
@@ -186,9 +181,11 @@ class TestRouter(base.TestOVNFunctionalBase):
         # AvailabilityZoneNotFound. after create will delete if.
         # add chassis4 is having azs [ovn2], not match routers az_hints [ovn]
         self.chassis3 = self.add_fake_chassis(
-            'ovs-host3', physical_nets=['physnet1'], enable_chassis_as_gw=True)
+            'ovs-host3', physical_nets=['physnet1'],
+            other_config={'ovn-cms-options': 'enable-chassis-as-gw'})
         self.chassis4 = self.add_fake_chassis(
-            'ovs-host4', physical_nets=['physnet1'], enable_chassis_as_gw=True,
+            'ovs-host4', physical_nets=['physnet1'],
+            other_config={'ovn-cms-options': 'enable-chassis-as-gw'},
             azs=['ovn2'])
         ovn_client = self.l3_plugin._ovn_client
         ext1 = self._create_ext_network(
@@ -216,16 +213,6 @@ class TestRouter(base.TestOVNFunctionalBase):
         # Test if chassis1 is selected as candidate or not.
         self._check_gateway_chassis_candidates([self.chassis1])
 
-    def test_gateway_chassis_no_physnet_tunnelled_network(self):
-        # The GW network is tunnelled, no physnet defined --> no possible
-        # candidates.
-        self._check_gateway_chassis_candidates([], physnet=None)
-
-    def _l3_ha_supported(self):
-        # If the Gateway_Chassis table exists in SB database, then it
-        # means that L3 HA is supported.
-        return self.nb_api.tables.get('Gateway_Chassis')
-
     def test_gateway_chassis_least_loaded_scheduler(self):
         # This test will create 4 routers each with its own gateway.
         # Using the least loaded policy for scheduling gateway ports, we
@@ -245,26 +232,17 @@ class TestRouter(base.TestOVNFunctionalBase):
         # At this point we expect two gateways to be present in chassis1
         # and two in chassis2. If schema supports L3 HA, we expect each
         # chassis to host 2 priority 2 gateways and 2 priority 1 ones.
-        if self._l3_ha_supported():
-            # Each chassis contains a dict of (priority, # of ports hosted).
-            # {1: 2, 2: 2} means that this chassis hosts 2 ports of prio 1
-            # and two ports of prio 2.
-            expected = {self.chassis1: {1: 2, 2: 2},
-                        self.chassis2: {1: 2, 2: 2}}
-        else:
-            # For non L3 HA, each chassis should contain two gateway ports.
-            expected = {self.chassis1: 2,
-                        self.chassis2: 2}
+        # Each chassis contains a dict of (priority, # of ports hosted).
+        # {1: 2, 2: 2} means that this chassis hosts 2 ports of prio 1
+        # and two ports of prio 2.
+        expected = {self.chassis1: {1: 2, 2: 2},
+                    self.chassis2: {1: 2, 2: 2}}
         sched_info = {}
         for row in self.nb_api.tables[
                 'Logical_Router_Port'].rows.values():
-            if self._l3_ha_supported():
-                for gwc in row.gateway_chassis:
-                    chassis = sched_info.setdefault(gwc.chassis_name, {})
-                    chassis[gwc.priority] = chassis.get(gwc.priority, 0) + 1
-            else:
-                rc = row.options.get(ovn_const.OVN_GATEWAY_CHASSIS_KEY)
-                sched_info[rc] = sched_info.get(rc, 0) + 1
+            for gwc in row.gateway_chassis:
+                chassis = sched_info.setdefault(gwc.chassis_name, {})
+                chassis[gwc.priority] = chassis.get(gwc.priority, 0) + 1
         self.assertEqual(expected, sched_info)
 
     def _get_gw_port(self, router_id):
@@ -535,8 +513,6 @@ class TestRouter(base.TestOVNFunctionalBase):
                     chassis[gwc.priority] = chassis.get(gwc.priority, 0) + 1
             return sched_info
 
-        if not self._l3_ha_supported():
-            self.skipTest('L3 HA not supported')
         ovn_client = self.l3_plugin._ovn_client
         chassis4 = self.add_fake_chassis(
             'ovs-host4', physical_nets=['physnet4'], other_config={
