@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from neutron_lib import constants as lib_const
 from neutron_lib import context
 from neutron_lib import rpc as n_rpc
@@ -36,8 +37,12 @@ _uuid = uuidutils.generate_uuid
 
 TEST_QOS_FIP = "3.3.3.3"
 
-TEST_FIP = "1.1.1.1"
-TEST_FIP2 = "2.2.2.2"
+TEST_FIP_RES_NON_STORED = fip_qos.FipResource('fip_none', '8.8.8.8')
+# fip1/fip3 and fip2/fip4 have duplicated IP addresses on purpose
+TEST_FIP_RES_1 = fip_qos.FipResource('fip1', '1.1.1.1')
+TEST_FIP_RES_2 = fip_qos.FipResource('fip2', '2.2.2.2')
+TEST_FIP_RES_3 = fip_qos.FipResource('fip3', '1.1.1.1')
+TEST_FIP_RES_4 = fip_qos.FipResource('fip4', '2.2.2.2')
 
 HOSTNAME = 'myhost'
 
@@ -110,15 +115,16 @@ class QosExtensionBaseTestCase(test_agent.BasicRouterOperationsFramework):
                     'port_id': _uuid(),
                     'host': HOSTNAME,
                     'qos_policy_id': self.policy.id}
-        self.router = {'id': _uuid(),
+        self.router_id = _uuid()
+        self.router = {'id': self.router_id,
                        'gw_port': self.ex_gw_port,
                        'ha': False,
                        'distributed': False,
                        lib_const.FLOATINGIP_KEY: [self.fip]}
-        self.router_info = l3router.RouterInfo(self.agent, _uuid(),
+        self.router_info = l3router.RouterInfo(self.agent, self.router_id,
                                                self.router, **self.ri_kwargs)
         self.router_info.ex_gw_port = self.ex_gw_port
-        self.agent.router_info[self.router['id']] = self.router_info
+        self.agent.router_info[self.router_id] = self.router_info
 
         def _mock_get_router_info(router_id):
             return self.router_info
@@ -128,7 +134,7 @@ class QosExtensionBaseTestCase(test_agent.BasicRouterOperationsFramework):
             'L3AgentExtensionAPI.get_router_info').start()
         self.get_router_info.side_effect = _mock_get_router_info
 
-        self.agent_api = l3_ext_api.L3AgentExtensionAPI(None)
+        self.agent_api = l3_ext_api.L3AgentExtensionAPI(None, None)
         self.fip_qos_ext.consume_api(self.agent_api)
 
 
@@ -275,6 +281,32 @@ class FipQosExtensionTestCase(QosExtensionBaseTestCase):
                            TEST_QOS_FIP)],
                 any_order=True)
 
+    def test_delete_router(self):
+        tc_wrapper = mock.Mock()
+        with mock.patch.object(self.fip_qos_ext, '_get_tc_wrapper',
+                               return_value=tc_wrapper):
+            self.fip_qos_ext.update_router(self.context, self.router)
+            tc_wrapper.set_ip_rate_limit.assert_has_calls(
+                [mock.call(lib_const.INGRESS_DIRECTION,
+                           TEST_QOS_FIP, 1111, 2222),
+                 mock.call(lib_const.EGRESS_DIRECTION,
+                           TEST_QOS_FIP, 3333, 4444)],
+                any_order=True)
+            self.fip_qos_ext.delete_router(self.context, self.router)
+            self.assertEqual(
+                set(),
+                self.fip_qos_ext.fip_qos_map.get_fips_by_router_id(
+                    self.router_id))
+            self.assertIsNone(
+                self.fip_qos_ext.fip_qos_map.ingress_ratelimits.get(
+                    TEST_QOS_FIP))
+            self.assertIsNone(
+                self.fip_qos_ext.fip_qos_map.egress_ratelimits.get(
+                    TEST_QOS_FIP))
+            self.assertIsNone(
+                self.fip_qos_ext.fip_qos_map.get_resource_policy(
+                    TEST_QOS_FIP))
+
     def test_update_router_fip_removed(self):
         self._test_qos_policy_scenarios()
 
@@ -308,12 +340,12 @@ class FipQosExtensionTestCase(QosExtensionBaseTestCase):
                                            lib_const.EGRESS_DIRECTION)
 
     def test_update_router_only_ingress(self):
-        self._test_only_one_direction_rule(self.fip_qos_ext.add_router,
+        self._test_only_one_direction_rule(self.fip_qos_ext.update_router,
                                            self.policy2,
                                            lib_const.INGRESS_DIRECTION)
 
     def test_update_router_only_egress(self):
-        self._test_only_one_direction_rule(self.fip_qos_ext.add_router,
+        self._test_only_one_direction_rule(self.fip_qos_ext.update_router,
                                            self.policy3,
                                            lib_const.EGRESS_DIRECTION)
 
@@ -347,7 +379,7 @@ class FipQosExtensionTestCase(QosExtensionBaseTestCase):
     def _test_process_ip_rates(self, with_cache):
         rates = {'egress': {'rate': 333, 'burst': 444},
                  'ingress': {'rate': 111, 'burst': 222}}
-        fip = '123.123.123.123'
+        fip_res = fip_qos.FipResource('fip1', '123.123.123.123')
         device = mock.Mock()
         tc_wrapper = mock.Mock()
         with mock.patch.object(
@@ -356,7 +388,7 @@ class FipQosExtensionTestCase(QosExtensionBaseTestCase):
             with mock.patch.object(
                     self.fip_qos_ext, 'process_ip_rate_limit') as process_ip:
                 self.fip_qos_ext.process_ip_rates(
-                    fip, device, rates, with_cache=with_cache)
+                    fip_res, device, rates, with_cache=with_cache)
                 if with_cache:
                     self.assertEqual(2, process_ip.call_count)
                 else:
@@ -377,10 +409,106 @@ class RouterFipRateLimitMapsTestCase(base.BaseTestCase):
         super(RouterFipRateLimitMapsTestCase, self).setUp()
         self.policy_map = fip_qos.RouterFipRateLimitMaps()
 
-    def test_find_fip_router_id(self):
-        router_id = _uuid()
-        self.policy_map.router_floating_ips[router_id] = set([TEST_FIP,
-                                                              TEST_FIP2])
-        self.assertIsNone(self.policy_map.find_fip_router_id("8.8.8.8"))
-        self.assertEqual(router_id,
-                         self.policy_map.find_fip_router_id(TEST_FIP))
+    def _check_policy_map_fip(self, router_id, fip_res):
+        if router_id is None:
+            self.assertIsNone(self.policy_map.get_router_id_by_fip(fip_res))
+            self.assertTrue(fip_res not in self.policy_map._fips_2_router)
+            for router_fips in self.policy_map._router_2_fips.values():
+                self.assertTrue(fip_res not in router_fips)
+        else:
+            self.assertEqual(router_id,
+                             self.policy_map.get_router_id_by_fip(fip_res))
+            self.assertEqual(router_id,
+                             self.policy_map._fips_2_router[fip_res])
+            self.assertTrue(fip_res in
+                            self.policy_map._router_2_fips[router_id])
+
+    def test_get_router_id_by_fip(self):
+        router_id_1, router_id_2 = _uuid(), _uuid()
+        self.policy_map.set_fips(router_id_1, [TEST_FIP_RES_1, TEST_FIP_RES_2])
+        self.policy_map.set_fips(router_id_2, [TEST_FIP_RES_3, TEST_FIP_RES_4])
+        self._check_policy_map_fip(None, TEST_FIP_RES_NON_STORED)
+        self._check_policy_map_fip(router_id_1, TEST_FIP_RES_1)
+        self._check_policy_map_fip(router_id_1, TEST_FIP_RES_2)
+        self._check_policy_map_fip(router_id_2, TEST_FIP_RES_3)
+        self._check_policy_map_fip(router_id_2, TEST_FIP_RES_4)
+
+        # Remove TEST_FIP_RES_1.
+        self.policy_map.delete_fips([TEST_FIP_RES_1])
+        self._check_policy_map_fip(None, TEST_FIP_RES_NON_STORED)
+        self._check_policy_map_fip(None, TEST_FIP_RES_1)
+        self._check_policy_map_fip(router_id_1, TEST_FIP_RES_2)
+        self._check_policy_map_fip(router_id_2, TEST_FIP_RES_3)
+        self._check_policy_map_fip(router_id_2, TEST_FIP_RES_4)
+
+        # Remove TEST_FIP_RES_2 and TEST_FIP_RES_3.
+        self.policy_map.delete_fips([TEST_FIP_RES_2, TEST_FIP_RES_3])
+        self._check_policy_map_fip(None, TEST_FIP_RES_NON_STORED)
+        self._check_policy_map_fip(None, TEST_FIP_RES_1)
+        self._check_policy_map_fip(None, TEST_FIP_RES_2)
+        self._check_policy_map_fip(None, TEST_FIP_RES_3)
+        self._check_policy_map_fip(router_id_2, TEST_FIP_RES_4)
+
+        # Remove TEST_FIP_RES_4.
+        self.policy_map.delete_fips([TEST_FIP_RES_4])
+        self._check_policy_map_fip(None, TEST_FIP_RES_NON_STORED)
+        self._check_policy_map_fip(None, TEST_FIP_RES_1)
+        self._check_policy_map_fip(None, TEST_FIP_RES_2)
+        self._check_policy_map_fip(None, TEST_FIP_RES_3)
+        self._check_policy_map_fip(None, TEST_FIP_RES_4)
+
+    def test_get_router_floating_ips(self):
+        router_id_1, router_id_2 = _uuid(), _uuid()
+        self.policy_map.set_fips(router_id_1, [TEST_FIP_RES_1, TEST_FIP_RES_2])
+        self.policy_map.set_fips(router_id_2, [TEST_FIP_RES_3, TEST_FIP_RES_4])
+        fips_1 = self.policy_map.get_fips_by_router_id(router_id_1)
+        self.assertEqual(2, len(fips_1))
+        fips_2 = self.policy_map.get_fips_by_router_id(router_id_2)
+        self.assertEqual(2, len(fips_2))
+
+        # Remove TEST_FIP_RES_1.
+        self.policy_map.delete_fips([TEST_FIP_RES_1])
+        fips_1 = self.policy_map.get_fips_by_router_id(router_id_1)
+        self.assertEqual(1, len(fips_1))
+        fips_2 = self.policy_map.get_fips_by_router_id(router_id_2)
+        self.assertEqual(2, len(fips_2))
+
+        # Remove TEST_FIP_RES_2 and TEST_FIP_RES_3.
+        self.policy_map.delete_fips([TEST_FIP_RES_2, TEST_FIP_RES_3])
+        fips_1 = self.policy_map.get_fips_by_router_id(router_id_1)
+        self.assertEqual(0, len(fips_1))
+        fips_2 = self.policy_map.get_fips_by_router_id(router_id_2)
+        self.assertEqual(1, len(fips_2))
+
+        # Remove TEST_FIP_RES_4.
+        self.policy_map.delete_fips([TEST_FIP_RES_4])
+        fips_1 = self.policy_map.get_fips_by_router_id(router_id_1)
+        self.assertEqual(0, len(fips_1))
+        fips_2 = self.policy_map.get_fips_by_router_id(router_id_2)
+        self.assertEqual(0, len(fips_2))
+
+    def test_remove_fip_ratelimit_cache(self):
+        fip = "1.1.1.1"
+        self.policy_map.set_fip_ratelimit_cache(
+            "ingress", fip, 100, 200)
+        self.policy_map.set_fip_ratelimit_cache(
+            "egress", fip, 100, 200)
+        self.policy_map.remove_fip_ratelimit_cache("ingress", fip)
+        self.assertIsNone(self.policy_map.ingress_ratelimits.get(fip))
+        self.policy_map.remove_fip_ratelimit_cache("egress", fip)
+        self.assertIsNone(self.policy_map.egress_ratelimits.get(fip))
+
+    def test_set_fip_ratelimit_cache(self):
+        fip = "1.1.1.1"
+        self.policy_map.set_fip_ratelimit_cache(
+            "ingress", fip, 100, 200)
+        self.policy_map.set_fip_ratelimit_cache(
+            "egress", fip, 300, 400)
+        in_rate, in_burst = self.policy_map.get_fip_ratelimit_cache(
+            "ingress", fip)
+        self.assertEqual(100, in_rate)
+        self.assertEqual(200, in_burst)
+        e_rate, e_burst = self.policy_map.get_fip_ratelimit_cache(
+            "egress", fip)
+        self.assertEqual(300, e_rate)
+        self.assertEqual(400, e_burst)
