@@ -29,6 +29,7 @@ from oslo_utils import uuidutils
 
 from neutron.agent import rpc
 from neutron.objects import network
+from neutron.objects.port.extensions import port_hints
 from neutron.objects import ports
 from neutron.tests import base
 
@@ -221,7 +222,10 @@ class TestCacheBackedPluginApi(base.BaseTestCase):
                                                    host='host1',
                                                    level=0,
                                                    segment=self._segment)],
-            status='ACTIVE')
+            status='ACTIVE',
+            hints=port_hints.PortHints(hints={
+                "openvswitch": {"other_config": {"tx-steering": "hash"}}}),
+        )
 
     def test__legacy_notifier_resource_delete(self):
         self._api._legacy_notifier(resources.PORT, events.AFTER_DELETE, self,
@@ -352,21 +356,22 @@ class TestCacheBackedPluginApi(base.BaseTestCase):
         self.assertIn(constants.NO_ACTIVE_BINDING, entry)
 
     def test_get_device_details_migrating_to_host(self):
-        for live_migration_events, migrating_to in ((True, 'host2'),
-                                                    (False, 'irrelevant')):
-            cfg.CONF.set_override('live_migration_events',
-                                  live_migration_events, group='nova')
-            profile = jsonutils.dumps({'migrating_to': migrating_to})
-            self._port.bindings[0].profile = profile
-            self._api.remote_resource_cache.get_resource_by_id.side_effect = [
-                self._port, self._network]
-            entry = self._api.get_device_details(mock.ANY, self._port_id,
-                                                 mock.ANY, 'host2')
-            if live_migration_events:
-                self.assertEqual('host2', entry['migrating_to'])
-            else:
-                self.assertTrue(entry[constants.NO_ACTIVE_BINDING])
-                self.assertNotIn('migrating_to', entry)
+        profile = jsonutils.dumps({'migrating_to': 'host2'})
+        self._port.bindings[0].profile = profile
+        self._api.remote_resource_cache.get_resource_by_id.side_effect = [
+            self._port, self._network]
+        entry = self._api.get_device_details(mock.ANY, self._port_id,
+                                             mock.ANY, 'host2')
+        self.assertEqual('host2', entry['migrating_to'])
+
+    def test_get_device_details_hints(self):
+        self._api.remote_resource_cache.get_resource_by_id.side_effect = [
+            self._port, self._network]
+        entry = self._api.get_device_details(
+            mock.ANY, self._port_id, mock.ANY, mock.ANY)
+        self.assertEqual(
+            {"openvswitch": {"other_config": {"tx-steering": "hash"}}},
+            entry['hints'])
 
     @mock.patch('neutron.agent.resource_cache.RemoteResourceCache')
     def test_initialization_with_default_resources(self, rcache_class):
