@@ -29,7 +29,6 @@ from oslo_config import cfg
 import testtools
 
 from neutron.common.ovn import constants
-from neutron.common.ovn import exceptions as ovn_exc
 from neutron.common.ovn import utils
 from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 from neutron.tests import base
@@ -54,38 +53,24 @@ class TestUtils(base.BaseTestCase):
     def test_get_system_dns_resolvers(self):
         tempdir = self.useFixture(fixtures.TempDir()).path
         resolver_file_name = tempdir + '/resolv.conf'
-        tmp_resolv_file = open(resolver_file_name, 'w')
-        tmp_resolv_file.writelines(RESOLV_CONF_TEMPLATE)
-        tmp_resolv_file.close()
+        with open(resolver_file_name, 'w') as f:
+            f.writelines(RESOLV_CONF_TEMPLATE)
         expected_dns_resolvers = RESOLV_DNS_SERVERS
         observed_dns_resolvers = utils.get_system_dns_resolvers(
             resolver_file=resolver_file_name)
         self.assertEqual(expected_dns_resolvers, observed_dns_resolvers)
 
-    def _test_is_chassis(self, is_gateway=False, is_extport=False):
-        if is_gateway:
-            cms_option_value = constants.CMS_OPT_CHASSIS_AS_GW
-            func = utils.is_gateway_chassis
-        if is_extport:
-            cms_option_value = constants.CMS_OPT_CHASSIS_AS_EXTPORT_HOST
-            func = utils.is_extport_host_chassis
-
+    def test_is_gateway_chassis(self):
         chassis = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
-            'other_config': {'ovn-cms-options': cms_option_value}})
-        wrong_chassis_0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
+            'other_config': {'ovn-cms-options': 'enable-chassis-as-gw'}})
+        non_gw_chassis_0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
             'other_config': {'ovn-cms-options': ''}})
-        wrong_chassis_1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
+        non_gw_chassis_1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
             'other_config': {}})
 
-        self.assertTrue(func(chassis))
-        self.assertFalse(func(wrong_chassis_0))
-        self.assertFalse(func(wrong_chassis_1))
-
-    def test_is_gateway_chassis(self):
-        self._test_is_chassis(is_gateway=True)
-
-    def test_is_extport_host_chassis(self):
-        self._test_is_chassis(is_extport=True)
+        self.assertTrue(utils.is_gateway_chassis(chassis))
+        self.assertFalse(utils.is_gateway_chassis(non_gw_chassis_0))
+        self.assertFalse(utils.is_gateway_chassis(non_gw_chassis_1))
 
     def test_get_chassis_availability_zones_no_azs(self):
         chassis = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
@@ -193,7 +178,7 @@ class TestUtils(base.BaseTestCase):
             set(),
             utils.get_chassis_in_azs(chassis_list, ['az6']))
 
-    def test_get_chassis_without_azs(self):
+    def test_get_gateway_chassis_without_azs(self):
         ch0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
             'name': 'ch0',
             'other_config': {
@@ -214,23 +199,23 @@ class TestUtils(base.BaseTestCase):
 
         chassis_list = [ch0, ch1, ch2, ch3]
         self.assertEqual(
-            {'ch1', 'ch3'},
-            utils.get_chassis_without_azs(chassis_list))
+            {'ch1'},
+            utils.get_gateway_chassis_without_azs(chassis_list))
 
-    def test_is_ovn_lb_hm_port(self):
-        ovn_lb_hm_port = {
-            'device_owner': constants.OVN_LB_HM_PORT_DISTRIBUTED,
-            'device_id': 'ovn-lb-hm-12345'}
-        non_ovn_lb_hm_port_0 = {
+    def test_is_ovn_metadata_port(self):
+        meta_port = {
             'device_owner': n_const.DEVICE_OWNER_DISTRIBUTED,
             'device_id': 'ovnmeta-12345'}
-        non_ovn_lb_hm_port_1 = {
-            'device_owner': n_const.DEVICE_OWNER_DHCP,
+        non_meta_port_0 = {
+            'device_owner': n_const.DEVICE_OWNER_DISTRIBUTED,
             'device_id': 'dhcp-12345'}
+        non_meta_port_1 = {
+            'device_owner': n_const.DEVICE_OWNER_DHCP,
+            'device_id': 'ovnmeta-12345'}
 
-        self.assertTrue(utils.is_ovn_lb_hm_port(ovn_lb_hm_port))
-        self.assertFalse(utils.is_ovn_lb_hm_port(non_ovn_lb_hm_port_0))
-        self.assertFalse(utils.is_ovn_lb_hm_port(non_ovn_lb_hm_port_1))
+        self.assertTrue(utils.is_ovn_metadata_port(meta_port))
+        self.assertFalse(utils.is_ovn_metadata_port(non_meta_port_0))
+        self.assertFalse(utils.is_ovn_metadata_port(non_meta_port_1))
 
 
 class TestGateWayChassisValidity(base.BaseTestCase):
@@ -476,20 +461,6 @@ class TestDHCPUtils(base.BaseTestCase):
         expected_options = {'domain_search_list': '"openstack.org,ovn.org"'}
         self.assertEqual(expected_options, options)
 
-    def test_get_lsp_dhcp_opts_sanitize_map(self):
-        opt = {'opt_name': 'classless-static-route',
-               'opt_value': '128.128.128.128/32,22.2.0.2',
-               'ip_version': 4}
-        port = {portbindings.VNIC_TYPE: portbindings.VNIC_NORMAL,
-                edo_ext.EXTRADHCPOPTS: [opt]}
-        dhcp_disabled, options = utils.get_lsp_dhcp_opts(port, 4)
-        self.assertFalse(dhcp_disabled)
-        # Assert option got translated to "classless_static_route" and
-        # the value is a map (wrapped with {})
-        expected_options = {
-            'classless_static_route': '{128.128.128.128/32,22.2.0.2}'}
-        self.assertEqual(expected_options, options)
-
 
 class TestGetDhcpDnsServers(base.BaseTestCase):
 
@@ -711,11 +682,6 @@ class TestValidateAndGetDataFromBindingProfile(base.BaseTestCase):
                 {portbindings.VNIC_TYPE: portbindings.VNIC_DIRECT,
                  constants.OVN_PORT_BINDING_PROFILE: binding_profile}))
 
-    def test_valid_input_no_binding_profile(self):
-        # Confirm that we treat a port without binding:profile as valid
-        self.assertEqual(utils.BPInfo({}, None, []),
-                         utils.validate_and_get_data_from_binding_profile({}))
-
     def test_unknown_profile_items_pruned(self):
         # Confirm that unknown profile items are pruned
         self.assertEqual(
@@ -1192,44 +1158,3 @@ class DetermineBindHostTestCase(base.BaseTestCase):
             self.fake_smartnic_hostname,
             utils.determine_bind_host(self.mock_sb_idl, {},
                                       port_context=context))
-
-
-class ValidatePortForwardingConfigurationTestCase(base.BaseTestCase):
-
-    def setUp(self):
-        super().setUp()
-        ovn_conf.register_opts()
-
-    def test_validation_when_distributed_fip_disabled(self):
-        cfg.CONF.set_override(
-            'enable_distributed_floating_ip', False, group='ovn')
-        cfg.CONF.set_override('service_plugins', 'some_plugin,port_forwarding')
-        cfg.CONF.set_override('tenant_network_types', 'geneve,vlan',
-                              group='ml2')
-        utils.validate_port_forwarding_configuration()
-
-    def test_validation_when_no_pf_plugin_enabled(self):
-        cfg.CONF.set_override(
-            'enable_distributed_floating_ip', True, group='ovn')
-        cfg.CONF.set_override('service_plugins', 'some_plugin')
-        cfg.CONF.set_override('tenant_network_types', 'geneve,vlan',
-                              group='ml2')
-        utils.validate_port_forwarding_configuration()
-
-    def test_validation_when_no_provider_net_configured(self):
-        cfg.CONF.set_override(
-            'enable_distributed_floating_ip', True, group='ovn')
-        cfg.CONF.set_override('service_plugins', 'some_plugin,port_forwarding')
-        cfg.CONF.set_override('tenant_network_types', 'geneve,vxlan',
-                              group='ml2')
-        utils.validate_port_forwarding_configuration()
-
-    def test_validation_when_pf_and_provider_net_enabled(self):
-        cfg.CONF.set_override(
-            'enable_distributed_floating_ip', True, group='ovn')
-        cfg.CONF.set_override('service_plugins', 'some_plugin,port_forwarding')
-        cfg.CONF.set_override('tenant_network_types', 'geneve,vlan',
-                              group='ml2')
-        self.assertRaises(
-            ovn_exc.InvalidPortForwardingConfiguration,
-            utils.validate_port_forwarding_configuration)
