@@ -53,10 +53,10 @@ class SystemReaderTests(SystemAdminTests):
         self.context = self.system_reader_ctx
 
 
-class ProjectAdminTests(FloatingipPoolsAPITestCase):
+class AdminTests(FloatingipPoolsAPITestCase):
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super(AdminTests, self).setUp()
         self.alt_target = {'project_id': self.alt_project_id}
         self.context = self.project_admin_ctx
 
@@ -64,22 +64,28 @@ class ProjectAdminTests(FloatingipPoolsAPITestCase):
         self.assertTrue(
             policy.enforce(self.context, 'get_floatingip_pool',
                            self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'get_floatingip_pool',
+                           self.alt_target))
 
-    def test_get_floatingip_pool_other_project(self):
+
+class ProjectMemberTests(AdminTests):
+
+    def setUp(self):
+        super(ProjectMemberTests, self).setUp()
+        self.context = self.project_member_ctx
+
+    def test_get_floatingip_pool(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'get_floatingip_pool',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'get_floatingip_pool', self.alt_target)
 
 
-class ProjectMemberTests(ProjectAdminTests):
-
-    def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
-
-
-class ProjectReaderTests(ProjectAdminTests):
+class ProjectReaderTests(ProjectMemberTests):
 
     def setUp(self):
         super(ProjectReaderTests, self).setUp()
