@@ -107,12 +107,51 @@ class SystemReaderTests(SystemMemberTests):
         self.context = self.system_reader_ctx
 
 
-class ProjectAdminTests(L3ConntrackHelperAPITestCase):
+class AdminTests(L3ConntrackHelperAPITestCase):
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super(AdminTests, self).setUp()
         self.context = self.project_admin_ctx
 
+    def test_create_router_conntrack_helper(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_router_conntrack_helper', self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_router_conntrack_helper', self.alt_target))
+
+    def test_get_router_conntrack_helper(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'get_router_conntrack_helper', self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'get_router_conntrack_helper', self.alt_target))
+
+    def test_update_router_conntrack_helper(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_router_conntrack_helper', self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_router_conntrack_helper', self.alt_target))
+
+    def test_delete_router_conntrack_helper(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'delete_router_conntrack_helper', self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'delete_router_conntrack_helper', self.alt_target))
+
+
+class ProjectMemberTests(AdminTests):
+
+    def setUp(self):
+        super(ProjectMemberTests, self).setUp()
+        self.context = self.project_member_ctx
+
     def test_create_router_conntrack_helper(self):
         self.assertTrue(
             policy.enforce(self.context,
@@ -150,13 +189,6 @@ class ProjectAdminTests(L3ConntrackHelperAPITestCase):
             self.context, 'delete_router_conntrack_helper', self.alt_target)
 
 
-class ProjectMemberTests(ProjectAdminTests):
-
-    def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
-
-
 class ProjectReaderTests(ProjectMemberTests):
 
     def setUp(self):
