@@ -114,6 +114,30 @@ class SystemAdminTests(RouterAPITestCase):
             'create_router:external_gateway_info:external_fixed_ips',
             self.alt_target)
 
+    def test_create_router_enable_default_route_bfd(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'create_router:enable_default_route_bfd',
+            self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'create_router:enable_default_route_bfd',
+            self.alt_target)
+
+    def test_create_router_enable_default_route_ecmp(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'create_router:enable_default_route_ecmp',
+            self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'create_router:enable_default_route_ecmp',
+            self.alt_target)
+
     def test_get_router(self):
         self.assertRaises(
             base_policy.InvalidScope,
@@ -224,6 +248,30 @@ class SystemAdminTests(RouterAPITestCase):
             'update_router:external_gateway_info:external_fixed_ips',
             self.alt_target)
 
+    def test_update_router_enable_default_route_bfd(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'update_router:enable_default_route_bfd',
+            self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'update_router:enable_default_route_bfd',
+            self.alt_target)
+
+    def test_update_router_enable_default_route_ecmp(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'update_router:enable_default_route_ecmp',
+            self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'update_router:enable_default_route_ecmp',
+            self.alt_target)
+
     def test_delete_router(self):
         self.assertRaises(
             base_policy.InvalidScope,
@@ -269,12 +317,209 @@ class SystemReaderTests(SystemMemberTests):
         self.context = self.system_reader_ctx
 
 
-class ProjectAdminTests(RouterAPITestCase):
+class AdminTests(RouterAPITestCase):
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super(AdminTests, self).setUp()
         self.context = self.project_admin_ctx
 
+    def test_create_router(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_router', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'create_router', self.alt_target))
+
+    def test_create_router_distributed(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_router:distributed', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_router:distributed', self.alt_target))
+
+    def test_create_router_ha(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_router:ha', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'create_router:ha', self.alt_target))
+
+    def test_create_router_external_gateway_info(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_router:external_gateway_info',
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_router:external_gateway_info',
+                           self.alt_target))
+
+    def test_create_router_external_gateway_info_network_id(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_router:external_gateway_info:network_id',
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_router:external_gateway_info:network_id',
+                           self.alt_target))
+
+    def test_create_router_external_gateway_info_enable_snat(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_router:external_gateway_info:enable_snat',
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_router:external_gateway_info:enable_snat',
+                           self.alt_target))
+
+    def test_create_router_external_gateway_info_external_fixed_ips(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                'create_router:external_gateway_info:external_fixed_ips',
+                self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                'create_router:external_gateway_info:external_fixed_ips',
+                self.alt_target))
+
+    def test_update_router_enable_default_route_bfd(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                'update_router:enable_default_route_bfd',
+                self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                'update_router:enable_default_route_bfd',
+                self.alt_target))
+
+    def test_update_router_enable_default_route_ecmp(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                'update_router:enable_default_route_ecmp',
+                self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                'update_router:enable_default_route_ecmp',
+                self.alt_target))
+
+    def test_get_router(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'get_router', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'get_router', self.alt_target))
+
+    def test_get_router_distributed(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'get_router:distributed', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'get_router:distributed', self.alt_target))
+
+    def test_get_router_ha(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'get_router:ha', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'get_router:ha', self.alt_target))
+
+    def test_update_router(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'update_router', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'update_router', self.alt_target))
+
+    def test_update_router_distributed(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_router:distributed', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_router:distributed', self.alt_target))
+
+    def test_update_router_ha(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'update_router:ha', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'update_router:ha', self.alt_target))
+
+    def test_update_router_external_gateway_info(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_router:external_gateway_info',
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_router:external_gateway_info',
+                           self.alt_target))
+
+    def test_update_router_external_gateway_info_network_id(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_router:external_gateway_info:network_id',
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_router:external_gateway_info:network_id',
+                           self.alt_target))
+
+    def test_update_router_external_gateway_info_enable_snat(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_router:external_gateway_info:enable_snat',
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_router:external_gateway_info:enable_snat',
+                           self.alt_target))
+
+    def test_update_router_external_gateway_info_external_fixed_ips(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                'update_router:external_gateway_info:external_fixed_ips',
+                self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                'update_router:external_gateway_info:external_fixed_ips',
+                self.alt_target))
+
+    def test_delete_router(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'delete_router', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'delete_router', self.alt_target))
+
+    def test_add_router_interface(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'add_router_interface', self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'add_router_interface', self.alt_target))
+
+    def test_remove_router_interface(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'remove_router_interface', self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'remove_router_interface', self.alt_target))
+
+
+class ProjectMemberTests(AdminTests):
+
+    def setUp(self):
+        super(ProjectMemberTests, self).setUp()
+        self.context = self.project_member_ctx
+
     def test_create_router(self):
         self.assertTrue(
             policy.enforce(self.context, 'create_router', self.target))
@@ -284,17 +529,20 @@ class ProjectAdminTests(RouterAPITestCase):
             self.context, 'create_router', self.alt_target)
 
     def test_create_router_distributed(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'create_router:distributed', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_router:distributed', self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'create_router:distributed', self.alt_target)
 
     def test_create_router_ha(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'create_router:ha', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_router:ha', self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -323,10 +571,11 @@ class ProjectAdminTests(RouterAPITestCase):
             self.alt_target)
 
     def test_create_router_external_gateway_info_enable_snat(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'create_router:external_gateway_info:enable_snat',
-                           self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_router:external_gateway_info:enable_snat',
+            self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -334,16 +583,45 @@ class ProjectAdminTests(RouterAPITestCase):
             self.alt_target)
 
     def test_create_router_external_gateway_info_external_fixed_ips(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context,
-                'create_router:external_gateway_info:external_fixed_ips',
-                self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context,
             'create_router:external_gateway_info:external_fixed_ips',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context,
+            'create_router:external_gateway_info:external_fixed_ips',
+            self.alt_target)
+
+    def test_update_router_enable_default_route_bfd(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context,
+            'update_router:enable_default_route_bfd',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context,
+            'update_router:enable_default_route_bfd',
+            self.alt_target)
+
+    def test_update_router_enable_default_route_ecmp(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context,
+            'update_router:enable_default_route_ecmp',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context,
+            'update_router:enable_default_route_ecmp',
             self.alt_target)
 
     def test_get_router(self):
@@ -355,17 +633,20 @@ class ProjectAdminTests(RouterAPITestCase):
             self.context, 'get_router', self.alt_target)
 
     def test_get_router_distributed(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'get_router:distributed', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'get_router:distributed', self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'get_router:distributed', self.alt_target)
 
     def test_get_router_ha(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'get_router:ha', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'get_router:ha', self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -380,17 +661,20 @@ class ProjectAdminTests(RouterAPITestCase):
             self.context, 'update_router', self.alt_target)
 
     def test_update_router_distributed(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'update_router:distributed', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_router:distributed', self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'update_router:distributed', self.alt_target)
 
     def test_update_router_ha(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'update_router:ha', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_router:ha', self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -419,10 +703,11 @@ class ProjectAdminTests(RouterAPITestCase):
             self.alt_target)
 
     def test_update_router_external_gateway_info_enable_snat(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'update_router:external_gateway_info:enable_snat',
-                           self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_router:external_gateway_info:enable_snat',
+            self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -430,11 +715,12 @@ class ProjectAdminTests(RouterAPITestCase):
             self.alt_target)
 
     def test_update_router_external_gateway_info_external_fixed_ips(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context,
-                'update_router:external_gateway_info:external_fixed_ips',
-                self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context,
+            'update_router:external_gateway_info:external_fixed_ips',
+            self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -469,125 +755,6 @@ class ProjectAdminTests(RouterAPITestCase):
             self.context, 'remove_router_interface', self.alt_target)
 
 
-class ProjectMemberTests(ProjectAdminTests):
-
-    def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
-
-    def test_create_router_distributed(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_router:distributed', self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_router:distributed', self.alt_target)
-
-    def test_create_router_ha(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_router:ha', self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_router:ha', self.alt_target)
-
-    def test_create_router_external_gateway_info_enable_snat(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_router:external_gateway_info:enable_snat',
-            self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_router:external_gateway_info:enable_snat',
-            self.alt_target)
-
-    def test_create_router_external_gateway_info_external_fixed_ips(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context,
-            'create_router:external_gateway_info:external_fixed_ips',
-            self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context,
-            'create_router:external_gateway_info:external_fixed_ips',
-            self.alt_target)
-
-    def test_get_router_distributed(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'get_router:distributed', self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'get_router:distributed', self.alt_target)
-
-    def test_get_router_ha(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'get_router:ha', self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'get_router:ha', self.alt_target)
-
-    def test_update_router_distributed(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_router:distributed', self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_router:distributed', self.alt_target)
-
-    def test_update_router_ha(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_router:ha', self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_router:ha', self.alt_target)
-
-    def test_update_router_external_gateway_info_enable_snat(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_router:external_gateway_info:enable_snat',
-            self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_router:external_gateway_info:enable_snat',
-            self.alt_target)
-
-    def test_update_router_external_gateway_info_external_fixed_ips(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context,
-            'update_router:external_gateway_info:external_fixed_ips',
-            self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context,
-            'update_router:external_gateway_info:external_fixed_ips',
-            self.alt_target)
-
-
 class ProjectReaderTests(ProjectMemberTests):
 
     def setUp(self):
@@ -752,12 +919,32 @@ class SystemReaderExtrarouteTests(SystemMemberExtrarouteTests):
         self.context = self.system_reader_ctx
 
 
-class ProjectAdminExtrarouteTests(ExtrarouteAPITestCase):
+class AdminExtrarouteTests(ExtrarouteAPITestCase):
 
     def setUp(self):
-        super(ProjectAdminExtrarouteTests, self).setUp()
+        super(AdminExtrarouteTests, self).setUp()
         self.context = self.project_admin_ctx
 
+    def test_add_extraroute(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'add_extraroutes', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'add_extraroutes', self.alt_target))
+
+    def test_remove_extraroute(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'remove_extraroutes', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'remove_extraroutes', self.alt_target))
+
+
+class ProjectMemberExtrarouteTests(AdminExtrarouteTests):
+
+    def setUp(self):
+        super(ProjectMemberExtrarouteTests, self).setUp()
+        self.context = self.project_member_ctx
+
     def test_add_extraroute(self):
         self.assertTrue(
             policy.enforce(self.context, 'add_extraroutes', self.target))
@@ -775,13 +962,6 @@ class ProjectAdminExtrarouteTests(ExtrarouteAPITestCase):
             self.context, 'remove_extraroutes', self.alt_target)
 
 
-class ProjectMemberExtrarouteTests(ProjectAdminExtrarouteTests):
-
-    def setUp(self):
-        super(ProjectMemberExtrarouteTests, self).setUp()
-        self.context = self.project_member_ctx
-
-
 class ProjectReaderExtrarouteTests(ProjectMemberExtrarouteTests):
 
     def setUp(self):
