@@ -29,19 +29,33 @@ class SubnetAPITestCase(base.PolicyBaseTestCase):
 
         self.network = {
             'id': uuidutils.generate_uuid(),
+            'tenant_id': self.project_id,
             'project_id': self.project_id}
+        self.alt_network = {
+            'id': uuidutils.generate_uuid(),
+            'tenant_id': self.alt_project_id,
+            'project_id': self.alt_project_id}
+
+        networks = {
+            self.network['id']: self.network,
+            self.alt_network['id']: self.alt_network}
 
         self.target = {
             'project_id': self.project_id,
+            'tenant_id': self.project_id,
             'network_id': self.network['id'],
             'ext_parent_network_id': self.network['id']}
         self.alt_target = {
             'project_id': self.alt_project_id,
-            'network_id': self.network['id'],
-            'ext_parent_network_id': self.network['id']}
+            'tenant_id': self.alt_project_id,
+            'network_id': self.alt_network['id'],
+            'ext_parent_network_id': self.alt_network['id']}
+
+        def get_network(context, id, fields=None):
+            return networks.get(id)
 
         self.plugin_mock = mock.Mock()
-        self.plugin_mock.get_network.return_value = self.network
+        self.plugin_mock.get_network.side_effect = get_network
         mock.patch(
             'neutron_lib.plugins.directory.get_plugin',
             return_value=self.plugin_mock).start()
@@ -158,12 +172,82 @@ class SystemReaderTests(SystemMemberTests):
         self.context = self.system_reader_ctx
 
 
-class ProjectAdminTests(SubnetAPITestCase):
+class AdminTests(SubnetAPITestCase):
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super(AdminTests, self).setUp()
         self.context = self.project_admin_ctx
 
+    def test_create_subnet(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_subnet', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'create_subnet', self.alt_target))
+
+    def test_create_subnet_segment_id(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_subnet:segment_id', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_subnet:segment_id', self.alt_target))
+
+    def test_create_subnet_service_types(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_subnet:service_types', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_subnet:service_types', self.alt_target))
+
+    def test_get_subnet(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'get_subnet', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'get_subnet', self.alt_target))
+
+    def test_get_subnet_segment_id(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'get_subnet:segment_id', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'get_subnet:segment_id', self.alt_target))
+
+    def test_update_subnet(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'update_subnet', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'update_subnet', self.alt_target))
+
+    def test_update_subnet_segment_id(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_subnet:segment_id', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_subnet:segment_id', self.alt_target))
+
+    def test_update_subnet_service_types(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_subnet:service_types', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_subnet:service_types', self.alt_target))
+
+    def test_delete_subnet(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'delete_subnet', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'delete_subnet', self.alt_target))
+
+
+class ProjectMemberTests(AdminTests):
+
+    def setUp(self):
+        super(ProjectMemberTests, self).setUp()
+        self.context = self.project_member_ctx
+
     def test_create_subnet(self):
         self.assertTrue(
             policy.enforce(self.context, 'create_subnet', self.target))
@@ -172,81 +256,6 @@ class ProjectAdminTests(SubnetAPITestCase):
             policy.enforce,
             self.context, 'create_subnet', self.alt_target)
 
-    def test_create_subnet_segment_id(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'create_subnet:segment_id', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_subnet:segment_id', self.alt_target)
-
-    def test_create_subnet_service_types(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'create_subnet:service_types', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_subnet:service_types', self.alt_target)
-
-    def test_get_subnet(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'get_subnet', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'get_subnet', self.alt_target)
-
-    def test_get_subnet_segment_id(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'get_subnet:segment_id', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'get_subnet:segment_id', self.alt_target)
-
-    def test_update_subnet(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'update_subnet', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_subnet', self.alt_target)
-
-    def test_update_subnet_segment_id(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'update_subnet:segment_id', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_subnet:segment_id', self.alt_target)
-
-    def test_update_subnet_service_types(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'update_subnet:service_types', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_subnet:service_types', self.alt_target)
-
-    def test_delete_subnet(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'delete_subnet', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'delete_subnet', self.alt_target)
-
-
-class ProjectMemberTests(ProjectAdminTests):
-
-    def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
-
     def test_create_subnet_segment_id(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -267,6 +276,14 @@ class ProjectMemberTests(ProjectAdminTests):
             policy.enforce,
             self.context, 'create_subnet:service_types', self.alt_target)
 
+    def test_get_subnet(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'get_subnet', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'get_subnet', self.alt_target)
+
     def test_get_subnet_segment_id(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -277,6 +294,14 @@ class ProjectMemberTests(ProjectAdminTests):
             policy.enforce,
             self.context, 'get_subnet:segment_id', self.alt_target)
 
+    def test_update_subnet(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'update_subnet', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_subnet', self.alt_target)
+
     def test_update_subnet_segment_id(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -297,6 +322,14 @@ class ProjectMemberTests(ProjectAdminTests):
             policy.enforce,
             self.context, 'update_subnet:service_types', self.alt_target)
 
+    def test_delete_subnet(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'delete_subnet', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'delete_subnet', self.alt_target)
+
 
 class ProjectReaderTests(ProjectMemberTests):
 
