@@ -14,10 +14,12 @@
 
 from unittest import mock
 
+from neutron_lib.api import attributes
 from neutron_lib.api.definitions import dvr as dvr_apidef
 from neutron_lib.api.definitions import external_net as extnet_apidef
 from neutron_lib.api.definitions import l3 as l3_apidef
 from neutron_lib.api.definitions import l3_ext_ha_mode
+from neutron_lib.api.definitions import network_ha
 from neutron_lib.api.definitions import port as port_def
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import provider_net as providernet
@@ -31,7 +33,6 @@ from neutron_lib.db import api as db_api
 from neutron_lib import exceptions as n_exc
 from neutron_lib.exceptions import l3 as l3_exc
 from neutron_lib.exceptions import l3_ext_ha_mode as l3ha_exc
-from neutron_lib.objects import exceptions
 from neutron_lib.plugins import constants as plugin_constants
 from neutron_lib.plugins import directory
 from oslo_config import cfg
@@ -46,6 +47,9 @@ from neutron.db import agents_db
 from neutron.db import l3_agentschedulers_db
 from neutron.db import l3_hamode_db
 from neutron.objects import l3_hamode
+from neutron.objects import network as network_obj
+from neutron.objects import subnet as subnet_obj
+from neutron.plugins.ml2 import plugin as ml2_plugin
 from neutron import quota
 from neutron.scheduler import l3_agent_scheduler
 from neutron.services.revisions import revision_plugin
@@ -83,6 +87,16 @@ class L3HATestFramework(testlib_api.SqlTestCase):
         self.agent1 = helpers.register_l3_agent()
         self.agent2 = helpers.register_l3_agent(
             'host_2', constants.L3_AGENT_MODE_DVR_SNAT)
+        # Extend network HA extension.
+        rname = network_ha.COLLECTION_NAME
+        attributes.RESOURCES[rname].update(
+            network_ha.RESOURCE_ATTRIBUTE_MAP[rname])
+        self._max_bind_retries = ml2_plugin.MAX_BIND_TRIES
+        ml2_plugin.MAX_BIND_TRIES = 1
+        self.addCleanup(self._restore_max_bind_retries)
+
+    def _restore_max_bind_retries(self):
+        ml2_plugin.MAX_BIND_TRIES = self._max_bind_retries
 
     @property
     def admin_ctx(self):
@@ -601,6 +615,7 @@ class L3HATestCase(L3HATestFramework):
     def test_add_ha_port_subtransactions_blocked(self):
         ctx = self.admin_ctx
         with db_api.CONTEXT_WRITER.using(ctx):
+            network_obj.Network(ctx).create()
             self.assertRaises(RuntimeError, self.plugin.add_ha_port,
                               ctx, 'id', 'id', 'id')
 
@@ -628,7 +643,8 @@ class L3HATestCase(L3HATestFramework):
 
         with mock.patch.object(l3_hamode, 'L3HARouterNetwork',
                                side_effect=ValueError):
-            self.assertRaises(ValueError, self.plugin._create_ha_network,
+            self.assertRaises(c_exc.CallbackFailure,
+                              self.plugin._create_ha_network,
                               self.admin_ctx, _uuid())
 
         networks_after = self.core_plugin.get_networks(self.admin_ctx)
@@ -680,15 +696,24 @@ class L3HATestCase(L3HATestFramework):
                           self.admin_ctx, binding.port_id)
 
     def test_create_ha_network_tenant_binding_raises_duplicate(self):
-        router = self._create_router()
-        network = self.plugin.get_ha_network(self.admin_ctx,
-                                             router['tenant_id'])
-        self.plugin._create_ha_network_tenant_binding(
-            self.admin_ctx, 't1', network['network_id'])
-        with testtools.ExpectedException(
-                exceptions.NeutronDbObjectDuplicateEntry):
+        # The router creation calls first the HA network creation and the
+        # HA network-tenant binding ("ha_router_networks" register)
+        project_id = uuidutils.generate_uuid()
+        self._create_router(tenant_id=project_id)
+        network = self.core_plugin.get_networks(self.admin_ctx)[0]
+        ha_network = self.plugin.get_ha_network(self.admin_ctx, project_id)
+        self.assertEqual(project_id, ha_network.project_id)
+        self.assertEqual(network['id'], ha_network.network_id)
+
+        with testtools.ExpectedException(l3_hamode_db.DuplicatedHANetwork):
+            network[network_ha.HA] = True
+            ctx = self.admin_ctx  # That will create a new admin context
+            ctx.project_id = project_id
+            payload = events.DBEventPayload(
+                ctx, states=(network, ), resource_id=network['id'],
+                request_body=network)
             self.plugin._create_ha_network_tenant_binding(
-                self.admin_ctx, 't1', network['network_id'])
+                mock.ANY, mock.ANY, mock.ANY, payload=payload)
 
     def test_create_router_db_vr_id_allocation_goes_to_error(self):
         for method in ('_ensure_vr_id',
@@ -954,12 +979,15 @@ class L3HATestCase(L3HATestFramework):
 class L3HAModeDbTestCase(L3HATestFramework):
 
     def _create_network(self, plugin, ctx, name='net',
-                        tenant_id='tenant1', external=False):
+                        tenant_id='tenant1', external=False, ha=False):
         network = {'network': {'name': name,
                                'shared': False,
                                'admin_state_up': True,
                                'tenant_id': tenant_id,
-                               extnet_apidef.EXTERNAL: external}}
+                               'project_id': tenant_id,
+                               extnet_apidef.EXTERNAL: external,
+                               network_ha.HA: ha,
+                               }}
         return plugin.create_network(ctx, network)['id']
 
     def _create_subnet(self, plugin, ctx, network_id, cidr='10.0.0.0/8',
@@ -1378,6 +1406,50 @@ class L3HAModeDbTestCase(L3HATestFramework):
                                                 router_ids=[router['id']])
         self.assertEqual(self.agent2['host'], routers[0]['gw_port_host'])
 
+    def test__before_router_create_no_network(self):
+        project_id = uuidutils.generate_uuid()
+        ha_network = self.plugin.get_ha_network(self.admin_ctx, project_id)
+        self.assertIsNone(ha_network)
+
+        router = {'ha': True, 'project_id': project_id}
+        self.plugin._before_router_create(mock.ANY, self.admin_ctx, router)
+        ha_network = self.plugin.get_ha_network(self.admin_ctx, project_id)
+        self.assertEqual(project_id, ha_network.project_id)
+
+        # This second call ensures the method is idempotent.
+        self.plugin._before_router_create(mock.ANY, self.admin_ctx, router)
+        ha_network = self.plugin.get_ha_network(self.admin_ctx, project_id)
+        self.assertEqual(project_id, ha_network.project_id)
+
+    def test__before_router_create_no_subnet(self):
+        project_id = uuidutils.generate_uuid()
+        admin_ctx = self.admin_ctx
+        admin_ctx.project_id = project_id
+        self._create_network(self.core_plugin, admin_ctx,
+                             tenant_id=project_id, ha=True)
+        ha_network = self.plugin.get_ha_network(self.admin_ctx, project_id)
+        self.assertEqual(project_id, ha_network.project_id)
+        subnets = subnet_obj.Subnet.get_objects(
+            admin_ctx, network_id=ha_network.network_id)
+        self.assertEqual([], subnets)
+
+        router = {'ha': True, 'project_id': project_id}
+        self.plugin._before_router_create(mock.ANY, admin_ctx, router)
+        ha_network = self.plugin.get_ha_network(admin_ctx, project_id)
+        self.assertEqual(project_id, ha_network.project_id)
+        subnets = subnet_obj.Subnet.get_objects(
+            admin_ctx, network_id=ha_network.network_id)
+        self.assertEqual(1, len(subnets))
+
+        # This test is simulating a concurrent update. The "Subnet.count"
+        # method returns 0 and "_before_router_create" tries to create the
+        # subnet again. The exception is catch and dismissed.
+        with mock.patch.object(subnet_obj.Subnet, 'count', return_value=0):
+            self.plugin._before_router_create(mock.ANY, admin_ctx, router)
+        subnets = subnet_obj.Subnet.get_objects(
+            admin_ctx, network_id=ha_network.network_id)
+        self.assertEqual(1, len(subnets))
+
 
 class L3HAUserTestCase(L3HATestFramework):
 
