@@ -12,12 +12,12 @@
 #    under the License.
 #
 
-
 import copy
+from unittest import mock
 
 import fixtures
-import mock
 from neutron_lib import context
+from neutron_lib.db import api as db_api
 from neutron_lib.db import constants as db_const
 from neutron_lib.exceptions import flavors as flav_exc
 from neutron_lib.plugins import constants
@@ -25,7 +25,6 @@ from oslo_config import cfg
 from oslo_utils import uuidutils
 from webob import exc
 
-from neutron.db import api as dbapi
 from neutron.db.models import l3 as l3_models
 from neutron.db import servicetype_db
 from neutron.extensions import flavors
@@ -52,10 +51,10 @@ class FlavorExtensionTestCase(extension.ExtensionTestCase):
 
     def setUp(self):
         super(FlavorExtensionTestCase, self).setUp()
-        self._setUpExtension(
+        self.setup_extension(
             'neutron.services.flavors.flavors_plugin.FlavorsPlugin',
-            constants.FLAVORS, {},
-            flavors.Flavors, '', supported_extension_aliases='flavors')
+            constants.FLAVORS, flavors.Flavors, '',
+            supported_extension_aliases=['flavors'])
 
     def test_create_flavor(self):
         tenant_id = uuidutils.generate_uuid()
@@ -199,7 +198,9 @@ class FlavorExtensionTestCase(extension.ExtensionTestCase):
                                'service_profiles': ['profile-1']}}
         instance = self.plugin.return_value
         instance.get_flavor.return_value = expected['flavor']
-        res = self.api.get(_get_path('flavors', id=flavor_id, fmt=self.fmt))
+        res = self.api.get(
+            _get_path('flavors', id=flavor_id, fmt=self.fmt),
+            extra_environ=test_base._get_neutron_env(as_admin=True))
         instance.get_flavor.assert_called_with(mock.ANY,
                                                flavor_id,
                                                fields=mock.ANY)
@@ -219,7 +220,9 @@ class FlavorExtensionTestCase(extension.ExtensionTestCase):
                              'service_profiles': ['profile-2', 'profile-1']}]}
         instance = self.plugin.return_value
         instance.get_flavors.return_value = data['flavors']
-        res = self.api.get(_get_path('flavors', fmt=self.fmt))
+        res = self.api.get(
+            _get_path('flavors', fmt=self.fmt),
+            extra_environ=test_base._get_neutron_env(as_admin=True))
         instance.get_flavors.assert_called_with(mock.ANY,
                                                 fields=mock.ANY,
                                                 filters=mock.ANY)
@@ -460,7 +463,7 @@ class FlavorPluginTestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
             self.service_manager.add_provider_configuration(
                 provider.split(':')[0], provconf.ProviderConfiguration())
 
-        dbapi.context_manager.writer.get_engine()
+        db_api.CONTEXT_WRITER.get_engine()
 
     def _create_flavor(self, description=None):
         flavor = {'flavor': {'name': 'GOLD',
@@ -482,6 +485,10 @@ class FlavorPluginTestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
         flavor = {'flavor': {'name': 'Silver',
                              'enabled': False}}
         self.plugin.update_flavor(self.ctx, fl['id'], flavor)
+
+        # don't reuse cached models from previous plugin call
+        self.ctx.session.expire_all()
+
         res = flavor_obj.Flavor.get_object(self.ctx, id=fl['id'])
         self.assertEqual('Silver', res['name'])
         self.assertFalse(res['enabled'])
@@ -560,6 +567,10 @@ class FlavorPluginTestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
         data['service_profile']['metainfo'] = '{"data": "value1"}'
         sp = self.plugin.update_service_profile(self.ctx, sp['id'],
                                                 data)
+
+        # don't reuse cached models from previous plugin call
+        self.ctx.session.expire_all()
+
         res = flavor_obj.ServiceProfile.get_object(self.ctx, id=sp['id'])
         self.assertEqual(data['service_profile']['metainfo'], res['metainfo'])
 
@@ -591,6 +602,9 @@ class FlavorPluginTestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
         self.assertEqual(fl['id'], binding['flavor_id'])
         self.assertEqual(sp['id'], binding['service_profile_id'])
 
+        # don't reuse cached models from previous plugin call
+        self.ctx.session.expire_all()
+
         res = self.plugin.get_flavor(self.ctx, fl['id'])
         self.assertEqual(1, len(res['service_profiles']))
         self.assertEqual(sp['id'], res['service_profiles'][0])
@@ -657,7 +671,7 @@ class FlavorPluginTestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
     def test_delete_flavor_in_use(self):
         # make use of router since it has a flavor id
         fl, data = self._create_flavor()
-        with self.ctx.session.begin():
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             self.ctx.session.add(l3_models.Router(flavor_id=fl['id']))
         self.assertRaises(
             flav_exc.FlavorInUse,
