@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from neutron_lib.api.definitions import servicetype as svctype_apidef
 from neutron_lib import context
 from neutron_lib import exceptions as n_exc
@@ -24,6 +25,7 @@ import webob.exc as webexc
 import webtest
 
 from neutron.api import extensions
+from neutron.common import config
 from neutron.db import servicetype_db as st_db
 from neutron.extensions import servicetype
 from neutron.objects import servicetype as servicetype_obj
@@ -47,6 +49,7 @@ class ServiceTypeManagerTestCase(testlib_api.SqlTestCase):
             provconf.NeutronModule, 'service_providers').start()
         super(ServiceTypeManagerTestCase, self).setUp()
         self.ctx = context.get_admin_context()
+        config.register_common_config_options()
         self.setup_coreplugin(PLUGIN_NAME)
 
     def _set_override(self, service_providers):
@@ -60,20 +63,20 @@ class ServiceTypeManagerTestCase(testlib_api.SqlTestCase):
                     svc_type=service_type))
 
     def test_service_provider_driver_not_unique(self):
-        self._set_override([constants.LOADBALANCER + ':lbaas:driver'])
-        prov = {'service_type': constants.LOADBALANCER,
+        self._set_override([constants.FIREWALL + ':fwaas:driver'])
+        prov = {'service_type': constants.FIREWALL,
                 'name': 'name2',
                 'driver': 'driver',
                 'default': False}
         self.assertRaises(
             n_exc.Invalid,
-            self.manager.config['LOADBALANCER'].add_provider, prov)
+            self.manager.config['FIREWALL'].add_provider, prov)
 
     def test_get_service_providers(self):
         """Test that get_service_providers filters correctly."""
         self._set_override(
-            [constants.LOADBALANCER +
-             ':lbaas:driver_path1',
+            [constants.VPN +
+             ':vpnaas:driver_path1',
              constants.FIREWALL +
              ':fwaas:driver_path2'])
         ctx = context.get_admin_context()
@@ -82,7 +85,7 @@ class ServiceTypeManagerTestCase(testlib_api.SqlTestCase):
 
         res = self.manager.get_service_providers(
             ctx,
-            filters=dict(service_type=[constants.LOADBALANCER])
+            filters=dict(service_type=[constants.FIREWALL])
         )
         self.assertEqual(1, len(res))
 
@@ -96,21 +99,21 @@ class ServiceTypeManagerTestCase(testlib_api.SqlTestCase):
         self.assertRaises(
             n_exc.Invalid,
             self._set_override,
-            [constants.LOADBALANCER +
-            ':lbaas1:driver_path:default',
-            constants.LOADBALANCER +
-            ':lbaas2:driver_path:default'])
+            [constants.FIREWALL +
+            ':fwaas1:driver_path:default',
+            constants.FIREWALL +
+            ':fwaas2:driver_path:default'])
 
     def test_get_default_provider(self):
-        self._set_override([constants.LOADBALANCER +
-                            ':lbaas1:driver_path:default',
+        self._set_override([constants.FIREWALL +
+                            ':fwaas1:driver_path:default',
                             dp.DUMMY_SERVICE_TYPE +
-                            ':lbaas2:driver_path2'])
+                            ':fwaas2:driver_path2'])
         # can pass None as a context
         p = self.manager.get_default_service_provider(None,
-                                                      constants.LOADBALANCER)
-        self.assertEqual({'service_type': constants.LOADBALANCER,
-                          'name': 'lbaas1',
+                                                      constants.FIREWALL)
+        self.assertEqual({'service_type': constants.FIREWALL,
+                          'name': 'fwaas1',
                           'driver': 'driver_path',
                           'default': True}, p)
 
@@ -148,24 +151,24 @@ class ServiceTypeManagerTestCase(testlib_api.SqlTestCase):
                           for td in test_data}, names_by_id)
 
     def test_add_resource_association(self):
-        self._set_override([constants.LOADBALANCER +
-                            ':lbaas1:driver_path:default',
+        self._set_override([constants.FIREWALL +
+                            ':fwaas1:driver_path:default',
                             dp.DUMMY_SERVICE_TYPE +
-                            ':lbaas2:driver_path2'])
+                            ':fwaas2:driver_path2'])
         ctx = context.get_admin_context()
         self.manager.add_resource_association(ctx,
-                                              constants.LOADBALANCER,
-                                              'lbaas1',
+                                              constants.FIREWALL,
+                                              'fwaas1',
                                               uuidutils.generate_uuid())
         self.assertEqual(
             1, servicetype_obj.ProviderResourceAssociation.count(ctx))
         servicetype_obj.ProviderResourceAssociation.delete_objects(ctx)
 
     def test_invalid_resource_association(self):
-        self._set_override([constants.LOADBALANCER +
-                            ':lbaas1:driver_path:default',
+        self._set_override([constants.FIREWALL +
+                            ':fwaas1:driver_path:default',
                             dp.DUMMY_SERVICE_TYPE +
-                            ':lbaas2:driver_path2'])
+                            ':fwaas2:driver_path2'])
         ctx = context.get_admin_context()
         self.assertRaises(provconf.ServiceProviderNotFound,
                           self.manager.add_resource_association,
@@ -191,6 +194,7 @@ class ServiceTypeExtensionTestCaseBase(testlib_api.WebTestCase):
     def setUp(self):
         # This is needed because otherwise a failure will occur due to
         # nonexisting core_plugin
+        config.register_common_config_options()
         self.setup_coreplugin(test_db_base_plugin_v2.DB_PLUGIN_KLASS)
 
         cfg.CONF.set_override('service_plugins',
@@ -232,7 +236,7 @@ class ServiceTypeManagerExtTestCase(ServiceTypeExtensionTestCaseBase):
         self.service_providers = mock.patch.object(
             provconf.NeutronModule, 'service_providers').start()
         service_providers = [
-            constants.LOADBALANCER + ':lbaas:driver_path',
+            constants.FIREWALL + ':fwaas:driver_path',
             dp.DUMMY_SERVICE_TYPE + ':dummy:dummy_dr'
         ]
         self.service_providers.return_value = service_providers
@@ -247,7 +251,8 @@ class ServiceTypeManagerExtTestCase(ServiceTypeExtensionTestCaseBase):
         super(ServiceTypeManagerExtTestCase, self).setUp()
 
     def _list_service_providers(self):
-        return self.api.get(_get_path('service-providers', fmt=self.fmt))
+        return self.api.get(_get_path('service-providers', fmt=self.fmt),
+                            extra_environ=test_base._get_neutron_env())
 
     def test_list_service_providers(self):
         res = self._list_service_providers()
