@@ -163,6 +163,7 @@ class FakeOvsdbNbOvnIdl(object):
         self.ha_chassis_group_del = mock.Mock()
         self.ha_chassis_group_add_chassis = mock.Mock()
         self.ha_chassis_group_del_chassis = mock.Mock()
+        self.get_lrouter_gw_ports = mock.Mock()
         self.lrp_get = mock.Mock()
         self.get_schema_version = mock.Mock(return_value='3.6.0')
 
@@ -324,6 +325,7 @@ class FakeNetwork(object):
             'availability_zone_hints': [],
             'is_default': False,
             'standard_attr_id': 1,
+            'mtu': 1500,
         }
 
         # Overwrite default attributes.
