@@ -55,6 +55,7 @@ from neutron.objects import router
 from neutron.objects import securitygroup
 from neutron.objects import stdattrs
 from neutron.objects import subnet
+from neutron.objects import subnetpool
 from neutron.tests import base as test_base
 from neutron.tests import tools
 from neutron.tests.unit.db import test_db_base_plugin_v2
@@ -505,6 +506,11 @@ def get_set_of_random_uuids():
     }
 
 
+def get_random_port_ranges():
+    port = tools.LAST_RANDOM_PORT_RANGE_GENERATED
+    return "%d:%d" % (port, port)
+
+
 # NOTE: The keys in this dictionary have alphabetic order.
 FIELD_TYPE_VALUE_GENERATOR_MAP = {
     common_types.DictOfMiscValuesField: get_random_dict,
@@ -552,7 +558,8 @@ FIELD_TYPE_VALUE_GENERATOR_MAP = {
     port_numa_affinity_policy.NumaAffinityPoliciesEnumField:
         tools.get_random_port_numa_affinity_policy,
     port_device_profile.PortDeviceProfile:
-        lambda: helpers.get_random_string(255)
+        lambda: helpers.get_random_string(255),
+    common_types.PortRangesField: get_random_port_ranges
 }
 
 
@@ -1549,12 +1556,14 @@ class BaseDbObjectTestCase(_BaseObjectTestCase,
         _network.create()
         return _network
 
-    def _create_test_network_id(self):
+    def _create_test_network_id(self, qos_policy_id=None):
         return self._create_test_network(
-            "test-network-%s" % helpers.get_random_string(4)).id
+            name="test-network-%s" % helpers.get_random_string(4),
+            qos_policy_id=qos_policy_id).id
 
-    def _create_external_network_id(self):
-        test_network_id = self._create_test_network_id()
+    def _create_external_network_id(self, qos_policy_id=None):
+        test_network_id = self._create_test_network_id(
+            qos_policy_id=qos_policy_id)
         ext_net = net_obj.ExternalNetwork(self.context,
             network_id=test_network_id)
         ext_net.create()
@@ -1575,7 +1584,7 @@ class BaseDbObjectTestCase(_BaseObjectTestCase,
         fip_obj.create()
         return fip_obj.id
 
-    def _create_test_subnet_id(self, network_id=None):
+    def _create_test_subnet_id(self, network_id=None, subnet_pool_id=None):
         if not network_id:
             network_id = self._create_test_network_id()
         test_subnet = {
@@ -1589,6 +1598,8 @@ class BaseDbObjectTestCase(_BaseObjectTestCase,
             'ipv6_ra_mode': None,
             'ipv6_address_mode': None
         }
+        if subnet_pool_id:
+            test_subnet['subnetpool_id'] = subnet_pool_id
         subnet_obj = subnet.Subnet(self.context, **test_subnet)
         subnet_obj.create()
         return subnet_obj.id
@@ -1633,9 +1644,9 @@ class BaseDbObjectTestCase(_BaseObjectTestCase,
         segment.create()
         return segment.id
 
-    def _create_test_router_id(self, router_id=None):
+    def _create_test_router_id(self, router_id=None, name=None):
         attrs = {
-            'name': 'test_router',
+            'name': name or 'test_router',
         }
         if router_id:
             attrs['id'] = router_id
@@ -1714,6 +1725,21 @@ class BaseDbObjectTestCase(_BaseObjectTestCase,
         _qos_policy.create()
         return _qos_policy
 
+    def _create_test_subnet_pool(
+            self, prefix, default_prefixlen, min_prefixlen, max_prefixlen,
+            ip_version):
+        subnet_pool = {
+            'prefixes': [prefix],
+            'default_prefixlen': default_prefixlen,
+            'min_prefixlen': min_prefixlen,
+            'max_prefixlen': max_prefixlen,
+            'ip_version': ip_version,
+            'address_scope_id': uuidutils.generate_uuid(),
+        }
+        subnet_pool_obj = subnetpool.SubnetPool(self.context, **subnet_pool)
+        subnet_pool_obj.create()
+        return subnet_pool_obj.id, subnet_pool_obj.address_scope_id
+
     def test_get_standard_attr_id(self):
 
         if not self._test_class.has_standard_attributes():
@@ -2204,7 +2230,7 @@ class GetObjectClassByModelTestCase(UniqueObjectBase):
             self.registered_object.db_model)
         self.assertIs(self.registered_object, found_obj)
 
-    def test_not_registed_object_raises_exception(self):
+    def test_not_registered_object_raises_exception(self):
         with testtools.ExpectedException(o_exc.NeutronDbObjectNotFoundByModel):
             base.get_object_class_by_model(self.not_registered_object.db_model)
 
