@@ -19,12 +19,12 @@ import time
 from unittest import mock
 
 from neutron_lib import constants as n_const
+from neutron_lib.plugins.ml2 import ovs_constants
 from oslo_config import cfg
 from oslo_log import log
 
 from neutron.agent.common import ip_lib
 from neutron.agent.common import ovs_lib
-from neutron.plugins.ml2.drivers.openvswitch.agent.common import constants
 from neutron.tests.unit.plugins.ml2.drivers.openvswitch.agent \
     import ovs_test_base
 from neutron.tests.unit.plugins.ml2.drivers.openvswitch.agent \
@@ -220,14 +220,14 @@ class TunnelTest(object):
             mock.call.setup_default_table(),
             mock.call.port_exists('phy-%s' % self.MAP_TUN_BRIDGE),
             mock.call.add_patch_port('phy-%s' % self.MAP_TUN_BRIDGE,
-                                     constants.NONEXISTENT_PEER),
+                                     ovs_constants.NONEXISTENT_PEER),
         ]
         self.mock_int_bridge_expected += [
             mock.call.db_get_val('Interface', 'int-%s' % self.MAP_TUN_BRIDGE,
                                  'type', log_errors=False),
             mock.call.port_exists('int-%s' % self.MAP_TUN_BRIDGE),
             mock.call.add_patch_port('int-%s' % self.MAP_TUN_BRIDGE,
-                                     constants.NONEXISTENT_PEER),
+                                     ovs_constants.NONEXISTENT_PEER),
             mock.call.set_igmp_snooping_flood('int-%s' % self.MAP_TUN_BRIDGE,
                                               igmp_snooping),
         ]
@@ -287,16 +287,16 @@ class TunnelTest(object):
 
         self.mock_int_bridge_expected += [
             mock.call.install_goto(
-                dest_table_id=constants.LOCAL_MAC_DIRECT,
+                dest_table_id=ovs_constants.LOCAL_MAC_DIRECT,
                 in_port=self.MAP_TUN_INT_OFPORT,
-                priority=4, table_id=constants.TRANSIENT_TABLE),
+                priority=4, table_id=ovs_constants.TRANSIENT_TABLE),
             mock.call.install_goto(
-                dest_table_id=constants.LOCAL_MAC_DIRECT,
+                dest_table_id=ovs_constants.LOCAL_MAC_DIRECT,
                 in_port=self.TUN_OFPORT,
-                priority=4, table_id=constants.TRANSIENT_TABLE),
+                priority=4, table_id=ovs_constants.TRANSIENT_TABLE),
             mock.call.install_goto(
-                dest_table_id=constants.TRANSIENT_EGRESS_TABLE,
-                table_id=constants.LOCAL_MAC_DIRECT),
+                dest_table_id=ovs_constants.TRANSIENT_EGRESS_TABLE,
+                table_id=ovs_constants.LOCAL_MAC_DIRECT),
         ]
 
     def _build_agent(self, **config_opts_agent):
@@ -460,7 +460,7 @@ class TunnelTest(object):
         a = self._build_agent()
         a.available_local_vlans = set()
         a.vlan_manager.add(NET_UUID, *self.LVM_DATA)
-        a.reclaim_local_vlan(NET_UUID)
+        a.reclaim_local_vlan(NET_UUID, LS_ID)
         self.assertIn(self.LVM_DATA[0], a.available_local_vlans)
         self._verify_mock_calls()
 
@@ -480,7 +480,7 @@ class TunnelTest(object):
 
         a.available_local_vlans = set()
         a.vlan_manager.add(NET_UUID, *self.LVM_FLAT_DATA)
-        a.reclaim_local_vlan(NET_UUID)
+        a.reclaim_local_vlan(NET_UUID, LS_ID)
         self.assertIn(self.LVM_FLAT_DATA[0], a.available_local_vlans)
         self._verify_mock_calls()
 
@@ -500,7 +500,7 @@ class TunnelTest(object):
 
         a.available_local_vlans = set()
         a.vlan_manager.add(NET_UUID, *self.LVM_VLAN_DATA)
-        a.reclaim_local_vlan(NET_UUID)
+        a.reclaim_local_vlan(NET_UUID, LS_ID)
         self.assertIn(self.LVM_VLAN_DATA[0], a.available_local_vlans)
         self._verify_mock_calls()
 
@@ -508,7 +508,8 @@ class TunnelTest(object):
         vlan_mapping = {'segmentation_id': str(LS_ID),
                         'physical_network': 'None',
                         'net_uuid': NET_UUID,
-                        'network_type': 'gre'}
+                        'network_type': 'gre',
+                        'tag': str(LV_ID)}
         self.mock_int_bridge_expected += [
             mock.call.db_get_val('Port', 'port', 'other_config'),
             mock.call.set_db_attribute('Port', VIF_PORT.port_name,
@@ -519,9 +520,11 @@ class TunnelTest(object):
         a.vlan_manager.add(NET_UUID, *self.LVM_DATA)
         a.local_dvr_map = {}
         self.ovs_bridges[self.INT_BRIDGE].db_get_val.return_value = {}
-        a.port_bound(VIF_PORT, NET_UUID, 'gre', None, LS_ID,
-                     FIXED_IPS, VM_DEVICE_OWNER, False)
-        self._verify_mock_calls()
+        with mock.patch.object(a, "_set_port_vlan") as set_vlan:
+            a.port_bound(VIF_PORT, NET_UUID, 'gre', None, LS_ID,
+                         FIXED_IPS, VM_DEVICE_OWNER, False)
+            self._verify_mock_calls()
+            set_vlan.assert_called_once_with(VIF_PORT, LV_ID)
 
     def test_port_unbound(self):
         with mock.patch.object(self.mod_agent.OVSNeutronAgent,
@@ -530,7 +533,7 @@ class TunnelTest(object):
             a.vlan_manager.add(NET_UUID, *self.LVM_DATA)
             a.port_unbound(VIF_ID, NET_UUID)
 
-        reclaim_local_vlan.assert_called_once_with(NET_UUID)
+        reclaim_local_vlan.assert_called_once_with(NET_UUID, LS_ID)
         self._verify_mock_calls()
 
     def test_port_dead(self):
@@ -539,7 +542,7 @@ class TunnelTest(object):
                                  log_errors=True),
             mock.call.set_db_attribute(
                 'Port', VIF_PORT.port_name,
-                'tag', constants.DEAD_VLAN_TAG,
+                'tag', ovs_constants.DEAD_VLAN_TAG,
                 log_errors=True),
             mock.call.drop_port(in_port=VIF_PORT.ofport),
         ]
@@ -615,7 +618,7 @@ class TunnelTest(object):
         # No cleanup is expected on ancillary bridge
 
         self.ovs_bridges[self.INT_BRIDGE].check_canary_table.return_value = \
-            constants.OVS_NORMAL
+            ovs_constants.OVS_NORMAL
         with mock.patch.object(log.KeywordArgumentAdapter,
                                'exception') as log_exception,\
                 mock.patch.object(self.mod_agent.OVSNeutronAgent,
