@@ -22,7 +22,6 @@ from neutron_lib import context
 from neutron_lib.db import api as db_api
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-from oslo_utils import uuidutils
 
 from neutron.common.ovn import constants
 from neutron.common.ovn import utils
@@ -417,7 +416,8 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
         self.assertFalse(
             self.fake_ovn_client.sync_ha_chassis_group.called)
 
-    def test_check_for_ha_chassis_group(self):
+    @mock.patch.object(utils, 'sync_ha_chassis_group')
+    def test_check_for_ha_chassis_group(self, mock_sync_ha_chassis_group):
         self.fake_ovn_client.is_external_ports_supported.return_value = True
         nb_idl = self.fake_ovn_client._nb_idl
 
@@ -441,7 +441,7 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
                        constants.OVN_NETWORK_NAME_EXT_ID_KEY: 'neutron-net1'}})
 
         nb_idl.db_find_rows.return_value.execute.return_value = [p0, p1]
-        self.fake_ovn_client.sync_ha_chassis_group.return_value = hcg0.uuid
+        mock_sync_ha_chassis_group.return_value = hcg0.uuid
 
         # Invoke the periodic method, it meant to run only once at startup
         # so NeverAgain will be raised at the end
@@ -450,16 +450,21 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
 
         # Assert sync_ha_chassis_group() is called for both networks
         expected_calls = [
-            mock.call(mock.ANY, 'net0', mock.ANY),
-            mock.call(mock.ANY, 'net1', mock.ANY)]
-        self.fake_ovn_client.sync_ha_chassis_group.assert_has_calls(
-            expected_calls)
+            mock.call(mock.ANY, 'net0',
+                      self.fake_ovn_client._nb_idl,
+                      self.fake_ovn_client._sb_idl, mock.ANY),
+            mock.call(mock.ANY, 'net1',
+                      self.fake_ovn_client._nb_idl,
+                      self.fake_ovn_client._sb_idl, mock.ANY),
+        ]
+        mock_sync_ha_chassis_group.assert_has_calls(expected_calls,
+                                                    any_order=True)
 
-        # Assert set_lswitch_port() is only called for p1 because
-        # the ha_chassis_group is different than what was returned
-        # by sync_ha_chassis_group()
-        nb_idl.set_lswitch_port.assert_called_once_with(
-            'p1', ha_chassis_group=hcg0.uuid)
+        expected_calls = [
+            mock.call('p0', ha_chassis_group=hcg0.uuid),
+            mock.call('p1', ha_chassis_group=hcg0.uuid)]
+        nb_idl.set_lswitch_port.assert_has_calls(expected_calls,
+                                                 any_order=True)
 
     def test_check_port_has_address_scope(self):
         self.fake_ovn_client.is_external_ports_supported.return_value = True
@@ -660,6 +665,102 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
         nb_idl.db_remove.assert_has_calls(expected_calls)
         self.assertEqual(2, nb_idl.db_remove.call_count)
 
+    def test_check_localnet_port_has_learn_fdb(self):
+        cfg.CONF.set_override('localnet_learn_fdb', 'True',
+                              group='ovn')
+        nb_idl = self.fake_ovn_client._nb_idl
+
+        # Already has the learn fdb option enabled
+        lsp0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={
+                "name": "lsp0",
+                "options": {
+                    constants.LSP_OPTIONS_LOCALNET_LEARN_FDB: "true",
+                },
+            }
+        )
+
+        # learn fdb option missing, needs update
+        lsp1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={
+                "name": "lsp1",
+                "options": {},
+            }
+        )
+
+        # learn fdb option set to false, needs update
+        lsp2 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={
+                "name": "lsp2",
+                "options": {
+                    constants.LSP_OPTIONS_LOCALNET_LEARN_FDB: "false",
+                },
+            }
+        )
+
+        nb_idl.db_find_rows.return_value.execute.return_value = [
+            lsp0,
+            lsp1,
+            lsp2,
+        ]
+
+        self.assertRaises(
+            periodics.NeverAgain,
+            self.periodic.check_localnet_port_has_learn_fdb)
+
+        options = {constants.LSP_OPTIONS_LOCALNET_LEARN_FDB: 'true'}
+        expected_calls = [mock.call('Logical_Switch_Port', 'lsp1',
+                                    ('options', options)),
+                          mock.call('Logical_Switch_Port', 'lsp2',
+                                    ('options', options))]
+        nb_idl.db_set.assert_has_calls(expected_calls)
+
+    def test_check_localnet_port_has_learn_fdb_disabled(self):
+        nb_idl = self.fake_ovn_client._nb_idl
+
+        # learn fdb option enabled, needs update
+        lsp0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={
+                "name": "lsp0",
+                "options": {
+                    constants.LSP_OPTIONS_LOCALNET_LEARN_FDB: "true",
+                },
+            }
+        )
+
+        # learn fdb option missing, no update needed
+        lsp1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={
+                "name": "lsp1",
+                "options": {},
+            }
+        )
+
+        # learn fdb option set to false, no update needed
+        lsp2 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={
+                "name": "lsp2",
+                "options": {
+                    constants.LSP_OPTIONS_LOCALNET_LEARN_FDB: "false",
+                },
+            }
+        )
+
+        nb_idl.db_find_rows.return_value.execute.return_value = [
+            lsp0,
+            lsp1,
+            lsp2,
+        ]
+
+        self.assertRaises(
+            periodics.NeverAgain,
+            self.periodic.check_localnet_port_has_learn_fdb)
+
+        options = {constants.LSP_OPTIONS_LOCALNET_LEARN_FDB: 'false'}
+        expected_calls = [mock.call('Logical_Switch_Port', 'lsp0',
+                                    ('options', options))]
+        nb_idl.db_set.assert_has_calls(expected_calls)
+
     def test_check_router_mac_binding_options(self):
         nb_idl = self.fake_ovn_client._nb_idl
         lr0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
@@ -688,29 +789,6 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
                                'dynamic_neigh_routers': 'true'})]
         nb_idl.update_lrouter.assert_has_calls(expected_calls)
 
-    def test_update_port_qos_with_external_ids_reference(self):
-        nb_idl = self.fake_ovn_client._nb_idl
-        lrs = [fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lr%s' % idx}) for idx in range(3)]
-        uuid1 = uuidutils.generate_uuid()
-        qoses1 = [fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'external_ids': {}, 'match': 'inport == "%s"' % uuid1})]
-        qoses2 = [fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'external_ids': {constants.OVN_PORT_EXT_ID_KEY: uuid1},
-                   'match': 'inport == "%s"' % uuid1})]
-        qoses3 = []
-        nb_idl.ls_list.return_value.execute.return_value = lrs
-        nb_idl.qos_list.return_value.execute.side_effect = [qoses1, qoses2,
-                                                            qoses3]
-        self.assertRaises(
-            periodics.NeverAgain,
-            self.periodic.update_port_qos_with_external_ids_reference)
-
-        external_ids = {constants.OVN_PORT_EXT_ID_KEY: uuid1}
-        expected_calls = [mock.call('QoS', qoses1[0].uuid,
-                                    ('external_ids', external_ids))]
-        nb_idl.db_set.assert_has_calls(expected_calls)
-
     def _test_check_redirect_type_router_gateway_ports(self, networks,
                                                        redirect_value):
         self.fake_ovn_client._plugin.get_ports.return_value = [{
@@ -813,18 +891,18 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
         self.fake_ovn_client._nb_idl.db_set.assert_has_calls(
             expected_calls)
 
-    def test_update_logical_router_with_gateway_network_id(self):
+    def test_remove_gw_ext_ids_from_logical_router(self):
         nb_idl = self.fake_ovn_client._nb_idl
-        # lr0: GW port ID, not GW network ID --> we need to add network ID.
+        # lr0: GW port ID, not GW network ID --> we need to remove port ID.
         lr0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
             'name': 'lr0',
             'external_ids': {constants.OVN_GW_PORT_EXT_ID_KEY: 'port0'}})
-        # lr1: GW port ID and not GW network ID --> register already updated.
+        # lr1: GW port ID and GW network ID --> we need to remove both.
         lr1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
                 'name': 'lr1',
                 'external_ids': {constants.OVN_GW_PORT_EXT_ID_KEY: 'port1',
                                  constants.OVN_GW_NETWORK_EXT_ID_KEY: 'net1'}})
-        # lr2: no GW port ID (nor GW network ID) --> no QoS.
+        # lr2: no GW port ID (nor GW network ID) --> no action needed.
         lr2 = fakes.FakeOvsdbRow.create_one_ovsdb_row(attrs={
                 'name': 'lr2', 'external_ids': {}})
         nb_idl.lr_list.return_value.execute.return_value = (lr0, lr1, lr2)
@@ -833,10 +911,11 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
 
         self.assertRaises(
             periodics.NeverAgain,
-            self.periodic.update_logical_router_with_gateway_network_id)
-        ext_ids = {constants.OVN_GW_NETWORK_EXT_ID_KEY: 'net0'}
+            self.periodic.remove_gw_ext_ids_from_logical_router)
         expected_calls = [mock.call('Logical_Router', lr0.uuid,
-                                    ('external_ids', ext_ids))]
+                                    ('external_ids', {})),
+                          mock.call('Logical_Router', lr1.uuid,
+                                    ('external_ids', {}))]
         nb_idl.db_set.assert_has_calls(expected_calls)
 
     def _test_check_baremetal_ports_dhcp_options(self, dhcp_disabled=False):
