@@ -73,7 +73,8 @@ class TestOVNClient(TestOVNClientBase):
         txn = mock.MagicMock()
         self.assertEqual(
             self.get_plugin().get_port(),
-            self.ovn_client._add_router_ext_gw(router, networks, txn))
+            self.ovn_client._add_router_ext_gw(mock.Mock(), router, networks,
+                                               txn))
         self.nb_idl.add_static_route.assert_called_once_with(
             'neutron-' + router['id'],
             ip_prefix='0.0.0.0/0',
@@ -104,7 +105,8 @@ class TestOVNClient(TestOVNClientBase):
         txn = mock.MagicMock()
         self.assertEqual(
             self.get_plugin().get_port(),
-            self.ovn_client._add_router_ext_gw(router, networks, txn))
+            self.ovn_client._add_router_ext_gw(mock.Mock(), router, networks,
+                                               txn))
         self.nb_idl.add_static_route.assert_not_called()
 
     def test_update_lsp_host_info_up(self):
