@@ -18,7 +18,9 @@ import contextlib
 import datetime
 from unittest import mock
 
+from neutron_lib.api import attributes
 from neutron_lib.api.definitions import l3_ext_ha_mode
+from neutron_lib.api.definitions import network_ha
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import router_availability_zone
 from neutron_lib.callbacks import events
@@ -209,13 +211,13 @@ class L3SchedulerBaseMixin(object):
 
     @contextlib.contextmanager
     def router_with_ext_gw(self, name='router1', admin_state_up=True,
-                           fmt=None, tenant_id=uuidutils.generate_uuid(),
+                           fmt=None, tenant_id=None,
                            external_gateway_info=None,
-                           subnet=None, set_context=False,
-                           **kwargs):
+                           subnet=None, **kwargs):
+        tenant_id = tenant_id or self._tenant_id
         router = self._make_router(fmt or self.fmt, tenant_id, name,
                                    admin_state_up, external_gateway_info,
-                                   set_context, **kwargs)
+                                   **kwargs)
         self._add_external_gateway_to_router(
             router['router']['id'],
             subnet['subnet']['network_id'])
@@ -1380,6 +1382,7 @@ class L3DvrSchedulerTestCase(L3SchedulerBaseMixin,
                 subnet_ids = []
                 subnet_ids.append(subnet['subnet']['id'])
                 with self.port(subnet=subnet,
+                               is_admin=True,
                                device_owner=DEVICE_OWNER_COMPUTE,
                                arg_list=('admin_state_up',
                                portbindings.PROFILE,), **host_args):
@@ -1454,6 +1457,10 @@ class L3HATestCaseMixin(testlib_api.SqlTestCase,
         self.mock_make_res = make_res.start()
         commit_res = mock.patch.object(quota.QuotaEngine, 'commit_reservation')
         self.mock_quota_commit_res = commit_res.start()
+        # Extend network HA extension.
+        rname = network_ha.COLLECTION_NAME
+        attributes.RESOURCES[rname].update(
+            network_ha.RESOURCE_ATTRIBUTE_MAP[rname])
 
     @staticmethod
     def get_router_l3_agent_binding(context, router_id, l3_agent_id=None,
@@ -1640,6 +1647,8 @@ class L3_HA_scheduler_db_mixinTestCase(L3HATestCaseMixin):
         router2 = self._create_ha_router()
         router3 = self._create_ha_router(ha=False)
         result = self.plugin.get_routers_l3_agents_count(self.adminContext)
+        result += self.plugin.get_routers_l3_agents_count(
+            self.adminContext, ha=True)
 
         self.assertEqual(3, len(result))
         check_result = [(router['id'], agents) for router, agents in result]
@@ -1647,6 +1656,29 @@ class L3_HA_scheduler_db_mixinTestCase(L3HATestCaseMixin):
         self.assertIn((router2['id'], 2), check_result)
         self.assertIn((router3['id'], 0), check_result)
 
+        result = self.plugin.get_routers_l3_agents_count(self.adminContext,
+                                                         ha=True, less_than=3)
+        check_result = [(router['id'], agents) for router, agents in result]
+        self.assertIn((router2['id'], 2), check_result)
+
+    def test_get_routers_not_ha_l3_agents_count(self):
+        router1 = self._create_ha_router(ha=False)
+        router2 = self._create_ha_router(ha=False)
+        self.plugin.schedule_router(self.adminContext, router1['id'],
+                                    candidates=[self.agent1])
+        result = self.plugin.get_routers_l3_agents_count(self.adminContext)
+
+        self.assertEqual(2, len(result))
+        check_result = [(router['id'], agents) for router, agents in result]
+        self.assertIn((router1['id'], 1), check_result)
+        self.assertIn((router2['id'], 0), check_result)
+
+        result = self.plugin.get_routers_l3_agents_count(self.adminContext,
+                                                         less_than=1)
+        check_result = [(router['id'], agents) for router, agents in result]
+        self.assertIn((router2['id'], 0), check_result)
+        self.assertNotIn((router1['id'], 1), check_result)
+
     def test_get_ordered_l3_agents_by_num_routers(self):
         # Mock scheduling so that the test can control it explicitly
         mock.patch.object(l3_hamode_db.L3_HA_NAT_db_mixin,
@@ -2087,6 +2119,10 @@ class L3AgentAZLeastRoutersSchedulerTestCase(L3HATestCaseMixin):
         self.patch_notifier = mock.patch(
             'neutron.notifiers.batch_notifier.BatchNotifier._notify')
         self.patch_notifier.start()
+        # Extend network HA extension.
+        rname = network_ha.COLLECTION_NAME
+        attributes.RESOURCES[rname].update(
+            network_ha.RESOURCE_ATTRIBUTE_MAP[rname])
 
     def _register_l3_agents(self):
         self.agent1 = helpers.register_l3_agent(host='az1-host1', az='az1')
